/**
 * 实用函数类，全局依赖，必须首先引用。
 */

Diigo = {
    Text : {},
    Doodle : {},
    UndoRedo : {},
    Data : {},
    FPT : {},
    $ : function(id){
        return document.getElementById(id);
    }
};

(function($) {

    var pathParser = {};

    pathParser.parsePathData = function(data) {
        // Path Data Segment must begin with a moveTo
        //m (x y)+  Relative moveTo (subsequent points are treated as lineTo)
        //M (x y)+  Absolute moveTo (subsequent points are treated as lineTo)
        //l (x y)+  Relative lineTo
        //L (x y)+  Absolute LineTo
        //h (x)+    Relative horizontal lineTo
        //H (x)+    Absolute horizontal lineTo
        //v (y)+    Relative vertical lineTo
        //V (y)+    Absolute vertical lineTo
        //z (closepath)
        //Z (closepath)
        //c (x1 y1 x2 y2 x y)+ Relative Bezier curve
        //C (x1 y1 x2 y2 x y)+ Absolute Bezier curve
        //q (x1 y1 x y)+       Relative Quadratic Bezier
        //Q (x1 y1 x y)+       Absolute Quadratic Bezier
        //t (x y)+    Shorthand/Smooth Relative Quadratic Bezier
        //T (x y)+    Shorthand/Smooth Absolute Quadratic Bezier
        //s (x2 y2 x y)+       Shorthand/Smooth Relative Bezier curve
        //S (x2 y2 x y)+       Shorthand/Smooth Absolute Bezier curve
        //a (rx ry x-axis-rotation large-arc-flag sweep-flag x y)+     Relative Elliptical Arc
        //A (rx ry x-axis-rotation large-arc-flag sweep-flag x y)+  Absolute Elliptical Arc

        // return early if data is not defined
        if (!data) {
            return [];
        }

        // command string
        var cs = data;

        // command chars
        var cc = ['m', 'M', 'l', 'L', 'v', 'V', 'h', 'H', 'z', 'Z', 'c', 'C', 'q', 'Q', 't', 'T', 's', 'S', 'a', 'A'];
        // convert white spaces to commas
        cs = cs.replace(new RegExp(' ', 'g'), ',');
        // create pipes so that we can split the data
        for (var n = 0; n < cc.length; n++) {
            cs = cs.replace(new RegExp(cc[n], 'g'), '|' + cc[n]);
        }
        // create array
        var arr = cs.split('|');
        var ca = [];
        // init context point
        var cpx = 0;
        var cpy = 0;
        for (n = 1; n < arr.length; n++) {
            var str = arr[n];
            var c = str.charAt(0);
            str = str.slice(1);
            // remove ,- for consistency
            str = str.replace(new RegExp(',-', 'g'), '-');
            // add commas so that it's easy to split
            str = str.replace(new RegExp('-', 'g'), ',-');
            str = str.replace(new RegExp('e,-', 'g'), 'e-');
            var p = str.split(',');
            if (p.length > 0 && p[0] === '') {
                p.shift();
            }
            // convert strings to floats
            for (var i = 0; i < p.length; i++) {
                p[i] = parseFloat(p[i]);
            }
            while (p.length > 0) {
                if (isNaN(p[0])) { // case for a trailing comma before next command
                    break;
                }

                var cmd = null;
                var points = [];
                var startX = cpx,
                    startY = cpy;
                // Move var from within the switch to up here (jshint)
                var prevCmd, ctlPtx, ctlPty; // Ss, Tt
                var rx, ry, psi, fa, fs, x1, y1; // Aa


                // convert l, H, h, V, and v to L
                switch (c) {

                    // Note: Keep the lineTo's above the moveTo's in this switch
                    case 'l':
                        cpx += p.shift();
                        cpy += p.shift();
                        cmd = 'L';
                        points.push(cpx, cpy);
                        break;
                    case 'L':
                        cpx = p.shift();
                        cpy = p.shift();
                        points.push(cpx, cpy);
                        break;

                    // Note: lineTo handlers need to be above this point
                    case 'm':
                        var dx = p.shift();
                        var dy = p.shift();
                        cpx += dx;
                        cpy += dy;
                        cmd = 'M';
                        // After closing the path move the current position
                        // to the the first point of the path (if any).
                        if (ca.length > 2 && ca[ca.length - 1].command === 'z') {
                            for (var idx = ca.length - 2; idx >= 0; idx--) {
                                if (ca[idx].command === 'M') {
                                    cpx = ca[idx].points[0] + dx;
                                    cpy = ca[idx].points[1] + dy;
                                    break;
                                }
                            }
                        }
                        points.push(cpx, cpy);
                        c = 'l';
                        // subsequent points are treated as relative lineTo
                        break;
                    case 'M':
                        cpx = p.shift();
                        cpy = p.shift();
                        cmd = 'M';
                        points.push(cpx, cpy);
                        c = 'L';
                        // subsequent points are treated as absolute lineTo
                        break;

                    case 'h':
                        cpx += p.shift();
                        cmd = 'L';
                        points.push(cpx, cpy);
                        break;
                    case 'H':
                        cpx = p.shift();
                        cmd = 'L';
                        points.push(cpx, cpy);
                        break;
                    case 'v':
                        cpy += p.shift();
                        cmd = 'L';
                        points.push(cpx, cpy);
                        break;
                    case 'V':
                        cpy = p.shift();
                        cmd = 'L';
                        points.push(cpx, cpy);
                        break;
                    case 'C':
                        points.push(p.shift(), p.shift(), p.shift(), p.shift());
                        cpx = p.shift();
                        cpy = p.shift();
                        points.push(cpx, cpy);
                        break;
                    case 'c':
                        points.push(cpx + p.shift(), cpy + p.shift(), cpx + p.shift(), cpy + p.shift());
                        cpx += p.shift();
                        cpy += p.shift();
                        cmd = 'C';
                        points.push(cpx, cpy);
                        break;
                    case 'S':
                        ctlPtx = cpx;
                        ctlPty = cpy;
                        prevCmd = ca[ca.length - 1];
                        if (prevCmd.command === 'C') {
                            ctlPtx = cpx + (cpx - prevCmd.points[2]);
                            ctlPty = cpy + (cpy - prevCmd.points[3]);
                        }
                        points.push(ctlPtx, ctlPty, p.shift(), p.shift());
                        cpx = p.shift();
                        cpy = p.shift();
                        cmd = 'C';
                        points.push(cpx, cpy);
                        break;
                    case 's':
                        ctlPtx = cpx;
                        ctlPty = cpy;
                        prevCmd = ca[ca.length - 1];
                        if (prevCmd.command === 'C') {
                            ctlPtx = cpx + (cpx - prevCmd.points[2]);
                            ctlPty = cpy + (cpy - prevCmd.points[3]);
                        }
                        points.push(ctlPtx, ctlPty, cpx + p.shift(), cpy + p.shift());
                        cpx += p.shift();
                        cpy += p.shift();
                        cmd = 'C';
                        points.push(cpx, cpy);
                        break;
                    case 'Q':
                        points.push(p.shift(), p.shift());
                        cpx = p.shift();
                        cpy = p.shift();
                        points.push(cpx, cpy);
                        break;
                    case 'q':
                        points.push(cpx + p.shift(), cpy + p.shift());
                        cpx += p.shift();
                        cpy += p.shift();
                        cmd = 'Q';
                        points.push(cpx, cpy);
                        break;
                    case 'T':
                        ctlPtx = cpx;
                        ctlPty = cpy;
                        prevCmd = ca[ca.length - 1];
                        if (prevCmd.command === 'Q') {
                            ctlPtx = cpx + (cpx - prevCmd.points[0]);
                            ctlPty = cpy + (cpy - prevCmd.points[1]);
                        }
                        cpx = p.shift();
                        cpy = p.shift();
                        cmd = 'Q';
                        points.push(ctlPtx, ctlPty, cpx, cpy);
                        break;
                    case 't':
                        ctlPtx = cpx;
                        ctlPty = cpy;
                        prevCmd = ca[ca.length - 1];
                        if (prevCmd.command === 'Q') {
                            ctlPtx = cpx + (cpx - prevCmd.points[0]);
                            ctlPty = cpy + (cpy - prevCmd.points[1]);
                        }
                        cpx += p.shift();
                        cpy += p.shift();
                        cmd = 'Q';
                        points.push(ctlPtx, ctlPty, cpx, cpy);
                        break;
                    case 'A':
                        rx = p.shift();
                        ry = p.shift();
                        psi = p.shift();
                        fa = p.shift();
                        fs = p.shift();
                        x1 = cpx;
                        y1 = cpy;
                        cpx = p.shift();
                        cpy = p.shift();
                        cmd = 'A';
                        points = this.convertEndpointToCenterParameterization(x1, y1, cpx, cpy, fa, fs, rx, ry, psi);
                        break;
                    case 'a':
                        rx = p.shift();
                        ry = p.shift();
                        psi = p.shift();
                        fa = p.shift();
                        fs = p.shift();
                        x1 = cpx;
                        y1 = cpy;
                        cpx += p.shift();
                        cpy += p.shift();
                        cmd = 'A';
                        points = this.convertEndpointToCenterParameterization(x1, y1, cpx, cpy, fa, fs, rx, ry, psi);
                        break;
                }

                ca.push({
                    command: cmd || c,
                    points: points
                });
            }

            if (c === 'z' || c === 'Z') {
                ca.push({
                    command: 'z',
                    points: []
                });
            }
        }

        return ca;
    };


    pathParser.convertEndpointToCenterParameterization = function(x1, y1, x2, y2, fa, fs, rx, ry, psiDeg) {
        // Derived from: http://www.w3.org/TR/SVG/implnote.html#ArcImplementationNotes
        var psi = psiDeg * (Math.PI / 180.0);
        var xp = Math.cos(psi) * (x1 - x2) / 2.0 + Math.sin(psi) * (y1 - y2) / 2.0;
        var yp = -1 * Math.sin(psi) * (x1 - x2) / 2.0 + Math.cos(psi) * (y1 - y2) / 2.0;

        var lambda = (xp * xp) / (rx * rx) + (yp * yp) / (ry * ry);

        if (lambda > 1) {
            rx *= Math.sqrt(lambda);
            ry *= Math.sqrt(lambda);
        }

        var f = Math.sqrt((((rx * rx) * (ry * ry)) - ((rx * rx) * (yp * yp)) - ((ry * ry) * (xp * xp))) / ((rx * rx) * (yp * yp) + (ry * ry) * (xp * xp)));

        if (fa === fs) {
            f *= -1;
        }
        if (isNaN(f)) {
            f = 0;
        }

        var cxp = f * rx * yp / ry;
        var cyp = f * -ry * xp / rx;

        var cx = (x1 + x2) / 2.0 + Math.cos(psi) * cxp - Math.sin(psi) * cyp;
        var cy = (y1 + y2) / 2.0 + Math.sin(psi) * cxp + Math.cos(psi) * cyp;

        var vMag = function(v) {
            return Math.sqrt(v[0] * v[0] + v[1] * v[1]);
        };
        var vRatio = function(u, v) {
            return (u[0] * v[0] + u[1] * v[1]) / (vMag(u) * vMag(v));
        };
        var vAngle = function(u, v) {
            return (u[0] * v[1] < u[1] * v[0] ? -1 : 1) * Math.acos(vRatio(u, v));
        };
        var theta = vAngle([1, 0], [(xp - cxp) / rx, (yp - cyp) / ry]);
        var u = [(xp - cxp) / rx, (yp - cyp) / ry];
        var v = [(-1 * xp - cxp) / rx, (-1 * yp - cyp) / ry];
        var dTheta = vAngle(u, v);

        if (vRatio(u, v) <= -1) {
            dTheta = Math.PI;
        }
        if (vRatio(u, v) >= 1) {
            dTheta = 0;
        }
        if (fs === 0 && dTheta > 0) {
            dTheta = dTheta - 2 * Math.PI;
        }
        if (fs === 1 && dTheta < 0) {
            dTheta = dTheta + 2 * Math.PI;
        }
        return [cx, cy, rx, ry, theta, dTheta, psi, fs];
    };

    var ua = navigator.userAgent.toLowerCase();
    var s;
    (s = ua.match(/msie ([\d.]+)/)) ? $.ie = s[1] : ( s = ua.match(/firefox\/([\d.]+)/)) ? $.firefox = s[1] : ( s = ua.match(/chrome\/([\d.]+)/)) ? $.chrome = s[1] : ( s = ua.match(/opera.([\d.]+)/)) ? $.opera = s[1] : ( s = ua.match(/version\/([\d.]+).*safari/)) ? $.safari = s[1] : 0;

    //检测ie11以上版本需要特别处理
    (s = ua.match(/trident\/.*rv:([\d.]+)/)) ? $.ie = s[1] : 0;

    (s = ua.match(/mac os x (\d+)[\._](\d+)/)) ? ($.macOS = s[1]+"."+s[2]) : $.winOS = true;
    (s = ua.match(/ipad;.+version\/(\d+\.\d+)/)) ? ($.iPad = s[1]) : 0;
    (s = ua.match(/android/)) ? ($.android = true) : 0;

    //检测是否是触屏。对于ie浏览器目前是单独的判断。
//    var has_tstart = ('ontouchstart' in window);
//    if(has_tstart || window.navigator.msMaxTouchPoints) {
//        $.touchable = true;
//    } else {
//        $.touchable = false;
//    }
    var has_tstart = false;
    $.touchable = false;


    var _ms = window.navigator.msPointerEnabled;


    $.touchEventType = {
        'start' : _ms ? ($.ie ==='10.0' ? 'MSPointerDown'  : 'pointerdown'): (has_tstart ? 'touchstart' : 'mousedown'),
        'move' : _ms ? ($.ie ==='10.0' ? 'MSPointerMove'  : 'pointermove') : (has_tstart ? 'touchmove' : 'mousemove'),
        'end' : _ms ? ($.ie === '10.0' ? 'MSPointerUp' : 'pointerup') : (has_tstart ? 'touchend' : 'mouseup')
    };

    $.extend = function(src, ext) {
        for(var f in ext) {
            if(src[f] == null)
                src[f] = ext[f];
            else {
                console.trace();
                $.log(f)
                throw "extend error!"
            }
        }
    };
    var CURSOR_CROSS_IMG = new Image();
    CURSOR_CROSS_IMG.src = 'images/cross.png';

    $.extend($, {
        parseSVGPath : function(data) {
            return pathParser.parsePathData(data);
        },
        __debug__ : true,
        log : function(format, arg1, arg2) {
            if(this.__debug__)
                jQuery.log.apply(this, arguments);
        },
        __IMAGE_CANVAS__ : null,
        __IMAGE_CTX__ : null,
        _getHelperImageCanvas : function() {
            if(this.__IMAGE_CANVAS__ === null) {
                this.__IMAGE_CANVAS__ = document.createElement("canvas");
                this.__IMAGE_CTX__ = this.__IMAGE_CANVAS__.getContext("2d");
            }
            return this.__IMAGE_CANVAS__;
        },
        getListCursor : function(val) {
            $._getHelperImageCanvas();
            var cvs = this.__IMAGE_CANVAS__, ctx = this.__IMAGE_CTX__;

            cvs.width = cvs.height = 32;
            ctx.drawImage(CURSOR_CROSS_IMG, 0, 18);


            ctx.font = "bold 14px Arial";
            ctx.fillStyle = "#39abed";
            ctx.strokeStyle = "white";
            ctx.textAlign = "center";
            ctx.textBaseline = "middle";

            ctx.save();
            ctx.lineWidth = 2;
            ctx.shadowBlur = 4;
            ctx.shadowColor = "rgba(0,0,0,0.3)";
            ctx.shadowOffsetX = 1;
            ctx.shadowOffsetY = 2;
            ctx.strokeText(val, 20, 10);
            ctx.restore();
            ctx.fillText(val, 20, 10);

            var url =  cvs.toDataURL();
            return 'url("'+url+'") 6 25, auto';
        },
        image2url : function(image) {
            $._getHelperImageCanvas();
            var cvs = this.__IMAGE_CANVAS__, ctx = this.__IMAGE_CTX__;
            cvs.width = image.naturalWidth;
            cvs.height = image.naturalHeight;
            ctx.drawImage(image, 0, 0);
            var rtn = cvs.toDataURL();
            cvs.width = cvs.height = 0;//clear data
            return rtn;
        },
        canvas2image : function(canvas, left, top, width, height, callback) {
            $._getHelperImageCanvas();
            var _c_ = canvas;
            if(typeof left === "number") {
                this.__IMAGE_CANVAS__.width = width;
                this.__IMAGE_CANVAS__.height = height;
                this.__IMAGE_CTX__.drawImage(canvas,left, top, width, height, 0, 0, width, height);
                _c_ = this.__IMAGE_CANVAS__;
            } else if(typeof left === 'function') {
                callback = left;
            }
            var img = new Image();
            if(typeof callback === 'function') {
                img.onload = function() {
                    callback();
                };
            }
            img.src = _c_.toDataURL();
            return img;
        },
        image2scale : function(image, scale, callback) {
            var cvs = $._getHelperImageCanvas(), ctx = this.__IMAGE_CTX__;
            var w = image.width, h = image.height, nw = Math.floor(w * scale), nh = Math.floor(h * scale);
            cvs.width = nw;
            cvs.height = nh;
            ctx.drawImage(image, 0, 0, nw, nh);
            var img = new Image();
            if(typeof callback === 'function') {
                img.onload = callback;
            }
            img.src = cvs.toDataURL();
            return img;
        },
        genPoints : function(num) {
            var rtn = [];
            for(var i=0;i<num;i++) {
                rtn.push({x : 0, y: 0});
            }
            return rtn;
        },
        _getEventPoint : function(e) {
            var x= 0,y=0;
            if ( typeof e.pageX !== 'undefined') {
                x = e.pageX;
                y = e.pageY;
            } else if(typeof e.clientX !== 'undefined') {
                x = e.clientX;
                y = e.clientY;
            } else {
                throw "no x,y in event(_getEventPoint)";
            }
            return {
                x : x,
                y : y
            };
        },
        getDomPosition : function(ele) {
            var left = 0, top = 0;

            while(ele != null) {
                left += ele.offsetLeft;
                top += ele.offsetTop;
                ele = ele.offsetParent;
            }
            return {
                left : left,
                top : top
            };
        },
        addEvent : function(ele, event, handler) {
            if( typeof ele === 'string')
                ele = $(ele);
            if(window.addEventListener) {
                ele.addEventListener(event, handler);
            } else {
                ele.attachEvent('on' + event, handler);
            }
//            $.log("add e:" + event);
        },
        delEvent : function(ele, event, handler) {
            if( typeof ele === 'string')
                ele = $(ele);
            if(window.removeEventListener) {
                ele.removeEventListener(event, handler);
            } else {
                ele.detachEvent('on' + event, handler);
            }
        },

        addGesture : function(ele, touch_start_handler, start_handler, pinch_handler, drag_handler, touch_end_handler) {
            if(typeof ele === 'string') {
                ele = document.getElementById(ele);
            }
            if(typeof touch_end_handler !== 'function') {
                touch_end_handler = function() {}
            }
            var is_pinching = false, is_draging = false;
            var pre_data = {
                scale : 0,
                x : 0,
                y : 0
            };
            var ie_scale = 1.0, s_b;
            var start_ges = function() {
                start_handler();
            };
            var deal_ges = function(scale, deltaX, deltaY) {
                var status = 0;
                if(!is_draging && !is_pinching) {
                    s_b = scale / pre_data.scale;
                    if(s_b < 0.97 | s_b > 1.03) {
                        is_pinching = true;
                    } else if(Math.abs(deltaX)>8 || Math.abs(deltaY)>8) {
                        is_draging = true;
                    }
                }

                if(is_pinching) {
                    s_b = scale / pre_data.scale;
                    if(s_b < 0.88 | s_b > 1.12) {
                        pinch_handler(scale);
                        status = 1;
                    }
                } else if(is_draging) {
                    if(Math.abs(deltaX)>10 || Math.abs(deltaY)>10) {
                        drag_handler(deltaX, deltaY);
                        status = 2;
                    }
                }
                return status;
            };
            var end_ges = function(ev) {
                is_pinching = false;
                is_draging = false;
                pre_data.x = 0;
                pre_data.y = 0;
                $.stopEvent(ev);

            };
            var ie_data = {
                ie_timeout : null,
                ie_event : null
            };
            var ie_timeout_handler = function() {
                ie_data.ie_timeout = null;
                touch_start_handler(ie_data.ie_event);
            };

            if($.ie) {
                var myGesture = new MSGesture(), myPointers = [];

                myGesture.target = ele;
                $.addEvent(ele, "MSGestureStart", function(ev) {
//                    $.log('start');
                    ie_scale = ev.scale;
                    pre_data.scale = ev.scale;
                    pre_data.x = ev.translationX;
                    pre_data.y = ev.translationY;
                    start_ges();
                    $.stopEvent(ev);
                })
                $.addEvent(ele, "MSGestureChange", function(ev) {
//                    $.log('change: ' + ev.scale);
//                    print_evt(ev);

                    pre_data.x += ev.translationX;
                    pre_data.y += ev.translationY;
                    ie_scale *= ev.scale;
//                    $.log("change: " + pre_data.scale);
                    var ges_status = deal_ges(ie_scale, pre_data.x, pre_data.y);
                    if(ges_status === 1) {
                        pre_data.scale = ie_scale;
                    } else if(ges_status === 2) {
                        pre_data.x = 0;
                        pre_data.y = 0;
                    }
                    $.stopEvent(ev);

                });

                $.addEvent(ele, "MSGestureEnd", end_ges);

                $.addEvent(ele, $.touchEventType.start, function(ev) {
                    var pi = myPointers.indexOf(ev.pointerId);
                    if(pi>=0) {
                        //pointer已经存在。这几乎是不可能的。因为系统每次pointerdown时生成的pointerId肯定不一样。
                        return;
                    }
                    if(myPointers.length === 0) {
                        myPointers.push(ev.pointerId);
                        ie_data.ie_event = ev;
                        ie_data.ie_timeout = window.setTimeout(ie_timeout_handler, 80);
                    } else if(myPointers.length === 1) {
                        if(ie_data.ie_timeout !== null) {
                            window.clearTimeout(ie_data.ie_timeout);
                            ie_data.ie_timeout = null;
                        }
                        myPointers.push(ev.pointerId);

                        for(pi = 0;pi<myPointers.length;pi++ ) {
                            myGesture.addPointer(myPointers[pi]);
                        }
                    }

                });
                $.addEvent(ele, $.touchEventType.end, function(ev) {
                    if(myPointers.length === 1) {
                        if(ie_data.ie_timeout !== null) {
                            window.clearTimeout(ie_data.ie_timeout);
                            ie_data.ie_timeout = null;
                            touch_start_handler(ie_data.ie_event);
                        }
                        touch_end_handler(ev);
                    }
                    myPointers.length = 0;
                });

            } else {
                var is_ges = false;
                $.addEvent(ele, $.touchEventType.start, function(ev) {
                    if(ev.touches.length === 1) {
                        is_ges = false;
                        touch_start_handler(ev);
                    }
                });
                $.addEvent(ele, "gesturestart", function(ev) {
                    is_ges = true;
                    pre_data.scale = ev.scale;
                    pre_data.x = ev.pageX;
                    pre_data.y = ev.pageY;
                    start_ges();
                    $.stopEvent(ev);
                });
                $.addEvent(ele, "gesturechange", function(ev) {
                    var ges_status = deal_ges(ev.scale, ev.pageX - pre_data.x, ev.pageY - pre_data.y);
                    if(ges_status === 1) {
                        pre_data.scale = ev.scale;
                    } else if(ges_status === 2) {
                        pre_data.x = ev.pageX;
                        pre_data.y = ev.pageY;
                    }
                    $.stopEvent(ev);

                });
                $.addEvent(ele, "gestureend", end_ges);
                $.addEvent(ele, $.touchEventType.end, function(ev) {
                   if(is_ges === false) {
                       touch_end_handler(ev);
                   }
                });
            }
        },
        addMouseEvent : function(ele, event, handler) {
            var rtn = {};
            if($.touchable && (['mousedown','mousemove','mouseup'].indexOf(event)>=0)) {
                var event_touch = event === 'mousedown' ? $.touchEventType.start : (event === 'mousemove' ? $.touchEventType.move : $.touchEventType.end);

                var _f_touch = function(e) {

                    if((e.touches && e.touches.length > 1) ||(e.changedTouches && e.changedTouches.length > 1)) {
                        //多点触屏不处理。
                        return;
                    }

                    handler.apply(this, arguments);
                };

                $.addEvent(ele, event_touch, _f_touch);

                rtn[event_touch] = _f_touch;
            } else {
                $.addEvent(ele, event, handler);
                rtn[event] = handler;
            }
            return rtn;
        },
        delMouseEvent : function(ele, event) {
            for(var e in event) {
                $.delEvent(ele, e, event[e]);
            }
        },
        createDelegate : function(instance, func) {
            return function() {
                func.apply(instance, arguments);
            }
        },
        stopEvent : function(e) {
//            $.log('stop');
            if(e == null)
                return;
            if(e.preventDefault) {
                e.preventDefault();
            } else {
                e.returnValue = false;
            }
            if(e.stopPropagation) {
                e.stopPropagation();
            } else {
                e.cancelBubble = true;
            }
            //for ie 10+
            if (e.preventManipulation) {
                e.preventManipulation();
            }
        },
        addWheelEvent : function(ele, handler) {

            if( typeof ele === 'string')
                ele = $(ele);
            if(window.addEventListener) {
                if($.firefox)
                    ele.addEventListener('DOMMouseScroll', handler);
                else
                    ele.addEventListener('mousewheel', handler);
            } else {
                ele.attachEvent('onmousewheel', handler);
            }
        },
        /**
         * js 面向对象。
         *
         */
        inherit : function(inheritClass, baseClass) {
            if(typeof inheritClass === 'undefined' || typeof baseClass ==='undefined'){
                console.trace();
                throw "inherit error!";
            }
            //首先把父类的prototype中的函数继承到子类中
            for(var pFunc in baseClass.prototype) {
                var sp = inheritClass.prototype[pFunc];
                //如果子类中没有这个函数，添加
                if( typeof sp === 'undefined') {
                    inheritClass.prototype[pFunc] = baseClass.prototype[pFunc];
                }
                //如果子类已经有这个函数，则忽略。以后可使用下面的callBase函数调用父类的方法

            }
            //保存继承树，当有多级继承时要借住继承树对父类进行访问
            inheritClass.__base_objects__ = new Array();
            inheritClass.__base_objects__.push(baseClass);

            if( typeof baseClass.__base_objects__ !== 'undefined') {
                for(var i = 0; i < baseClass.__base_objects__.length; i++)
                    inheritClass.__base_objects__.push(baseClass.__base_objects__[i]);
            }

            /**
             * 执行父类构造函数，相当于java中的this.super()
             * 不使用super是因为super是ECMAScript保留关键字.
             * @param {arguments} args 参数，可以不提供
             */
            inheritClass.prototype.base = function(args) {

                var baseClass = null, rtn = undefined;
                if( typeof this.__inherit_base_deep__ === 'undefined') {
                    this.__inherit_base_deep__ = 0;
                } else {
                    this.__inherit_base_deep__++;
                    //$.dprint("d+:"+this.__inherit_deep__);
                }

                baseClass = inheritClass.__base_objects__[this.__inherit_base_deep__];

                if( typeof args === "undefined" || args == null) {
                    rtn = baseClass.call(this);
                } else if( args instanceof Array === true) {
                    rtn = baseClass.apply(this, args);
                } else {
//					var _args = new Array();
//					for(var i = 0; i < arguments.length; i++)
//						_args.push(arguments[i]);
//					rtn = baseClass.apply(this, _args);
                    // arguments 是Object而不是Array，需要转换。
                    rtn = baseClass.apply(this, [].slice.call(arguments));
                }

                this.__inherit_base_deep__--;

                //$.dprint("d-:"+this.__inherit_deep__);
                return rtn;
            };
            /**
             * 给继承的子类添加调用父函数的方法
             * @param {string} method 父类的函数的名称
             * @param {arguments} args 参数，可以不提供
             */
            inheritClass.prototype.callBase = function(method, args) {

                var baseClass = null, rtn = undefined;

                if( typeof this.__inherit_deep__ === 'undefined') {
                    this.__inherit_deep__ = 0;

                } else {
                    this.__inherit_deep__++;
                    //$.dprint("d+:"+this.__inherit_deep__);
                }

                //$.dprint(this.__inherit_deep__);
                baseClass = inheritClass.__base_objects__[this.__inherit_deep__];

                var med = baseClass.prototype[method];
                if( typeof med === 'function') {
                    if( typeof args === "undefined" || args === null) {
                        rtn = med.call(this);
                    } else if( args instanceof Array === true) {
                        rtn = med.apply(this, args);
                    } else {

                        rtn = med.apply(this, [].slice.call(arguments, 1));
                    }
                } else {
                    throw "There is no method:" + method + " in baseClass";
                }

                this.__inherit_deep__--;

                //$.dprint("d-:"+this.__inherit_deep__);
                //$.dprint("----");
                return rtn;
            }
        },
        __FONT_INFO_TABLE__ : {},
        getFontInfo : function(font) {
            var h = this.__FONT_INFO_TABLE__[font];
            if(h == null) {
                h = this.__FONT_INFO_TABLE__[font] = this._calcFontInfo(font);
            }
            return h;
        },
        /*
         * 计算font_size大小的字号，font_name名称的字体的信息
         *  height : 当前字体的高度
         * baseline: 当前字体的baseline线距离底部的距离
         * 实现的原理是使用浏览器对dom元素的渲染结果，当span的font-size为0时其位置正好处于baseline的地方。
         */
        _calcFontInfo : function(font) {
            var con = document.createElement("div"), ele = document.createElement("span"), ele2 = document.createElement("span");
            con.style.margin = "0px";
            con.style.padding = "0px";
            con.style.position = "relative";
            con.style.left = '0px';
            con.style.top = '0px';
            con.style.overflow = "hidden";
            con.style.whiteSpace = "nowrap";
            con.style.visibility = "hidden";

            ele.style.font = font;
            ele.style.margin = "0px";
            ele.style.padding = "0px";
            ele.style.verticalAlign = "baseline";
            ele.style.whiteSpace = "nowrap";

            ele2.style.font = font.replace(/\d+px/, '0px');
            ele2.style.margin = "0px";
            ele2.style.padding = "0px";
            ele2.style.verticalAlign = "baseline";
            ele.style.whiteSpace = "nowrap";

            var test_string = "@白羊座小葛 04-02.I Love Diigo.南京大学";
            ele.innerText = test_string;
            ele2.innerText = test_string;
            con.appendChild(ele2);
            con.appendChild(ele);
            document.body.appendChild(con);
            var h = con.offsetHeight;
            var bo = ele.offsetHeight + ele.offsetTop - ele2.offsetTop;
            document.body.removeChild(con);
//            $.log("font %s height:%d", font, h);
//        $.log("%s,%s",h,bo)
            return {
                height : h,
                baseline : ele2.offsetTop,
                baseline_offset : bo
            };
        },
        getMiddlePoint : function(p1, p2) {
            return {
                x : (p1.x + p2.x) / 2,
                y : (p1.y + p2.y) / 2
            }
        },

        drawBesier : function(ctx, points) {
            var len = points.length;
            if(len === 0)
                return;
            else if(len === 1) {
                //to do
                return;
            }

            ctx.beginPath();

            var dest = null;
            var ctrl = points[0];
            ctx.moveTo(ctrl.x, ctrl.y);
            for(var i = 0; i < len - 1; i++) {
                dest = $.getMiddlePoint(points[i], points[i + 1]);
                ctx.quadraticCurveTo(ctrl.x, ctrl.y, dest.x, dest.y);
                ctrl = points[i + 1];
            }
            dest = points[len - 1];
            ctx.quadraticCurveTo(ctrl.x, ctrl.y, dest.x, dest.y);
            ctx.stroke();
            ctx.closePath();
        },
        drawLine : function(ctx, x1, y1, x2, y2) {
            ctx.beginPath();
            ctx.moveTo(x1, y1);
            ctx.lineTo(x2, y2);
            ctx.stroke();
            ctx.closePath();
        },
        drawLine_w : function(ctx, x, y, w, h) {
            $.drawLine(ctx, x, y, x+w, y+h);
        },
        drawEllipse : function(ctx, x, y, a, b, fill_color) {
//            var k = .5522848,
//                ox = a * k, // 水平控制点偏移量
//                oy = b * k; // 垂直控制点偏移量
//
            ctx.beginPath();
            ctx.ellipse(x, y, a, b, 0, 0, Math.PI * 2, 0);
            ctx.closePath();
            if(fill_color !== null) {
                ctx.fillStyle = fill_color;
                ctx.fill();
            }
            ctx.stroke();

        },
        calcArrow : function(x1, y1, x2, y2, aLen) {
            // 计算
            function rotateVec(px, py, ang, isChLen, newLen)   {
                var mathstr = [0.0, 0.0];
                // 矢量旋转函数，参数含义分别是x分量、y分量、旋转角、是否改变长度、新长度
                var vx = px * Math.cos(ang) - py * Math.sin(ang);
                var vy = px * Math.sin(ang) + py * Math.cos(ang);
                if (isChLen) {
                    var d = Math.sqrt(vx * vx + vy * vy);
                    vx = vx / d * newLen;
                    vy = vy / d * newLen;
                    mathstr[0] = vx;
                    mathstr[1] = vy;
                }
                return mathstr;
            }

            var dist = $.getPTPRange_xy(x1, y1, x2, y2);
            var H = aLen;

            var L = H * 0.42,
                awrad = Math.atan(L / H), // 箭头角度
                arraow_len = Math.sqrt(L * L + H * H); // 箭头的长度


            var arrXY_1  =  rotateVec(x2  -  x1, y2  -  y1, awrad,  true , arraow_len);
            var arrXY_2  =  rotateVec(x2  -  x1, y2  -  y1,  - awrad,  true , arraow_len);
            var x3  = Math.floor(x2  -  arrXY_1[0]);  // (x3,y3)是第一端点
            var y3  = Math.floor(y2  -  arrXY_1[1]);
            var x4  = Math.floor(x2  -  arrXY_2[0]); // (x4,y4)是第二端点
            var y4  = Math.floor(y2  -  arrXY_2[1]);


            var r = H / dist,
                x5 = Math.floor(x2 - (x2 - x1) * r);
                y5 = Math.floor(y2 - (y2 - y1) * r);

            return {
                ax : x3,
                ay : y3,
                bx : x4,
                by : y4,
                cx : x5,
                cy : y5,
                dx : x2,
                dy : y2
            }
        },
        drawArrow : function(ctx, x1, y1, x2, y2)  {
            var r = $.calcArrow(x1, y1, x2, y2);

            $.drawLine(ctx, x2, y2, r.ax, r.ay);
            // 画箭头的另一半
            $.drawLine(ctx, x2, y2, r.bx, r.by);
        },
        clearContext : function(ctx) {
            ctx.clearRect(ctx.canvas.width, ctx.canvas.height);
        },
        copyArray : function(arr) {
            var n_a = [];
            for(var i = 0; i < arr.length; i++) {
                n_a.push(arr[i]);
            }
            return n_a;
        },
        setArray : function(m1, m2) {
            for(var i=0;i<m1.length;i++) {
                m1[i] = m2[i];
            }
        },
        /**
         * 拷贝点阵
         * @param ps points to be copied
         * @returns {Array}
         */
        copyPoints : function(ps) {
            /**
             * 拷贝笔画中的点阵。
             * 当前的版本点阵有两种情况，带p值和不带p值的。需要分别判断。
             * 带p值的包括PenInk和ChineseBrush数据。（参看数据格式文档）
             */
            var c_ps = [];
            if(ps.length === 0) {
                return c_ps;
            }
            var _h = typeof ps[0].p !== 'undefined';
            for(var i = 0; i < ps.length; i++) {
                var n_p = {
                    x : ps[i].x,
                    y : ps[i].y
                };
                if(_h) {
                    n_p.p = ps[i].p;
                }
                c_ps.push(n_p);
            }
            return c_ps;
        },
        /**
         * 复制点阵，将a1点阵中的数据设置为和a2中一样
         * @param a1 dest points array
         * @param a2 source points array
         */
        setPoints : function(a1,a2) {
            /**
             * 将a1点阵中的数据设置为和a2中一样。
             * 当前的版本点阵有两种情况，带p值和不带p值的。需要分别判断。
             * 带p值的包括PenInk和ChineseBrush数据。（参看数据格式文档）
             */
            if(a1.length === 0 || a1.length !== a2.length){
                return;
            }
            for(var i=0;i<a1.length;i++) {
                a1[i].x = a2[i].x;
                a1[i].y = a2[i].y;
            }
        },

        /**
         * 计算两点距离(Point To Point)
         */
        getPTPRange : function(point1, point2) {
            return Math.sqrt(Math.pow(point1.x - point2.x, 2) + Math.pow(point1.y - point2.y, 2));
        },
        getPTPRange_xy : function(x1, y1, x2, y2) {
            return Math.sqrt(Math.pow(x1 - x2, 2) + Math.pow(y1 - y2, 2));
        },

        color2int : function(data) {
            return (data[0] << 16) | (data[1] << 8) | data[2];
        },
        int2color : function(i) {
            var r = (i & 0xff0000).toString(16), g = (i & 0x00ff00).toString(16), b = (i & 0x0000ff).toString(16);
            var c = "#" + (r.length === 1 ? "0" : "") + r +(g.length===1?"0":"") + g + (b.length===1?"0":"") + b;
            return c;
        },
        rgba2str : function(r,g,b,a) {
            if(typeof a !== 'undefined') {
                return "rgba("+r+","+g+","+b+","+a+")";
            } else {
                return '#' + (r<10 ? '0' : '') + r.toString(16).toUpperCase() +  (g<10 ? '0' : '') + g.toString(16).toUpperCase() +  (b<10 ? '0' : '') + b.toString(16).toUpperCase();
            }
        },
        str2rgba : function(clr_str) {
            var r = 0, g = 0, b = 0, a = 1.0, m;
            if(/^#[0-9a-f]{3}$/i.test(clr_str)) {
                r = parseInt(clr_str.substr(1,1) + clr_str.substr(1,1), 16);
                g = parseInt(clr_str.substr(2,1) + clr_str.substr(2,1), 16);
                b = parseInt(clr_str.substr(3,1) + clr_str.substr(3,1), 16);
                a = 1.0;
            } else if(/^#[0-9a-f]{6}$/i.test(clr_str)) {
                r = parseInt(clr_str.substr(1,2), 16);
                g = parseInt(clr_str.substr(3,2), 16);
                b = parseInt(clr_str.substr(5,2), 16);
                a = 1.0;
            } else if( (m=clr_str.match(/^rgb\(\s*(\d+)\s*,\s*(\d+)\s*,\s*(\d+)\s*\)$/i))!=null) {
                r = parseInt(m[1]);
                g = parseInt(m[2]);
                b = parseInt(m[3]);
                a = 1.0;
            } if( (m=clr_str.match(/^rgba\(\s*(\d+)\s*,\s*(\d+)\s*,\s*(\d+)\s*,\s*(\d(\.\d+)?)\s*\)$/i))!=null) {
                r = parseInt(m[1]);
                g = parseInt(m[2]);
                b = parseInt(m[3]);
                a = parseFloat(m[4]);
            } else {
                //todo 查表查询。比如像"blank","red","blue"这样的值
            }
            return {
                r : r,
                g : g,
                b : b,
                a : a
            };
        },
        is_color_blank : function(clr) {
            return clr === '#000000'
                || clr === '#000'
                || clr === 'blank'
                || /^rgba\(\s*0\s*,\s*0\s*,\s*0\s*,\s*0\s*\)$/i.test(clr)
                || /^rgb\(\s*0\s*,\s*0\s*,\s*0\s*\)$/i.test(clr);
        },

        setLineDash : function(ctx, dash) {
            if(typeof ctx.setLineDash !== 'undefined') {
                ctx.setLineDash(dash);
            } else if(typeof ctx.mozDash !== 'undefined') {
                ctx.mozDash = dash;
            }
        },
        getCanvasBlob : function(canvas) {
            if(canvas.toBlob) {
                return canvas.toBlob();
            } else {
                var dataURL = canvas.toDataURL( "image/png" );
                var data = atob( dataURL.substring( "data:image/png;base64,".length ) ),
                    asArray = new Uint8Array(data.length);
                for( var i = 0, len = data.length; i < len; ++i ) {
                    asArray[i] = data.charCodeAt(i);
                }
                return new Blob( [ asArray.buffer ], {type: "image/png"} );
            }
        },
        dataUrl2Blob: function(dataURL) {
            var data = atob( dataURL.substring( "data:image/png;base64,".length ) ),
                asArray = new Uint8Array(data.length);
            for( var i = 0, len = data.length; i < len; ++i ) {
                asArray[i] = data.charCodeAt(i);
            }
            return new Blob( [ asArray.buffer ], {type: "image/png"} );
        }

    });

})(Diigo.$);

(function($) {

    $.fn.extend({
        addMouseEvent : function(type, element, handler) {
            var _h = typeof element === 'function' ? element
                : (typeof handler==='function' ? handler : function() {
                //do nothing
            });
            var pre_timestamp = 0;

            var _f_touch = function(ev) {
//                $.log('t')
                e = ev.originalEvent;
                if((e.touches && e.touches.length > 1) ||(e.changedTouches && e.changedTouches.length > 1)) {
                    //多点触屏不处理。
                    return;
                }
                _h.apply(this, arguments);
            };
            var _f2 = function(e) {
//                $.log('d')
                if(pre_timestamp > 0 && e.timeStamp - pre_timestamp > 800) {
//                    $.log("skip md");
                    return;
                }
                _h.apply(this, arguments);
            };
            var type_touch = type === 'mousedown' ? Diigo.$.touchEventType.start : (type === 'mousemove' ? Diigo.$.touchEventType.move : Diigo.$.touchEventType.end);
            if(Diigo.$.touchable && (['mousedown','mousemove','mouseup'].indexOf(type)>=0)) {
                if(typeof element === "function") {
                    this.on(type_touch, _f_touch);
//                    this.on(type,  _f2);
//                    this.on(type_touch, element);
                } else {
                    this.on(type_touch, element, _f_touch);
                    this.on(type, element, _f2);
//                    this.on(type_touch, element, handler);
                }

            } else {
                if(typeof element === "function") {
                    this.on(type, element);
                } else {
                    this.on(type, element, handler);
                }
            }
            return this;
        },

        addMouseDownEvent : function(element, handler) {
            return this.addMouseEvent("mousedown", element, handler);
        },
        addMouseMoveEvent : function(element, handler) {
            return this.addMouseEvent("mousemove", element, handler);
        },
        addMouseUpEvent : function(element, handler) {
            return this.addMouseEvent("mouseup", element, handler);
        },
        addMouseTagEvent : function(element, handler) {
            var _b = true,  ts_n = Diigo.$.touchEventType.start, te_n = Diigo.$.touchEventType.end;
            if(typeof element === 'function') {
                handler = element;
                _b = false;
            }

            var pre = {
                x : 0,
                y : 0
            };
            var _ts = function(e) {
//                $.log(e);
                e = e.originalEvent || e;
                if(e.touches && e.touches.length>0) {
                    pre.x = e.touches[0].pageX;
                    pre.y = e.touches[0].pageY;
                } else {
                    pre.x = e.pageX;
                    pre.y = e.pageY;
                }
            };
            var _te = function(e) {
                e = e.originalEvent || e;
                var x, y;
                if(e.changedTouches && e.changedTouches.length>0) {
                    x = e.changedTouches[0].pageX;
                    y = e.changedTouches[0].pageY;
                } else {
                    x = e.pageX;
                    y = e.pageY;
                }
                if(Math.sqrt(Math.pow(pre.x - x, 2) + Math.pow(pre.y - y, 2)<20)) {
                    handler.apply(this, arguments);
                }
            };
            if(Diigo.$.touchable) {
                if(_b) {
                    this.on(ts_n, element, _ts);
                    this.on(te_n, element, _te);
                } else {
                    this.on(ts_n, _ts);
                    this.on(te_n, _te);
                }
            } else {
                if(_b) {
                    this.on("mousedown", element, handler);
                } else {
                    this.on("mousedown", handler);
                }
            }

            return this;
        }


    });

    $.stopEvent = function(e) {
        if(typeof e === 'undefined') {
            return;
        }
        e.preventDefault();
        e.stopPropagation();
    }
})(jQuery);

(function(Text, Doodle, UR, $) {
	Doodle._Drawer = function(parent, callback) {
		this.parent = parent;
        this.container = parent.container;
        this.out_container = parent.out_container;
		this.edit_canvas = parent.layer_canvas;
		this.doodle_canvas = parent.doodle_canvas;
        this.textarea = parent.textarea;
        this.textarea_out = parent.textarea_out;

        this.$list_dialog = parent.$list_dialog; //带$开头表示是jQuery包装的dom元素，可以直接使用。
        this.$list_input = this.$list_dialog.find("input");

        this.choose_canvas = document.createElement("canvas");
        this.temp_canvas = document.createElement("canvas");
        this.image_canvas = document.createElement("canvas");
        this.blur_canvas = document.createElement("canvas");

        this.i_ctx = this.image_canvas.getContext('2d');
		this.d_ctx = this.doodle_canvas.getContext('2d');
		this.e_ctx = this.edit_canvas.getContext('2d');
        this.c_ctx = this.choose_canvas.getContext("2d");
        this.t_ctx = this.temp_canvas.getContext("2d");
        this.b_ctx = this.blur_canvas.getContext('2d');

        this.out_pos = null;

        this.style = {
            brush_type : Doodle.Type.CURVE,
            pen_width : 4,
            pen_opacity : 1.0,
            pen_color : '#000',
            dot_type : Doodle.LineType.NORMAL,
            arrow_type : Doodle.LineType.NORMAL,
            color : 'rgba(0,0,0,1.0)',
            text_color : '#000000',
            font_size : 20,
            font_name : 'Times New Roman',
            svg_image : new Image()
        };

        this.cur_textbox = null;
		this.history = new UR._UndoRedoManager(this);

        //drawer只需要一个合并的scale
        this.zoom_scale = 1.0;

		this.page = {
            doodle_array : []
        };

		this.edit_doodle = new Doodle._EditDoodle(this);
        this.temp_doodle = null;

        this.has_selected_doodle = false;
        this.default_cursor = "url(images/pencil.png),auto";

        this.image_canvas.width = parent.image.naturalWidth;
        this.image_canvas.height = parent.image.naturalHeight;
        this.i_ctx.drawImage(parent.image, 0, 0);

        this.bg_info = {
            saved_origin : null,
            origin_image : null,
            image : this.image_canvas,
            x : 0,
            y : 0,
            width : parent.image.naturalWidth,
            height : parent.image.naturalHeight
        };// parent.image;


        this.__pre_mouse_enter_region__ = null;
        this.__region_visible__ = true;

        this.cut_mode = false;
        this.cut_doodle = null;
        this.__cut_undo_command__ = null;
        this.__tmp_undo_command__ = null;

        this.style_callback = callback;

        this.initEvent();
        this.textbox_editor = new Diigo.Text._Editor(this);

        this.pre_cursor_name = '';
        this.cursor_type = 1;
        this.d_changed = false;
	};
	Doodle._Drawer.prototype = {

        onChange : function() {

        },
        setCursor : function(cursor) {
            jQuery(this.edit_canvas).removeClass(this.pre_cursor_name);
            this.edit_canvas.style.cursor = cursor;
            this.pre_cursor_name = '';
        },
        setCursor_name : function(cursor_name) {
            this.edit_canvas.style.cursor = '';
            jQuery(this.edit_canvas).removeClass(this.pre_cursor_name).addClass(cursor_name);
            this.pre_cursor_name = cursor_name;
        },

		blur : function(){
            if(this.focused) {
                $.log("d blur");
                this.focused = false;
            }
		},
		focus : function(){
            if(!this.focused) {
                $.log("d focus");
                //触屏设备不应该让虚拟键盘出现。
                //todo 但是对于同时有触屏和键盘的设备还需要进一步处理
                if(!$.touchable) {
                    this.caret.focus();
                }
                this.focused = true;
            }
            if(this.cur_textbox!==null && this.cur_textbox.actived) {
                this.cur_textbox.editor.focus();
            }
		},
        isEdited : function() {
            var bi = this.bg_info, dl = this.page.doodle_array.length;
            return dl>0
                || bi.width !== bi.origin_image.naturalWidth
                || bi.height !== bi.origin_image.naturalHeight
                || bi.x !== 0
                || bi.y !== 0
                || bi.width !== bi.image.width
                || bi.height !== bi.image.height
        },
        isChanged : function() {
            return this.isEdited() || this.d_changed;
        },
        setBgInfo: function(image, auto_fit_screen) {
            this.bg_info.origin_image = image;
            this.bg_info.saved_origin = null;
            //this.image_canvas.width = image.naturalWidth;
            //this.image_canvas.height = image.naturalHeight;
            this.bg_info.image = this.image_canvas;
            this.bg_info.width = image.naturalWidth;
            this.bg_info.height = image.naturalHeight;
            this.bg_info.x = 0;
            this.bg_info.y = 0;
            this.zoom_scale = 1.0;



            this._clear();
            this._do_resize();
            this.d_changed = false;

            var me = this;
            this.out_container.style.visibility = 'hidden';
            if(auto_fit_screen) {
                window.setTimeout(function() {
                    me._on_resize();
                    me.setFitScale();
                    me.out_container.style.visibility = 'visible';
                    me.paint();
                }, 0);
            } else {
                window.setTimeout(function() {
                    me._on_resize();
                    me.out_container.style.visibility = 'visible';
                    me.paint();
                }, 0);
            }
        },

        setBgImage : function(image, auto_fit_screen) {
            this.bg_info.origin_image = image;
            this.bg_info.saved_origin = null;
            this.image_canvas.width = image.naturalWidth;
            this.image_canvas.height = image.naturalHeight;
            this.i_ctx.drawImage(image, 0, 0);
            this.bg_info.image = this.image_canvas;
            this.bg_info.width = image.naturalWidth;
            this.bg_info.height = image.naturalHeight;
            this.bg_info.x = 0;
            this.bg_info.y = 0;
            this.zoom_scale = 1.0;



            this._clear();
            this._do_resize();
            this.d_changed = false;

            var me = this;
            this.out_container.style.visibility = 'hidden';
            if(auto_fit_screen) {
                window.setTimeout(function() {
                    me._on_resize();
                    me.setFitScale();
                    me.out_container.style.visibility = 'visible';
                    me.paint();
                }, 0);
            } else {
                window.setTimeout(function() {
                    me._on_resize();
                    me.out_container.style.visibility = 'visible';
                    me.paint();
                }, 0);
            }

        },

		resize : function() {
			this.zoom_scale = 1.0;
            this._resize();
            this.paint();

        },
        _do_resize : function() {
            var w =  Math.floor(this.bg_info.width * this.zoom_scale),
                h =  Math.floor(this.bg_info.height * this.zoom_scale);

            this.edit_canvas.width = w;
            this.edit_canvas.height = h;
            this.doodle_canvas.width = w;
            this.doodle_canvas.height = h;
            this.choose_canvas.height = h;
            this.choose_canvas.width = w;
            this.temp_canvas.width = w;
            this.temp_canvas.height = h;
            this.blur_canvas.width = w;
            this.blur_canvas.height = h;

            this.container.style.width = w + 'px';
            this.container.style.height = h + 'px';
            this.out_container.scrollLeft = 0;
            this.out_container.scrollTop = 0;
        },
        _resize : function() {
            this._do_resize();
            this._on_resize();
        },
        _resetDoodleScale : function() {
            var d_arr = this.page.doodle_array;
            for(var i=0;i<d_arr.length;i++) {
                d_arr[i].resetScale();
            }
        },
        setScale : function(scale) {
            this.zoom_scale = scale;
            this._resetDoodleScale();
            this._resize();
            this.paint();
        },
        setFitScale : function() {
            var oc = this.out_container,
                W = oc.offsetWidth,
                H = oc.offsetHeight,
                bi = this.bg_info;
            var sx = W / bi.width,
                sy = H / bi.height;
            if(sx < 1.0 || sy < 1.0) {
                this.setScale(Math.min(sx, sy));
            } else {
                this.setScale(1.0);
            }
        },
        setImageSize : function(w, h) {
            if(this.cur_textbox !== null) {
                this.unactiveTextbox();
            }
            this.hideListDialog();

            this.__tmp_undo_command__ = new UR._SizeCommand(this);

            this._set_image_size_redo(w, h);

            this.__tmp_undo_command__.finish();
            this.history.add(this.__tmp_undo_command__);
            this.__tmp_undo_command__ = null;
        },
        _set_image_size_undo : function(img, vb, ds) {
            var bi = this.bg_info;
            this.zoom_scale = 1.0;

            this.image_canvas.width = img.width;
            this.image_canvas.height = img.height;
            this.i_ctx.drawImage(img, 0, 0);

            bi.x = vb.x;
            bi.y = vb.y;
            bi.width = vb.width;
            bi.height = vb.height;

            this._resize();

            [].push.apply(this.page.doodle_array, ds);
            this.paint();

            this._clear_back();
        },
        _set_image_size_redo : function(w, h) {
            this._select_nothing();

            var save_ctx = this.d_ctx;
            var save_scale = this.zoom_scale;

            var bi = this.bg_info;

            this.zoom_scale = 1.0;
            this.d_ctx = this.b_ctx;
            this.blur_canvas.width = bi.width;
            this.blur_canvas.height = bi.height;
            this._paintDoodleLayer();
            this.d_ctx = save_ctx;
            this.image_canvas.width = w;
            this.image_canvas.height = h;
            this.i_ctx.drawImage(this.blur_canvas, 0, 0, bi.width, bi.height, 0, 0, w, h);

            bi.width = w;
            bi.height = h;
            bi.x = 0;
            bi.y = 0;
            this.zoom_scale = save_scale;
            this._resize();
            this.page.doodle_array.length = 0;

            this._clear_back();

            this.paint();
        },
        _get_image : function(type, format, maxHeight) {
            if(this.cur_textbox !== null) {
                this.unactiveTextbox();
            }
            this._select_nothing();
            var rtn=[];
            var bi = this.bg_info;
            var save_ctx = this.d_ctx;
            var save_scale = this.zoom_scale;
            var sw = this.blur_canvas.width,
                sh = this.blur_canvas.height;

            this.zoom_scale = 1.0;
            this._resetDoodleScale();
            this.d_ctx = this.b_ctx;

            this.blur_canvas.width = bi.width;
            this.blur_canvas.height = bi.height;

            this._paintDoodleLayer();
            if(type === 'url'){
            	if(!maxHeight || sh <= maxHeight){
                	rtn.push(this.blur_canvas.toDataURL(format));
                }else{
                	var hlen=Math.round(sh/maxHeight);
                	var startY=0;
                	var context = this.blur_canvas.getContext("2d"), oCanvas = document.createElement("canvas"), oCtx=oCanvas.getContext("2d");
                	oCanvas.width = sw;
                    oCanvas.height = maxHeight;
                	for(var i=0;i<hlen;i++){
                		startY=i*maxHeight;
                		
                		if(i==hlen-1){
                			var lastHeight=sh-startY;
                			oCanvas.height = lastHeight;
                			var oImgData = context.getImageData(0, startY, sw, lastHeight);
                    		oCtx.putImageData(oImgData, 0, 0);
                    		maxHeight=lastHeight;
                		}else{
                			var oImgData = context.getImageData(0, startY, sw, maxHeight);
                    		oCtx.putImageData(oImgData, 0, 0);
                		}
                		
                		rtn.push(oCanvas.toDataURL(format));
                		oCtx.clearRect(0, 0, sw, maxHeight);
                	}
                }
            	
            }else{
            	rtn.push($.getCanvasBlob(this.blur_canvas));
            }
            this.d_ctx = save_ctx;
            this.zoom_scale = save_scale;
            this._resetDoodleScale();
            this.blur_canvas.width = sw;
            this.blur_canvas.height = sh;

            return rtn;
        },
        getImageDataURL : function(format, maxHeight) {
            return this._get_image('url', format, maxHeight);
        },
        getImageDataBlob : function() {
            return this._get_image('blob');
        },
        _removeDoodle : function(doo) {
            if(this.cur_textbox !== null) {
               this.unactiveTextbox();
               this.textbox_editor.hide();
            }

            var d_arr = this.page.doodle_array,
                idx = d_arr.indexOf(doo);
            d_arr.splice(idx, 1);

            this._select_nothing();
            this._clear_back();
        },
		_insertDoodle : function(doo) {
            this.page.doodle_array.unshift(doo);
            this._clear_back();
		},
        _ur_insert : function(doo) {
            this.page.doodle_array.unshift(doo);
            this._select_doodle(doo);
            this._clear_back();
        },
		insertDoodle : function(doo) {
		    var cmd = new UR._DoodleNewCommand(doo);
			this._insertDoodle(doo);
			this.history.add(cmd);
		},
        unactiveTextbox : function() {
            if(this.cur_textbox!==null && this.cur_textbox.actived) {
                this.cur_textbox.unactive();
                this.cur_textbox = null;
                this._select_nothing();
            }
        },
        activeTextbox : function() {
//            $.log(this.cur_mode);

            this._select_nothing();

            this.cur_textbox.selected = true;
            this.has_selected_doodle = true;

            //这两行代码顺序不能变。cur_textbox.active会调用drawer的paint函数。
            this.attachCurTextbox();
            this.cur_textbox.active();

            this.style_callback("btn", "text");
        },
        attachCurTextbox : function() {
            this.edit_doodle.attachDoodle(this.cur_textbox);
            this._paintEditLayer();
        },
        activeInnerTextbox : function() {
            this.cur_textbox.active();
            this.style_callback("btn", "text");
        },

        delTextbox : function(tb) {
            var i = this.page.doodle_array.indexOf(tb);
            if(i>=0) {
                this.page.doodle_array.splice(i,1);
            }
            this.cur_textbox = null;
        },

		paint : function(){

            this._paintDoodleLayer();

            this._paintEditLayer();

            this._paintChooseLayer();
        },
        _prepare_for_blur : function() {
//            this.b_ctx.save();
//            this.b_ctx.drawImage(this.doodle_canvas, 0, 0);
//            var t = new Date().getTime();
//            $.stackBlurCanvasRGBA(this.b_ctx, 0, 0, this.doodle_canvas.width, this.doodle_canvas.height);
//            $.log("blur buffered image, time: " + (new Date().getTime() - t));
//            this.b_ctx.restore();
        },
        _finish_for_blur : function() {
//            this.doodle_canvas.style.display = 'block';
        },

        _paintDoodleLayer : function() {
//            $.log("paint doodle layer");
            var bi = this.bg_info, ctx = this.d_ctx;
            var t_ctx = this.t_ctx, s = this.zoom_scale;

            ctx.save();
            t_ctx.save();
            ctx.lineCap = "round";
            ctx.lineJoin = "round";
            t_ctx.lineCap = "round";
            t_ctx.lineJoin = "round";

            ctx.scale(s, s);
            ctx.translate(-bi.x, -bi.y);

            t_ctx.scale(s, s);
            t_ctx.translate(-bi.x, -bi.y);

            ctx.clearRect(bi.x, bi.y, bi.width, bi.height);
            ctx.drawImage(bi.image, bi.x, bi.y, bi.width, bi.height, bi.x, bi.y, bi.width, bi.height);


            var d_arr = this.page.doodle_array;
			for (var i = d_arr.length - 1; i >= 0; i--) {
                if(!d_arr[i].selected) {
                    d_arr[i].draw(ctx);
                }
			}

            ctx.restore();
            t_ctx.restore();
        },
        _clear_ctx : function(ctx) {
            var bi = this.bg_info;
            ctx.clearRect(bi.x, bi.y, bi.width, bi.height);
        },
        _select_nothing : function() {
            var d_arr = this.page.doodle_array;
            this.has_selected_doodle = false;
            for(var i=0;i<d_arr.length;i++) {
                d_arr[i].selected = false;
            }
            this.edit_doodle.attachNothing();
            this._select_back();
        },
        _select_doodle:function(doo) {
            var d_arr = this.page.doodle_array;
            for(var i=0;i<d_arr.length;i++) {
                d_arr[i].selected = false;
            }
            this.has_selected_doodle = true;
            doo.selected = true;
            this.edit_doodle.attachDoodle(doo);
            this._select_back();
        },
		_paintEditLayer : function(){
//            $.log('p e layer');
            var d_arr = this.page.doodle_array;
            var ctx = this.e_ctx, bi = this.bg_info;
            var t_ctx = this.t_ctx, s = this.zoom_scale;
            var w = bi.width,
                h = bi.height;

            ctx.save();
            t_ctx.save();
            ctx.lineCap = "round";
            ctx.lineJoin = "round";
            t_ctx.lineCap = "round";
            t_ctx.lineJoin = "round";

            ctx.scale(s, s);
            ctx.translate(-bi.x, -bi.y);

            t_ctx.scale(s, s);
            t_ctx.translate(-bi.x, -bi.y);

            ctx.clearRect(bi.x, bi.y, w, h);

            if(this.cut_mode) {
                ctx.fillStyle = "rgba(0, 0, 0, 0.3)";
                ctx.fillRect(bi.x, bi.y, w, h);
            }

			for(var i=d_arr.length-1;i>=0;i--) {
                if(d_arr[i].selected) {
                    d_arr[i].draw_select(ctx);
                }
            }

            var td = this.temp_doodle;
            if(td !== null) {
                if(td.type === Doodle.Type.RECT_BLUR) {
                    td.draw_blur(ctx, this.blur_canvas);
                } else {
                    td.draw(ctx);
                }
            }


            function dr(ctx, doo, scale) {
                var es= doo.edit_regions;
                for(var k=0;k<es.length;k++) {
                    es[k].draw(ctx, scale);
                }
            }

            if(this.cut_doodle !== null) {
                this.cut_doodle.draw(ctx);
                dr(ctx, this.cut_doodle, this.zoom_scale);
            } else if(this.__region_visible__) {
                //绘制二次编辑的控制点
                for(i=d_arr.length-1;i>=0;i--) {
                    if(d_arr[i].selected) {
                        dr(ctx, d_arr[i], this.zoom_scale);
                        break;
                    }
                }
                dr(ctx, this.edit_doodle, this.zoom_scale);
            }

			ctx.restore();
            t_ctx.restore();

		},
        _paintChooseLayer : function() {
            var d_arr = this.page.doodle_array;
            var ctx = this.c_ctx, bi = this.bg_info;
            var t_ctx = this.t_ctx, scale = this.zoom_scale;
            var i;
            ctx.save();
            t_ctx.save();

            ctx.lineCap = "round";
            ctx.lineJoin = "round";
            t_ctx.lineCap = "round";
            t_ctx.lineJoin = "round";

            ctx.scale(scale, scale);
            ctx.translate(-bi.x, -bi.y);
            t_ctx.scale(scale, scale);
            t_ctx.translate(-bi.x, -bi.y);

            ctx.clearRect(bi.x, bi.y, bi.width, bi.height);

            if(!this.cut_mode) {
                for (i = d_arr.length - 1; i >= 0; i--) {
                    d_arr[i].draw_choose(ctx, i);
                }
            }

            if(this.cut_doodle !== null) {
                this.cut_doodle.draw_choose(ctx, d_arr.length);
            }

            ctx.restore();
            t_ctx.restore();
        },
        cutImage : function() {
            if(this.cur_textbox !== null) {
                this.unactiveTextbox();
            }
            this.cut_saved = {
                brush : this.style.brush_type,
                cursor : this.default_cursor,
                cursor_type : this.cursor_type
            };
            this.hideListDialog();
            this.cursor_type = 1;
            this.style.brush_type = Doodle.Type.CUT;
            this.default_cursor = "cursor_crosshair";
            this.setCursor_name(this.default_cursor);

            this.cut_mode = true;
            this._select_nothing();
            this.edit_doodle.attachNothing();
            this.paint();
            this.__cut_undo_command__ = new UR._CropCommand(this);
        },
        setCropSize : function(width, height) {
            if(this.cut_mode) {
                this.cut_doodle.setSize(width, height);
                this._paintEditLayer();
                this._paintChooseLayer();
            }
        },
        set_bg_info : function(vb) {
            var bi = this.bg_info;
            bi.x = vb.x;
            bi.y = vb.y;
            bi.width = vb.w;
            bi.height = vb.h;
            this._resize();
            this.paint();
        },
        finishCutImage : function(do_cut) {

            if(do_cut && this.cut_doodle !== null) {
                var p = this.cut_doodle.points,
                    x0 = Math.min(p[0].x, p[1].x),
                    y0 = Math.min(p[0].y, p[1].y),
                    x1 = Math.max(p[0].x, p[1].x),
                    y1 = Math.max(p[0].y, p[1].y);
                var bi = this.bg_info;
                x0 = Math.max(x0, bi.x);
                y0 = Math.max(y0, bi.y);
                x1 = Math.min(x1, bi.x + bi.width);
                y1 = Math.min(y1, bi.y + bi.height);
                bi.x = x0;
                bi.y = y0;
                bi.width = x1 - x0;
                bi.height = y1 - y0;
                this._resize();
                this._clear_back();
                this.__cut_undo_command__.finish();
                this.history.add(this.__cut_undo_command__);
                this.__cut_undo_command__ = null;

                var d_arr = this.page.doodle_array;
                var T = Doodle.Type;
                for(var i=0;i<d_arr.length;i++) {
                    if(d_arr[i].type === T.TEXT) {
                        d_arr[i]._calc();
                    } else if(d_arr[i].type === T.CALLOUT) {
                        d_arr[i].child_textbox._calc();
                    }
                }

            }

            this.cursor_type = this.cut_saved.cursor_type;
            this.default_cursor = this.cut_saved.cursor;
            this.style.brush_type = this.cut_saved.brush;

            if(this.cursor_type === 2) {
                this.setCursor(this.default_cursor);
            } else {
                this.setCursor_name(this.default_cursor);
            }
            this.cut_mode = false;
            this.cut_doodle = null;
            this.has_selected_doodle = false;
            this.paint();

        },
        setPenWidth : function(pw) {
            this.style.pen_width = pw;
            var d_arr = this.page.doodle_array;
            if(this.has_selected_doodle) {
                for(var i=0;i<d_arr.length;i++) {
                    if(d_arr[i].selected) {
                        var pre_w = d_arr[i].pen_width;
                        d_arr[i].setPenWidth(pw);
                        this.history.add(new UR._DoodleWidthCommand(d_arr[i], pre_w, pw));

                        break;
                    }
                }
                this.paint();
            }
        },
        setPenOpacity : function(opacity) {
            this.style.pen_opacity = opacity;
            this._get_color();
        },
        setPenColor : function(color) {
            this.style.pen_color = color;
            this._get_color();
        },
        setArrowType : function(at) {
            this.style.arrow_type = at;
        },
        setPenType : function(shape_name) {
            var pt = Doodle.Type[shape_name.toUpperCase()];
            this.style.brush_type = pt;

            if(pt === Doodle.Type.LIST) {
                var LI = Doodle._ListDoodle.__LAST_INFO__;
                LI.color = this.style.color;
                this.default_cursor = LI.getCursor();
                this.setCursor(this.default_cursor);
                this.cursor_type = 2;
            } else {
                this.default_cursor = 'cursor_' + shape_name;
                this.setCursor_name(this.default_cursor);
                this.cursor_type = 1;
            }

        },

        setSvgImage : function(svg_image) {
            this.style.svg_image = svg_image;
        },
        insertSvgImage : function(svg_image) {
            this.style.svg_image = svg_image;
            var scale = this.zoom_scale;
            var c = this.container,
                oc = this.out_container,
                W = Math.min(oc.offsetWidth, c.offsetWidth),
                H = Math.min(oc.offsetHeight, c.offsetHeight),
                iw = svg_image.width,
                ih = svg_image.height,
                st = oc.scrollTop,
                sl = oc.scrollLeft;
            var bi = this.bg_info;
            var _l = Math.floor(((W - iw * scale) / 2 + sl) / scale),
                _t = Math.floor(((H - ih * scale) / 2 + st) / scale);

            var d = Doodle.create(Doodle.Type.IMAGE, {
                drawer: this,
                image : this.style.svg_image.image,
                width: iw,
                height: ih,
                choose_type : svg_image.choose_type,
                points : [{
                    x : _l + bi.x,
                    y : _t + bi.y
                }, {
                    x : _l + bi.x + iw,
                    y : _t + bi.y + ih
                }]
            });
            d.initialize();
            this.insertDoodle(d);
            this._select_doodle(d);
            this.paint();
        },
        _get_color : function() {
            var clr = $.str2rgba(this.style.pen_color);
            this.style.color = $.rgba2str(clr.r, clr.g, clr.b, this.style.pen_opacity);
            Doodle._ListDoodle.__LAST_INFO__.color = this.style.color;

            var d_arr = this.page.doodle_array;
            if(this.has_selected_doodle) {
                for(var i=0;i<d_arr.length;i++) {
                    if(d_arr[i].selected) {
                        var pc = d_arr[i].color;
                        d_arr[i].setColor(this.style.color);
                        this.history.add(new UR._DoodleColorCommand(d_arr[i], pc, this.style.color));
                        break;
                    }
                }
                this.paint();
            }
        },
        _get_selected_shape : function() {
            if(this.has_selected_doodle) {
                var d_arr = this.page.doodle_array;
                for(var i=0;i<d_arr.length;i++) {
                    if(d_arr[i].selected) {
                        return d_arr[i];
                    }
                }
            }
            return null;
        },
        setFontName : function(fn) {
            this.style.font_name = fn;
            var T = Doodle.Type;
            var ct = this.cur_textbox || this._get_selected_shape();
            if(ct !== null && (ct.type === T.TEXT || ct.type === T.INNERTEXT || ct.type === T.CALLOUT)) {
                ct.setFontName(fn);
            }
        },
        setFontSize : function(fs) {
            this.style.font_size = fs;
            var T = Doodle.Type;
            var ct = this.cur_textbox || this._get_selected_shape();
            if(ct !== null && (ct.type === T.TEXT  || ct.type === T.INNERTEXT || ct.type === T.CALLOUT)) {
                ct.setFontSize(fs);
            }
        },
        undo : function() {
            this.history.undo();
            this._ur_back()
        },
        redo : function() {
            this.history.redo();
            this._ur_back()
        },
        _clear : function() {
            this.page.doodle_array.length = 0;
            this.history.clear();
            this._select_nothing();
            this._clear_back();
        },
        clear : function(){
            this._clear();
            this.d_changed = true;
            var bi = this.bg_info;
            bi.x = 0;
            bi.y = 0;
            bi.width = bi.origin_image.naturalWidth;
            bi.height = bi.origin_image.naturalHeight;

            bi.image.width = bi.width;
            bi.image.height = bi.height;

            this.i_ctx.drawImage(bi.origin_image, 0 , 0);

            this.reset_list();
            this._resize();
            this.paint();

            this._clear_back();
        },
        saveOrigin : function(callback) {
            if(this.bg_info.saved_origin !== null) {
                callback();
            } else {
                var img = new Image();
                img.src = $.image2url(this.bg_info.origin_image);
                img.onload = callback;
                this.bg_info.saved_origin = img;
            }
        },
        restoreOrigin : function() {
          this.bg_info.origin_image = this.bg_info.saved_origin;
        },
        _ur_back : function() {
            this.style_callback('undo', this.history.canUndo());
            this.style_callback('redo', this.history.canRedo());
        },
        _select_back : function() {
            this.style_callback('del', this.has_selected_doodle);
            var selected_doo = this.edit_doodle.selected_doodle;
            var T = Doodle.Type, tt = selected_doo !== null ? selected_doo.type : this.style.brush_type;
            if(tt === T.LIST && this.style.brush_type !== T.LIST) {
                tt = this.style.brush_type;
            }
            var v = (tt === T.CALLOUT || tt=== T.TEXT) ? 'text'
                : (tt === T.LIST ? 'list' : 'other');

            this.style_callback("btn", v);
        },

        _clear_back : function() {
           this.style_callback("clear", this.isEdited() === false);
        },
        deleteSelected : function() {

            var doo = null;
            var d_arr = this.page.doodle_array;

            if(this.has_selected_doodle) {
                for(var i=0;i<d_arr.length;i++) {
                    if(d_arr[i].selected) {
                        doo = d_arr[i];
                        break;
                    }
                }
            }
            if(doo === null) {
                return;
            }
            this._removeDoodle(doo);
            this.history.add(new UR._DoodleDelCommand(doo));
            this.paint();
        },
        reset_list : function() {
            var DI = Doodle._ListDoodle.__LAST_INFO__;
            DI.reset();
        },
        resetList : function() {
            var DI = Doodle._ListDoodle.__LAST_INFO__;
            this.reset_list();
            this.default_cursor = DI.getCursor();
            this.setCursor(this.default_cursor);
            this.hideListDialog();

        }

	}
})(Diigo.Text, Diigo.Doodle, Diigo.UndoRedo, Diigo.$);


(function(Doodle, $) {
    /*****
     * 笔画的基类，文件需要首先引用
     */

	Doodle._Doodle = function(type, data) {
        this.type = type;
        //反向指针，指向拥有doodle的drawer
        this.drawer = data.drawer;
        /*
         * __data__保存了笔画从存档里面读到的所有数据。
         * 这样的好处是保存存档时可以统一从__data__属性中读取数据
         */
        //this.__data__ = data;
        /*
         * 虽然__data__中已经有所有数据，为了方便数据的读取和代码的可读，仍然将数据赋值给相应属性
         */
		this.points = data.points;
		this.color = typeof data.color === 'undefined' ? 'rgba(0,0,0,1.0)' : data.color;
        this.highlight_color = this._calc_highlight_color(this.color);
		this.pen_width = typeof data.pen_width === 'undefined' ? 3 : data.pen_width;
        this.line_type = typeof data.line_type === 'undefined' ? 0 : data.line_type;
        this.fill_color = typeof data.fill_color === 'undefined' ? null : data.fill_color;
        this.child_textbox = null;
		this.selected = false;
        this.is_eraser = data.is_eraser ? true : false;
        this.has_shadow = false;
        this.region_points = data.region_points ? data.region_points : this.points;
        /*
         * 是否初始化。即是否已经被正式加入到了doodle的列表中。
         * 用户新拖出一个doodle时，initialized为false，在这个状态下某些doodle，
         * 比如Frame和TextBox的显示效果会有不同（很简略）。用户拖完放开鼠标时，
         * Frame和TextBox都会检测拖动的有效性，如果拖出来的doodle太小，则Frame不会被加入到doodle的列表（即忽略），
         * TextBox会以自动改变大小的模式出现。
         * 对于其它Doodle，这个属性暂时没有特别作用。
         */
        this.initialized = false;
        /*
         * 用于二次编辑的EventRegion。
         */
        this.edit_regions = [];

		this.boundary = {
			left : 0,
			top : 0,
			height : 0,
			width : 0
		};
	};
	Doodle.Type = {
		CURVE : 1,
        LINE : 2,
        RECT : 3,
        ELLIPSE : 4,
        HIGHLIGHT: 1,

        RECT_BLUR : 5,
        CURVE_BLUR : 6,
        CALLOUT : 7,
        LIST : 8,

        LINE_ARROW : 20,
        CURVE_ARROW : 21,
        BEZIER_ARROW: 22,

        IMAGE : 30,

		ERASER : 60,
        TEXT : 80,
        INNERTEXT : 81,

        CUT : 8888,

		EDITHELPER : 999
	};
    Doodle.LineType = {
        NORMAL : 0,
        DASH_ONE : 0x1,
        DASH_TWO : 0x2,
        DASH_THREE : 0x4,
        LEFT_ARROW : 0x8,
        RIGHT_ARROW : 0x10,
        DOUBLE_ARROW : 0x20,
        SEED : 0x80,
        FILL : 0x100,
        MATRIX : 0x200
    };
	/**
	 * tag: IMAGE下是变形矩阵 matrix
	 *
	 */
	Doodle.create = function(type, data) {
		var d = null, T = Doodle.Type;
		switch(type) {
			case T.ERASER:
				return new Doodle._SimpleEraserDoodle(data);
			case T.LINE:
				return new Doodle._LineDoodle(data);
			case T.RECT:
				return new Doodle._RectDoodle(data);
			case T.ELLIPSE:
				return new Doodle._EllipseDoodle(data);
			case T.CURVE :
				return new Doodle._CurveDoodle(data);
            case T.RECT_BLUR:
                return new Doodle._RectBlurDoodle(data);
            case T.CURVE_BLUR:
                return new Doodle._CurveBlurDoodle(data);
			case T.TEXT :
				return new Doodle._TextboxDoodle(data);
            case T.INNERTEXT:
                return new Doodle._InnerTextboxDoodle(data);
            case T.CUT:
                return new Doodle._CutDoodle(data);
            case T.CALLOUT:
                return new Doodle._CalloutDoodle(data);
            case T.LIST:
                return new Doodle._ListDoodle(data);
            case T.IMAGE:
                return new Doodle._ImageDoodle(data);
            case T.LINE_ARROW:
                return new Doodle._LineArrowDoodle(data);
            case T.CURVE_ARROW:
                return new Doodle._CurveArrowDoodle(data);
            case T.BEZIER_ARROW:
                return new Doodle._BezierArrowDoodle(data);
			default:
				$.log("unkown type of doodle: " + type);
                return new Doodle._CurveDoodle(data);
		}
	};

	Doodle._Doodle.prototype = {
        setRegionDisabled : function(disabled) {
            for(var i=0;i<this.edit_regions.length;i++) {
                this.edit_regions[i].disabled = disabled;
            }
        },

        /**
         * doodle被拖动结束，在插入到笔画列表中时调用
         */
        initialize : function() {
           this.initialized = true;
        },
        onRegionEdit : function(idx, p) {
            // do nothing
        },
        onRegionEditStart : function(idx, p) {

        },
        onRegionEditFinish : function(idx, p) {

        },
        getRotateUndoCommand : function() {
            return null;
        },
        getMoveUndoCommand : function() {
            return null;
        },
        getRegionUndoCommand : function() {
            return null;
        },
        afterUndoRedo  : function() {
            this._calc();
            this.drawer._select_doodle(this);
        },
        _create_edit_region : function() {
            for(var i=0;i<this.region_points.length;i++) {
                this.edit_regions.push(new Doodle.CircleRegion(this, i, this.region_points[i], Math.round((Math.max(this.pen_width, 8) + 6)/2), 'pointer'));
            }
        },
        setPenWidth : function(pw) {
            this.pen_width = pw;
            for(var i=0;i<this.edit_regions.length;i++) {
                this.edit_regions[i].radius = Math.round((Math.max(this.pen_width, 8) + 6)/2);
            }
        },
        setColor : function(clr) {
            this.color = clr;
            this.highlight_color = this._calc_highlight_color(clr);
        },
        _calc_highlight_color : function() {
            var rgba = $.str2rgba(this.color);
            if(rgba.r>=200 && rgba.b>=200 && rgba.g>=200) {
                //white color
                return 'rgba(0,0,0,0.3)';
            } else {
                return 'rgba(255, 255, 255, '+rgba.a+')';
            }
        },
        getSelectedColor : function() {

        },
        getRotatePoint : function() {
            return null;
        },
        /*
         * _calc 和 _calc_2，得到包围点阵的边界矩形框。
         * 其中_calc_1是得到包围任意点的边界矩形。
         * _calc_2是包围两个顶点够成的矩形。
         */
		_calc_1 : function(ps) {
            var p = ps[0], x1 = p.x, y1 = p.y, x2 = p.x, y2 = p.y, _b = this.boundary;
            for(var j = 0; j < ps.length; j++) {
                p = ps[j];
                if(p.x < x1)
                    x1 = p.x;
                if(p.x > x2)
                    x2 = p.x;
                if(p.y < y1)
                    y1 = p.y;
                if(p.y > y2)
                    y2 = p.y;
            }
            _b.width = x2 - x1;
            _b.height = y2 - y1;
            _b.left = x1;
            _b.top = y1;
            _b.right = x2;
            _b.bottom = y2;
		},
        _calc_2 : function(x1, y1, x2, y2) {
            var _b = this.boundary;
            _b.width = Math.abs(x1 - x2);
            _b.height = Math.abs(y1 - y2);
            _b.left = Math.min(x1, x2);
            _b.top = Math.min(y1, y2);
            _b.right = _b.left + _b.width;
            _b.bottom = _b.top + _b.height;
        },
        set_child_textbox : function() {
            //do nothing;
        },
		_doDraw : function(ctx, left, top, width, height) {
			throw "abstract method _doDraw";
		},
        draw_choose : function(ctx, index) {
            var c = $.int2color(index);
            ctx.strokeStyle = c;
            ctx.fillStyle = c;
            ctx.lineWidth = Math.round(this.pen_width * 1.5);

            this._doChooseDraw(ctx, c);
        },
        draw_select : function(ctx) {
            ctx.save();
            ctx.strokeStyle = this.highlight_color;
            ctx.shadowColor = "rgba(0, 0, 0, 0.4)";
            ctx.shadowOffsetX = 0;
            ctx.shadowOffsetY = 2;
            ctx.shadowBlur = 4;
            ctx.lineWidth = Math.floor(this.pen_width + 6);
            this._doSelectDraw(ctx);
            ctx.restore();

            this.draw(ctx);
        },
        draw_region : function(ctx, scale, selected_color) {
            this.draw_select(ctx, selected_color);
            for(var i=0;i<this.edit_regions.length;i++) {
                this.edit_regions[i].draw(ctx, scale);
            }
        },
        _doChooseDraw : function(ctx, c) {
            this._doDraw(ctx, c);
        },
        _doSelectDraw : function(ctx) {
            this._doDraw(ctx);
        },
		draw : function(ctx, filter_ctx, left_off, top_off) {
            throw "abstruct methon draw";
		},
        drawFPT : function(ctx, filter_ctx, left_off, top_off) {
            this.draw(ctx, filter_ctx, left_off, top_off);
        },
        _typed_draw : function(ctx) {
            ctx.save();
            ctx.strokeStyle = this.color;
            ctx.lineWidth = this.pen_width;
            var LT = Doodle.LineType, _arrow = null, _t = this.line_type;

            if((_t & LT.DASH_ONE) > 0) {
//                ctx.lineDash = [1, 5];
                $.setLineDash(ctx, [1, 5]);
            } else if((_t & LT.DASH_TWO)>0) {
                //todo 完善不同类型的dash
//                ctx.lineDash = [6, 5];
                $.setLineDash(ctx, [6, 5]);
            } else if((_t & LT.DASH_THREE) > 0) {
//                ctx.lineDash = [6, 5, 1, 5];
                $.setLineDash(ctx, [6, 5, 1, 5]);
            }

            if((_t & LT.LEFT_ARROW)>0) {
                _arrow = this._drawLeftArrow;
            } else if((_t & LT.RIGHT_ARROW)>0){
                _arrow = this._drawRightArrow;
            } else if((_t & LT.DOUBLE_ARROW)>0) {
                _arrow = this._drawDoubleArrow;
            }

            this._doDraw(ctx, this.fill_color, this.has_shadow);
            if(_arrow !== null) {
                _arrow.call(this, ctx);
            }
            ctx.restore();

            if(this.child_textbox !== null) {
                this.child_textbox.draw(ctx);
            }
        },
        _normal_draw : function(ctx, filter_ctx, left_off, top_off) {
            ctx.strokeStyle = this.color;
            ctx.lineWidth = this.pen_width;

            this._doDraw(ctx, this.fill_color, filter_ctx, left_off, top_off);
        },
		editMove : function(dx, dy) {
            throw "absolute method editMove";
        },
		editRotateScale : function(relay_point, rotate, scale, not_calc) {
            throw "absolute method editRotateScale";
        },
		rotateScale : function(relay_point, rotate, scale) {
            throw "absolute method rotateScale";
		},
		move : function(dx, dy) {
            throw "absolute method move";
        },
		editStart : function(args) {
			throw "absolute methon editStart";
		},
		editFinish : function(args) {
			this._calc();
		},
		editPushPoint : function(p) {
            throw "absolute method editPushPoint";
        },
        _drawLeftArrow : function(ctx) {
            //do nothing;
        },
        _drawRightArrow : function(ctx) {
            //do nothing;
        },
        _drawDoubleArrow : function(ctx) {
            this._drawLeftArrow(ctx);
            this._drawRightArrow(ctx);
        },
        setFillColor : function(color) {
            return false;
        },
        resetScale : function() {
            //do nothing
        }
	}

})(Diigo.Doodle, Diigo.$);

(function(Doodle,UR, $) {
    /*
     * 普通笔画，包括Normal, line , diamond
     */
	Doodle._CommonDoodle = function(type, data) {
		this.base(type, data);
        this.pre_points = $.copyPoints(this.points);
        this.rotate_point = {
            x : 0,
            y : 0
        };

        this._calc();
	};
	Doodle._CommonDoodle.prototype = {
        getRotatePoint : function() {
            return null;
        },
        getMoveUndoCommand : function(drawer) {
            return new UR._DoodlePointsCommand(this);
        },
        _calc : function() {
            this._calc_1(this.points);
            var b = this.boundary;
            this.rotate_point.x = Math.floor(b.left + b.width / 2);
            this.rotate_point.y = b.top - 20;

        },
        draw : function(ctx, filter_ctx, left_off, top_off) {
            this._typed_draw(ctx, filter_ctx, left_off, top_off);
        },
        editMove : function(dx, dy) {
            for(var i = 0; i < this.points.length; i++) {
                this.points[i].x = this.pre_points[i].x + dx;
                this.points[i].y = this.pre_points[i].y + dy;
            }
            this._calc();
        },
        move : function(dx, dy) {
            for(var i = 0; i < this.points.length; i++) {
                this.points[i].x += dx;
                this.points[i].y += dy;
            }
            this._calc();
        },
        editStart : function() {
            $.setPoints(this.pre_points, this.points);
        },
        editPushPoint : function(p) {
            this.points.push(p);
            this.pre_points.push({
                x : 0,
                y : 0
            });
            this._calc();
        }
	};
	$.inherit(Doodle._CommonDoodle, Doodle._Doodle);

    Doodle._CurveDoodle = function(data) {
        if(data.points.length === 1) {
            var p0 = data.points[0];
            var pw = data.pen_width;
            var p1 = {
                x : p0.x + pw / 4,
                y : p0.y
            };
            data.points.push(p1);
        }
        this.base(Doodle.Type.CURVE, data);
    };
    Doodle._CurveDoodle.prototype = {

        _doDraw : function(ctx) {
            $.drawBesier(ctx, this.points);
        },
        _drawLeftArrow : function(ctx) {
            var p = this.points, p1 = p[0], p2 = p.length>1 ? p[1] : p1;
            $.drawArrow(ctx, p2.x, p2.y, p1.x, p1.y);
        },
        _drawRightArrow : function(ctx) {
            var p = this.points, p1 = p[p.length-1], p2 = p.length>1 ? p[p.length-2] : p1;
            $.drawArrow(ctx, p2.x, p2.y, p1.x, p1.y);
        }
    };
    $.inherit(Doodle._CurveDoodle, Doodle._CommonDoodle);

    Doodle._LineDoodle = function(data) {
        if(data.points.length === 1) {
            data.points.push({
                x : data.points[0].x,
                y : data.points[0].y
            });
        }

        this.base(Doodle.Type.LINE, data);
        this.region_points = this.points;
        this._create_edit_region();

    };
    Doodle._LineDoodle.prototype = {

        _calc : function() {
            var p = this.points;
            this._calc_2(p[0].x, p[0].y, p[1].x, p[1].y);
        },
        _doDraw : function(ctx) {
            var p = this.points;
            $.drawLine(ctx, p[0].x, p[0].y, p[1].x, p[1].y);
        },
        _drawLeftArrow : function(ctx) {
            var p = this.points, p1 = p[0], p2 = p[1];
            $.drawArrow(ctx, p2.x, p2.y, p1.x, p1.y);
        },
        _drawRightArrow : function(ctx) {
            var p = this.points, p1 = p[1], p2 = p[0];
            $.drawArrow(ctx, p2.x, p2.y, p1.x, p1.y);
        },
        editPushPoint : function(point) {
            this.points[1].x = point.x;
            this.points[1].y = point.y;
            this._calc();
        },
        getRegionUndoCommand : function() {
            return new UR._DoodlePointsCommand(this);
        },
        onRegionEdit : function(idx, p) {
            this.points[idx].x = p.x;
            this.points[idx].y = p.y;
            this._calc();
            this.drawer.edit_doodle.attachDoodle(this);
        },
        onRegionEditFinish : function(idx, p) {
            this.drawer.edit_doodle.attachDoodle(this);
        }
    };
    $.inherit(Doodle._LineDoodle, Doodle._CommonDoodle);



    Doodle._LineArrowDoodle = function(data) {
        this.arrow_info = {
            idx : 0,
            pos : {

            }
        };
        this.base(data);
    };
    Doodle._LineArrowDoodle.prototype = {
        setPenWidth : function(pw) {
            this.callBase('setPenWidth', pw);
            this._calc_arrow();
        },
        draw : function(ctx) {

            var t_ctx = this.drawer.t_ctx;
            var bi = this.drawer.bg_info;

            t_ctx.save();
            t_ctx.fillStyle = this.color;
            t_ctx.strokeStyle = this.color;
            t_ctx.lineWidth = this.pen_width;

            t_ctx.clearRect(bi.x, bi.y, bi.width, bi.height);

            this._doDraw(t_ctx);

            t_ctx.restore();

            ctx.save();
            ctx.setTransform(1,0,0,1,0,0);
            ctx.drawImage(t_ctx.canvas, 0, 0);
            ctx.restore();

        },
        _calc_arrow : function() {
            var ps = this.points;
            var A_LEN = this.pen_width * 5;
            this.arrow_info.idx = $.getPTPRange(ps[0], ps[1]) > A_LEN ? 1 : 0;
            this.arrow_info.pos =  $.calcArrow(ps[0].x, ps[0].y, ps[1].x, ps[1].y, A_LEN);

        },
        _doDraw : function(ctx, stroke) {
            var points = this.points;
            var ai = this.arrow_info;
            var pos = ai.pos;
            var _t = ai.idx === 0;

            ctx.beginPath();

            if(!_t) {

                ctx.moveTo(points[0].x, points[0].y);
                ctx.lineTo(pos.cx, pos.cy);


                if(stroke) {

                    ctx.lineTo(pos.ax, pos.ay);
                    ctx.lineTo(pos.dx, pos.dy);
                    ctx.lineTo(pos.bx, pos.by);

                    ctx.lineTo(pos.cx, pos.cy);
                    ctx.stroke();
                } else {
                    ctx.stroke();
                    ctx.closePath();
                    ctx.beginPath();
                    ctx.moveTo(pos.ax, pos.ay);
                    ctx.lineTo(pos.dx, pos.dy);
                    ctx.lineTo(pos.bx, pos.by);
                    ctx.closePath();

                    ctx.save();
                    ctx.globalCompositeOperation = "destination-out";
                    ctx.fillStyle = "black";
                    ctx.fill();
                    ctx.restore();

                    ctx.fill();
                }
            } else {
                ctx.beginPath();
//                ctx.moveTo(pos.cx, pos.cy);
                ctx.moveTo(pos.ax, pos.ay);
                ctx.lineTo(pos.dx, pos.dy);
                ctx.lineTo(pos.bx, pos.by);
                ctx.closePath();
                ctx.fill();
            }



        },
        _calc : function() {
            this.callBase("_calc");
            this._calc_arrow();
        },
        _doSelectDraw : function(ctx) {
            this._doDraw(ctx, true);
        },
        _doChooseDraw : function(ctx, c) {
            this._doDraw(ctx, false);
        }
    };
    $.inherit(Doodle._LineArrowDoodle, Doodle._LineDoodle);

    Doodle._CurveArrowDoodle = function(data) {
        this.arrow_info = {
            idx : 0,
            pos : {

            }
        };
        this.base(data);
    };
    Doodle._CurveArrowDoodle.prototype = {
        setPenWidth : function(pw) {
            this.callBase('setPenWidth', pw);
            this._calc_arrow();
        },
        draw : function(ctx) {

            var dr = this.drawer, t_ctx = dr.t_ctx;
            var bi = dr.bg_info;

            t_ctx.save();
            t_ctx.fillStyle = this.color;
            t_ctx.strokeStyle = this.color;
            t_ctx.lineWidth = this.pen_width;

            t_ctx.clearRect(bi.x, bi.y, bi.width, bi.height);

            this._doDraw(t_ctx);

            t_ctx.restore();

            ctx.save();
            ctx.setTransform(1,0,0,1,0,0);
            ctx.drawImage(t_ctx.canvas, 0, 0);
            ctx.restore();

        },

        _doDraw : function(ctx, stroke) {
            var points = this.points;
            var ai = this.arrow_info;
            var pos = ai.pos;
            var _t = ai.idx === 0;

            ctx.beginPath();

            if(!_t) {
                var dest = null;
                var ctrl = points[0];
                ctx.moveTo(ctrl.x, ctrl.y);
                for(var i = 0; i < ai.idx; i++) {
                    dest = $.getMiddlePoint(points[i], points[i + 1]);
                    ctx.quadraticCurveTo(ctrl.x, ctrl.y, dest.x, dest.y);
                    ctrl = points[i + 1];
                }
                    var np = {
                        x : pos.cx,
                        y : pos.cy
                    };
                    dest = $.getMiddlePoint(points[ai.idx], np);
                    ctx.quadraticCurveTo(ctrl.x, ctrl.y, dest.x, dest.y);
                    ctrl = np;
                    dest = np;

                ctx.quadraticCurveTo(ctrl.x, ctrl.y, dest.x, dest.y);
                if(!stroke) {

                    ctx.stroke();
                    ctx.closePath();
                    ctx.beginPath();
                    ctx.moveTo(pos.cx, pos.cy);
                }

                ctx.lineTo(pos.ax, pos.ay);
                ctx.lineTo(pos.dx, pos.dy);
                ctx.lineTo(pos.bx, pos.by);

                if(stroke) {
                    ctx.lineTo(pos.cx, pos.cy);
                    ctx.stroke();
                } else {
                    ctx.closePath();

                    ctx.save();
                    ctx.globalCompositeOperation = "destination-out";
                    ctx.fillStyle = "black";
                    ctx.fill();
                    ctx.restore();

                    ctx.fill();
                }
            } else {
                ctx.beginPath();
                ctx.moveTo(pos.cx, pos.cy);
                ctx.lineTo(pos.ax, pos.ay);
                ctx.lineTo(pos.dx, pos.dy);
                ctx.lineTo(pos.bx, pos.by);
                ctx.closePath();
                ctx.fill();
            }



        },
        _calc : function() {
            this.callBase("_calc");
            this._calc_arrow();
        },
        _calc_arrow : function() {
            var ps = this.points;
            var A_LEN = this.pen_width * 5;
            var idx = ps.length - 1;
            if(idx <= 0) {
                return;
            }

            var dist = 0;
            while(idx > 0) {
                dist = $.getPTPRange(ps[ps.length-1], ps[idx-1]);
                if(dist >= A_LEN || idx === 1) {
                    break;
                }
                idx--;
            }

            this.arrow_info.idx = idx - 1;
            this.arrow_info.pos =  $.calcArrow(ps[idx - 1].x, ps[idx-1].y, ps[ps.length-1].x, ps[ps.length-1].y, A_LEN);

        },
        _doSelectDraw : function(ctx) {
            this._doDraw(ctx, true);
        },
        _doChooseDraw : function(ctx, c) {
            this._doDraw(ctx, false);
        }

    };
    $.inherit(Doodle._CurveArrowDoodle, Doodle._CurveDoodle);
})(Diigo.Doodle, Diigo.UndoRedo, Diigo.$);

(function(Doodle, UR, $) {
    /**
     *
     */
    Doodle._MatrixDoodle = function(type, data) {
        if(data.points.length === 1) {
            data.points.push({
                x : data.points[0].x,
                y : data.points[0].y
            });
        }

        this.base(type, data);
        this.matrix = data.matrix == null ? [1,0,0,0,1,0,0,0,0] : data.matrix;
        this.line_type |= 0x200;
        this.pre_matrix = $.copyArray(this.matrix);
        this.region_points = [];
        this.rotate_point = {
            x : 0,
            y : 0
        };
        this.region_points = $.genPoints(data.region_number ? data.region_number : 4);//   [{x:0,y:0},{x:0,y:0},{x:0,y:0},{x:0,y:0}];

        this._calc();
        this._create_edit_region();
    };
    Doodle._MatrixDoodle.prototype = {

        getRotatePoint : function() {
            return this.rotate_point;
        },
        _create_edit_region : function() {
            for(var i=0;i<this.region_points.length;i++) {
                this.edit_regions.push(new Doodle.CircleRegion(this, i, this.region_points[i], Math.round((Math.max(this.pen_width, 8) + 6)/2), 'pointer'));
            }
        },
        getMoveUndoCommand : function() {
            return new UR._DoodleMatrixCommand(this);
        },
        getRegionUndoCommand : function() {
            return new UR._DoodlePointsCommand(this);
        },
        getRotateUndoCommand : function() {
            return new UR._DoodleMatrixCommand(this);
        },
        /**
         *
         * @param m matrix
         * @param dst_x
         * @param dst_y
         * @private 计算矩阵变化前的点。
         */
        _calcBeforeMatrixPoint : function(m, dst_x, dst_y) {
            var de = (m[3]*m[1]-m[0]*m[4]);
            if(de === 0) {
                alert("0");
                console.error("出现除0！");
                return null;
            }
            var src_x = ((dst_y-m[5]) * m[1] - (dst_x-m[2]) * m[4]) / de, src_y;
            if(m[1]!==0) {
                src_y = (dst_x - m[2] - m[0]*src_x)/m[1];
            } else if(m[4]!==0){
                src_y = (dst_y - m[5] - m[3]*src_x)/m[4];
            } else {
                alert("0");

                console.error("出现除0~！");
                return null;
            }
            return {
                x : Math.floor(src_x),
                y : Math.floor(src_y)
            };
        },
        /**
         * 计算两个点在矩阵变换之前的水平宽度。
         * @param m
         * @param x1
         * @param y1
         * @param x2
         * @param y2
         * @returns {number}
         * @private
         */
        _calcBeforeMatrixWidth : function(m, x1, y1, x2, y2) {
            var de = (m[3]*m[1]-m[0]*m[4]);
            if(de === 0) {
                alert("0");
                console.error("出现除0！");
                return -1;
            }
            var src_x1 = ((y1-m[5]) * m[1] - (x1-m[2]) * m[4]) / de,
                src_x2 = ((y2-m[5]) * m[1] - (x2-m[2]) * m[4]) / de;

            return Math.abs(Math.floor(src_x1 - src_x2));

        },
        _onRegionEdit : function(idx, p, ps) {
            var _p = this._calcBeforeMatrixPoint(this.matrix, p.x, p.y);
            var x = _p.x,
                y = _p.y;
            var p0 = ps[0],
                p1 = ps[1];
            if(this.region_points.length === 8) {
                switch (idx) {
                    case 0:
                        p0.x = x;
                        p0.y = y;
                        break;
                    case 1:
                        p0.y = y;
                        break;
                    case 2:
                        p1.x = x;
                        p0.y = y;
                        break;
                    case 3:
                        p1.x = x;
                        break;
                    case 4:
                        p1.x = x;
                        p1.y = y;
                        break;
                    case 5:
                        p1.y = y;
                        break;
                    case 6:
                        p0.x = x;
                        p1.y = y;
                        break;
                    case 7:
                        p0.x = x;
                        break;
                }
            } else { //region_points.length = 4
                switch (idx) {
                    case 0:
                        p0.x = x;
                        p0.y = y;
                        break;

                    case 1:
                        p1.x = x;
                        p0.y = y;
                        break;

                    case 2:
                        p1.x = x;
                        p1.y = y;
                        break;

                    case 3:
                        p0.x = x;
                        p1.y = y;
                        break;

                }
            }

        },
        onRegionEdit : function(idx, p) {
            this._onRegionEdit(idx, p, this.points);
            this._calc();
            this.drawer.edit_doodle.attachDoodle(this);
        },

        set_child_textbox : function(ct) {
//            $.log('set ct')
            this.child_textbox = ct;
            this._calc_boundary();
        },
        _calc_boundary : function() {
//            $.log("calc bou")
            var _b = this.boundary, _cb = this.child_textbox.boundary;
//            $.log(_cb);

            _b.left = Math.min(_b.left, _cb.left);
            _b.right = Math.max(_b.right, _cb.right);
            _b.top = Math.min(_b.top, _cb.top);
            _b.bottom = Math.max(_b.bottom, _cb.bottom);
        },
        _calc : function() {
            var m = this.matrix, p = this.points, x1, x2, x3, x4, y1, y2, y3, y4;
            var mx = (p[0].x + p[1].x) / 2,
                my = (p[0].y + p[1].y) / 2,
                ry = (Math.min(p[0].y, p[1].y) - this.pen_width / 2 - 25);

            function c012(x, y) {
                return Math.floor(m[0] * x + m[1] * y + m[2]);
            }
            function c345(x, y) {
                return Math.floor(m[3] * x + m[4] * y + m[5]);
            }

            x1 = c012(p[0].x, p[0].y);
            y1 = c345(p[0].x, p[0].y);//m[3] * p[0].x + m[4] * p[0].y + m[5];
            x2 = c012(p[1].x, p[0].y);
            y2 = c345(p[1].x, p[0].y);//m[3] * p[1].x + m[4] * p[0].y + m[5];
            x3 = c012(p[1].x, p[1].y); //m[0] * p[1].x + m[1] * p[1].y + m[2];
            y3 = c345(p[1].x, p[1].y);//m[3] * p[1].x + m[4] * p[1].y + m[5];
            x4 = c012(p[0].x, p[1].y); //m[0] * p[0].x + m[1] * p[1].y + m[2];
            y4 = c345(p[0].x, p[1].y);//m[3] * p[0].x + m[4] * p[1].y + m[5];

            var rp = this.region_points;


            if(rp.length === 8) {
                rp[0].x = x1;
                rp[0].y = y1;
                rp[1].x = c012(mx, p[0].y);
                rp[1].y = c345(mx, p[0].y);
                rp[2].x = x2;
                rp[2].y = y2;
                rp[3].x = c012(p[1].x, my);
                rp[3].y = c345(p[1].x, my);
                rp[4].x = x3;
                rp[4].y = y3;
                rp[5].x = c012(mx, p[1].y);
                rp[5].y = c345(mx, p[1].y);
                rp[6].x = x4;
                rp[6].y = y4;
                rp[7].x = c012(p[0].x, my);
                rp[7].y = c345(p[0].x, my);
            } else {
                rp[0].x = x1;
                rp[0].y = y1;
                rp[1].x = x2;
                rp[1].y = y2;
                rp[2].x = x3;
                rp[2].y = y3;
                rp[3].x = x4;
                rp[3].y = y4;
            }

            this.rotate_point.x = c012(mx, ry);// Math.floor(m[0] * mx + m[1] * ry + m[2]);
            this.rotate_point.y = c345(mx, ry);//Math.floor(m[3] * mx + m[4] * ry + m[5]);


            this._calc_2(Math.min(x1,x2,x3,x4), Math.min(y1,y2,y3,y4), Math.max(x1,x2,x3,x4),Math.max(y1,y2,y3,y4));
        },
        draw : function(ctx, filter_ctx, left_off, top_off) {
            this._typed_draw(ctx, filter_ctx, left_off, top_off);
        },
        editStart : function() {
            $.setArray(this.pre_matrix, this.matrix);
            if(this.child_textbox !== null) {
                this.child_textbox.editStart();
            }
        },
        editFinish : function() {
            this._calc();
            if(this.child_textbox !== null) {
                this.child_textbox.editFinish();
                this._calc_boundary();
            }
        },
        editMove : function(dx, dy) {
            this.matrix[2] = this.pre_matrix[2] + dx;
            this.matrix[5] = this.pre_matrix[5] + dy;
            this._calc();
            if(this.child_textbox !== null) {
                this.child_textbox.editMove();
            }
        },
        move : function(dx, dy) {
            this.matrix[2] += dx;
            this.matrix[5] += dy;

            this._calc();
        },
        rotateScale : function(relay_point, rotate, scale) {
            $.setArray(this.pre_matrix, this.matrix);
            this.editRotateScale(relay_point, rotate, scale);
        },
        editRotateScale : function(relay_point, rotate, scale, not_calc) {
            /**
             * 对矩阵进行缩放。由于操作的时候是相对图形中心点（relay_point）进行的旋转，而this.matrix保存的是相对于原点 的旋转，
             * 所以实际的操作是先将中点移回原点，然后旋转，缩放，然后再将中点移回来。
             *
             * 					[1 0 x]		[cos(rotate) -sin(rotate) 0]		[scale 0 0]		[1 0 -x]
             * this.matrix =	[0 1 y]	* 	[sin(rotate)  cos(rotate) 0]	*	[scale 0 0]	* 	[0 1 -y]	*	this.pre_matrix
             * 					[0 0 1]		[0            0           1]		[0     0 1]		[0 0  1]
             * 其中x，y是图形中心点（relay_point）的坐标
             * 注意矩阵相乘的顺序和图形变换操作的次序是相反的，最右边的矩阵代表最先进行的变形。
             * 注意下面的代码是上面矩阵展开精简后的结果。
             *
             */
            scale = 1.0; //ignore scale

            var m = this.matrix, pm = this.pre_matrix, s = Math.sin(rotate) * scale, c = Math.cos(rotate) * scale, x = relay_point.x, y = relay_point.y;
            m[0] = c * pm[0] - s * pm[3];
            m[1] = c * pm[1] - s * pm[4];
            m[2] = c * pm[2] - s * pm[5] - c * x + s * y + x;
            m[3] = s * pm[0] + c * pm[3];
            m[4] = s * pm[1] + c * pm[4];
            m[5] = s * pm[2] + c * pm[5] - s * x - c * y + y;
            if(not_calc !== true) {
                this._calc();
            }

            if(this.child_textbox !== null) {
                this.child_textbox.editRotateScale();
            }
        },
        editPushPoint : function(point) {
            this.points[1].x = point.x;
            this.points[1].y = point.y;
            this._calc();
        },
        setFillColor : function(color) {
            if(typeof color !== 'string') {
                this.fill_color = null;
            } else {
                this.fill_color = color;
            }
            return true;
        },
        resetZoomScale : function() {
            if(this.child_textbox !== null) {
                this.child_textbox.resetZoomScale();
            }
        }
    };
    $.inherit(Doodle._MatrixDoodle, Doodle._Doodle);

    Doodle._RectDoodle = function(data) {
        this.base(Doodle.Type.RECT, data);
    };
    Doodle._RectDoodle.prototype = {

        _doDraw : function(ctx, fill_color) {
//            $.log(ctx.lineWidth);

            var p = this.points;
            ctx.save();
            ctx.transform(this.matrix[0], this.matrix[3], this.matrix[1], this.matrix[4], this.matrix[2], this.matrix[5]);
            ctx.beginPath();
            ctx.moveTo(p[0].x, p[0].y);
            ctx.lineTo(p[1].x, p[0].y);
            ctx.lineTo(p[1].x, p[1].y);
            ctx.lineTo(p[0].x, p[1].y);
            ctx.closePath();
            if(fill_color !== null) {
                ctx.fillStyle = fill_color;
                ctx.fill();
            }
            ctx.stroke();
            ctx.restore();
        },
        _doChooseDraw : function(ctx, choose_clr) {
            this._doDraw(ctx, this.fill_color !== null ? choose_clr : null);
        },
        _doSelectDraw : function(ctx) {
            this._doDraw(ctx, null);
        }

    };
    $.inherit(Doodle._RectDoodle, Doodle._MatrixDoodle);

    Doodle._EllipseDoodle = function(data) {
        this.center = {
            x : 0,
            y : 0
        };
        this.radius = {
            a : 0,
            b : 0
        };
        this.base(Doodle.Type.ELLIPSE, data);
    };
    Doodle._EllipseDoodle.prototype = {

        _calc : function() {
            var p = this.points;
            this.center.x = Math.round((p[0].x+p[1].x)/2);
            this.center.y = Math.round((p[0].y+p[1].y)/2);

            this.radius.a = Math.round(Math.abs(p[0].x-p[1].x)/ 2);
            this.radius.b = Math.round(Math.abs(p[0].y-p[1].y)/ 2);
            this.callBase("_calc");
        },
        _doDraw : function(ctx, fill_color) {
            ctx.save();
            ctx.transform(this.matrix[0], this.matrix[3], this.matrix[1], this.matrix[4], this.matrix[2], this.matrix[5]);
            $.drawEllipse(ctx, this.center.x, this.center.y, this.radius.a, this.radius.b, fill_color);
            ctx.restore();
        },
        _doChooseDraw : function(ctx, choose_clr) {
            this._doDraw(ctx, this.fill_color !== null ? choose_clr : null);
        },
        _doSelectDraw : function(ctx) {
            this._doDraw(ctx, null);
        }
    };
    $.inherit(Doodle._EllipseDoodle, Doodle._MatrixDoodle);

})(Diigo.Doodle, Diigo.UndoRedo, Diigo.$);

(function(Text, Doodle, UR, $) {

	Doodle._TextboxDoodle = function(data){
        if(data.points.length===1) {
            data.points.push({
                x : data.points[0].x,
                y : data.points[0].y
            });
        }
        this.base(Doodle.Type.TEXT, data);

        this.editor = this.drawer.textbox_editor;
        this.matrix = [1,0,0,0,1,0,0,0,0];
        this.pre_matrix = $.copyArray(this.matrix);
        this.editor_matrix = $.copyArray(this.matrix);


        this.style = data.style ? data.style : new Text._Style(this.drawer.style);

        this.page_idx = this.editor.createPage(this.style);

        this.actived = false;
        this.auto_width = data.auto_width !== false;
        this.size = {width: 0, height : 0};
        this.center = {x : 0, y: 0};
        this.rotate_point = {
            x : 0,
            y : 0
        };

        this._ur_timeout = null;
        this._ur_value = this.editor.getPageByIdx(this.page_idx).text;
        this._ur_handler = $.createDelegate(this, this._deal_ur);
        this._calc();

	};
	Doodle._TextboxDoodle.prototype = {
        afterUndoRedo : function() {
            this._calc();
            if(this.actived) {
                this.resetOutline();
            } else if(this.drawer.cur_textbox !== null && this.drawer.cur_textbox !== this) {
                this.drawer.unactiveTextbox();
            }
            this.drawer._select_doodle(this);
        },
        getRotatePoint : function() {
            return this.rotate_point;
        },
        getMoveUndoCommand : function() {
            return new UR._DoodleMatrixCommand(this);
        },
        getRegionUndoCommand : function() {
            return new UR._DoodlePointsCommand(this);
        },
        getRotateUndoCommand : function() {
            return new UR._DoodleMatrixCommand(this);
        },
        setURText : function(txt) {
            var p = this.editor.getPageByIdx(this.page_idx);
            p.text = txt;
            p.initParagraph();



            if(this.actived) {
                if(this.auto_width) {
                    this._calc_text_outline(txt);
                }

                this.editor.textarea.value = txt;
                this.editor.textarea.focus();
            }
        },
        setColor : function(clr) {
            this.style.color = clr;
            this.editor.textarea.style.color = this.style.color;
        },
        setFontName : function(fn) {
            this.style.setFontName(fn);
            this._resetFont();
        },
        setFontSize : function(fs){
            this.style.setFontSize(fs);
            this._resetFont();
        },
        _resetFont : function() {
            var fnt = this.style.getScaleFont(this.drawer.zoom_scale);
            if(this.actived) {
                this.editor.cur_page.resetFont();
                this.editor.textarea.style.font = fnt;
                this.editor.textarea.style.lineHeight = $.getFontInfo(fnt).height + 'px';
                this.onTextInput(this.editor.textarea.value);
            } else {
                var pg = this.editor.getPageByIdx(this.page_idx);
                pg.resetFont();
                if(this.auto_width) {
                    this._calc_text_outline(pg.text);
                } else {
                    var ed = this.editor;
                    ed.save_state();
                    ed._setCurPage(this.page_idx);
                    pg.initParagraph();
                    ed.restore_state();
                }

                this.drawer.edit_doodle._re_attach_doodle();
                this.drawer._paintEditLayer();
            }
        },

        initialize : function() {
            var ps = this.points;
            if(ps[1].y < ps[0].y) {
                var tp = ps[0];
                ps[0] = ps[1];
                ps[1] = tp;
            }
            if(ps[1].x<ps[0].x) {
                var _x = ps[0].x;
                ps[0].x = ps[1].x;
                ps[1].x = _x;
            }

            var p_h = this.editor.getPageHeight(this.page_idx);

            if(this.auto_width) {
                this.size.width = 20;
                this.size.height = p_h;
            } else {
                this.size.width = Math.max(20, ps[1].x - ps[0].x);
                this.size.height = Math.max(50, ps[1].y - ps[0].y);
            }


            this.matrix[2] = ps[0].x;
            this.matrix[5] = ps[0].y;
            ps[0].x = 0;
            ps[0].y = 0;
            ps[1].x = this.size.width;
            ps[1].y = this.size.height;
            this.initialized = true;
            this._setAutoWidth(this.auto_width);
            this._calc();
            this.resetOutline();

        },
        _setAutoWidth : function(auto) {
            this.editor.setBoxAutoWidth(auto);
        },


        editStart : function() {
            $.setArray(this.pre_matrix, this.matrix);
        },

        editMove : function(dx, dy) {
            this.matrix[2] = this.pre_matrix[2] + dx;
            this.matrix[5] = this.pre_matrix[5] + dy;
            this._calc();
        },
        move : function(dx, dy) {
            this.matrix[2] += dx;
            this.matrix[5] += dy;
            this._calc();
        },
        rotateScale : function(relay_point, rotate, scale) {

            $.setArray(this.pre_matrix, this.matrix);

            this.editRotateScale(relay_point, rotate, scale);
        },
        editRotateScale : function(relay_point, rotate, scale) {
            if(!this.is_rotating) {
                this.is_rotating = true;
            }
            var m = this.matrix, pm = this.pre_matrix, s = Math.sin(rotate), c = Math.cos(rotate), x = relay_point.x, y = relay_point.y;
            m[0] = c * pm[0] - s * pm[3];
            m[1] = c * pm[1] - s * pm[4];
            m[2] = c * pm[2] - s * pm[5] - c * x + s * y + x;
            m[3] = s * pm[0] + c * pm[3];
            m[4] = s * pm[1] + c * pm[4];
            m[5] = s * pm[2] + c * pm[5] - s * x - c * y + y;

            this._calc();

            if(this.actived) {
                this.resetMatrix();
                this._resetSize();
            }
        },
        editPushPoint : function(point) {
            //do nothing;
        },
        _calc_editor_matrix : function() {

            var m = this.matrix,
                em = this.editor_matrix,
                _s = this.drawer.zoom_scale,
                cx = (this.center.x - this.drawer.bg_info.x) * _s,
                cy = (this.center.y - this.drawer.bg_info.y) * _s;

            var scale = Math.sqrt(m[0] * m[4] - m[1] * m[3]) * _s;


            /*
             * 相当于先把矩形移动到中心点，再旋转。
             */
             $.setArray(em, [1,0,0,0,1,0,0,0,0]);
             em[2] = cx - this.size.width * scale / 2;
             em[5] = cy - this.size.height * scale / 2;

            /*
             * 旋转的角度计算公式，参考http://stackoverflow.com/questions/16359246/how-to-extract-position-rotation-and-scale-from-matrix-svg
             */
            var r = Math.atan2(m[4], m[1]) - Math.PI / 2;
            var c = Math.cos(r), s = Math.sin(r);
            var x0 = c * em[0] - s * em[3];
            var x1 = c * em[1] - s * em[4];
            var x2 = c * em[2] - s * em[5] - c * cx  + s * cy + cx;
            var x3 = s * em[0] + c * em[3];
            var x4 = s * em[1] + c * em[4];
            var x5 = s * em[2] + c * em[5] - s * cx - c * cy + cy;
            em[0] = x0;
            em[1] = x1;
            em[2] = x2;
            em[3] = x3;
            em[4] = x4;
            em[5] = x5;
        },
        resetScale : function() {
            this._calc_editor_matrix();
            this.resetOutline();
            this.resetFont();
        },
        resetFont : function() {
            var m = this.matrix;
            var scale = Math.sqrt(m[0] * m[4] - m[1] * m[3]) * this.drawer.zoom_scale;
            this.editor.textarea.style.font = this.editor.cur_page.style.getScaleFont(scale);
        },
        resetOutline : function() {
            if(!this.actived) {
                return;
            }
            this._resetSize( );
            this.editor.setBoxMatrix(this.editor_matrix);
        },

        _resetSize : function() {
            var m = this.matrix;
            var svalue = Math.sqrt(m[0] * m[4] - m[1] * m[3]) * this.drawer.zoom_scale;

            var n_w = this.size.width ,
                n_h = this.size.height;
//
            this.editor.setBoxSize_scale(n_w, n_h, svalue);
//            $.log(n_w + ","+n_h);
        },
        _setDrawSize : function() {
            var m = this.matrix;
            var svalue = Math.sqrt(m[0] * m[4] - m[1] * m[3]) * this.drawer.zoom_scale;

            var n_w = this.size.width ,
                n_h = this.size.height;
            this.editor.set_drawtext_size(n_w, n_h, svalue);
        },
        _calc_text_outline : function(txt) {
            var ed = this.editor;
            var paras = txt.split('\n');
            var max_width = 20;
            var ctx = ed.render.ctx;
            var ps = this.points;
            ctx.save();
            ctx.font = ed.cur_page.style.font;
            for(var i=0;i<paras.length;i++) {
                var w = ctx.measureText(paras[i]).width;
                if(max_width < w) {
                    max_width = w;
                }
            }
            ctx.restore();
            var height = ed.cur_page.line_height * paras.length;
            this.size.width = Math.ceil(max_width) + 5;
            this.size.height = Math.ceil(height);
            ps[1].x = this.size.width;
            ps[1].y = this.size.height;

            this._resetSize();

            this._calc();
        },
        onTextInput : function(txt) {
            if(this.auto_width) {
                this._calc_text_outline(txt);
                this.drawer.edit_doodle._re_attach_doodle();
                this.drawer._paintEditLayer();
            }

        },
        resetMatrix : function() {
            this.setBoxMatrix(this.editor_matrix);
        },
        setBoxMatrix : function(m) {
            this.editor.setBoxMatrix(m);
        },

        _calc : function(no_calc_matrix) {
            var m = this.matrix, p = this.points, x1, x2, x3, x4, y1, y2, y3, y4;
            var rx = (p[0].x + p[1].x) / 2,
                ry = (Math.min(p[0].y, p[1].y) - 20);

            x1 = m[0] * p[0].x + m[1] * p[0].y + m[2];
            y1 = m[3] * p[0].x + m[4] * p[0].y + m[5];
            x2 = m[0] * p[1].x + m[1] * p[0].y + m[2];
            y2 = m[3] * p[1].x + m[4] * p[0].y + m[5];
            x3 = m[0] * p[1].x + m[1] * p[1].y + m[2];
            y3 = m[3] * p[1].x + m[4] * p[1].y + m[5];
            x4 = m[0] * p[0].x + m[1] * p[1].y + m[2];
            y4 = m[3] * p[0].x + m[4] * p[1].y + m[5];

            var mx = (p[0].x+p[1].x)/ 2, my = (p[0].y+p[1].y)/2;

            this.center.x = Math.floor(m[0] * mx + m[1] * my + m[2]);
            this.center.y = Math.floor(m[3] * mx + m[4] * my + m[5]);

            this.rotate_point.x = Math.floor(m[0] * rx + m[1] * ry + m[2]);
            this.rotate_point.y = Math.floor(m[3] * rx + m[4] * ry + m[5]);

            this._calc_2(Math.min(x1,x2,x3,x4), Math.min(y1,y2,y3,y4), Math.max(x1,x2,x3,x4),Math.max(y1,y2,y3,y4));

            if(!no_calc_matrix) {
                this._calc_editor_matrix();
            }
        },
        _deal_ur : function() {
//            $.log('check ttt')
            var nt = this.editor.textarea.value;
            if(this._ur_value !== nt) {
//                $.log('add text undo/redo');
                this.drawer.history.add(new UR._DoodleTextCommand(this, this._ur_value, nt));
                this._ur_value = nt;
            }
        },
        onTextPress : function() {
            if(this._ur_timeout !== null) {
                window.clearTimeout(this._ur_timeout);
            }
            this._ur_timeout = window.setTimeout(this._ur_handler, 300);
        },
		active : function(){
            this._doActive();
            this.editor.textarea.style.color = this.style.color;
		},

        _doActive : function() {
            //这两行代码顺序不能反。先active=true再drawer.paint()
            this.actived = true;
            this.drawer.paint();

            this.editor.floated_textbox = this;
            this.editor.setCurPage(this.page_idx);

            this._setAutoWidth(this.auto_width);
//            $.log("active: " + this.page_idx);
            this.resetOutline();
            var ed = this.editor;
            ed.show();
            ed.focus();
        },
		unactive : function(){
            this.actived = false;
            var ed = this.editor;
            ed.blur();
            ed.hide();
            //如果当前文本框没有文字，则应该删除该文本框
            if(ed.textarea.value.trim()==="") {
                this.drawer.delTextbox(this);
            } else {
//                $.log('unactive: ' + this.page_idx);
                ed.cur_page.text = ed.textarea.value;
                ed.cur_page.initParagraph();
            }
		},
        _doDraw : function(ctx, fill_color, stroke_color) {
            var p = this.points;
            ctx.save();
            ctx.lineWidth = 2;
            $.setLineDash(ctx, [6, 5]);
            ctx.transform(this.matrix[0], this.matrix[3], this.matrix[1], this.matrix[4], this.matrix[2], this.matrix[5]);
            ctx.beginPath();
            ctx.moveTo(p[0].x, p[0].y);
            ctx.lineTo(p[1].x, p[0].y);
            ctx.lineTo(p[1].x, p[1].y);
            ctx.lineTo(p[0].x, p[1].y);
            ctx.closePath();
            if(fill_color) {
                ctx.fillStyle = fill_color;
                ctx.fill();
            } else if(stroke_color) {
                ctx.strokeStyle = stroke_color;
                ctx.stroke();
            }
            ctx.restore();
        },
        draw_select : function(ctx, selected_color) {
            //draw nothing
            if(!this.actived) {
                this._draw_text(ctx);
            }
            this._doDraw(ctx, null, this.style.color);

        },
        _doChooseDraw : function(ctx, choose_clr) {
            this._doDraw(ctx, choose_clr, null);
        },
        _draw_text : function(ctx) {
            var em = this.editor_matrix;
            var ed = this.editor;
            ed.save_state();
            ctx.save();
            ctx.setTransform(1, 0, 0, 1, 0, 0);
            ctx.transform(em[0], em[3], em[1], em[4], em[2], em[5]);
            ed._setCurPage(this.page_idx);
//            $.log('draw text: ' + ed.cur_page.text);

            this._setDrawSize();
            this.editor.render.paintToContext(ctx, this.style);
            ctx.restore();

            ed.restore_state();
//            $.log('aft: ' + ed.cur_page.text);
        },
		draw : function(ctx) {
            if(!this.initialized) {
                this._doDraw(ctx, null, this.style.color);
            } else if(!this.actived) {
                this._draw_text(ctx);
            } else if(this.actived) {
                this._doDraw(ctx, null, this.style.color);
            }
		}
	};
	$.inherit(Doodle._TextboxDoodle, Doodle._Doodle);
	


})(Diigo.Text, Diigo.Doodle, Diigo.UndoRedo, Diigo.$);

(function(Doodle, $) {

    Doodle._RectBlurDoodle = function(data) {
        if(data.points.length === 1) {
            data.points.push({
                x : data.points[0].x,
                y : data.points[0].y
            });
        }
        data.pen_width = 2;
        data.region_points = $.genPoints(4);
        this.base(Doodle.Type.RECT_BLUR, data);

        this._create_edit_region();
    };
    Doodle._RectBlurDoodle.prototype = {
        onRegionEdit : function(idx, p) {
            var x = p.x,
                y = p.y;
            var p0 = this.points[0],
                p1 = this.points[1];
            switch (idx) {
                case 0:
                    p0.x = x;
                    p0.y = y;
                    break;

                case 1:
                    p1.x = x;
                    p0.y = y;
                    break;

                case 2:
                    p1.x = x;
                    p1.y = y;
                    break;

                case 3:
                    p0.x = x;
                    p1.y = y;
                    break;

            }
            this._calc();
        },
        _calc : function() {
            var p = this.points, rp = this.region_points;
            rp[0].x = p[0].x;
            rp[0].y = p[0].y;

            rp[1].x = p[1].x;
            rp[1].y = p[0].y;

            rp[2].x = p[1].x;
            rp[2].y = p[1].y;

            rp[3].x = p[0].x;
            rp[3].y = p[1].y;

            this._calc_1(this.points);
        },
        draw : function(ctx) {
                var b = this.boundary;
                var s = this.drawer.zoom_scale;
                var ox = this.drawer.bg_info.x,
                    oy = this.drawer.bg_info.y;

                var x = Math.floor((b.left - ox) * s),
                    y = Math.floor((b.top - oy) * s),
                    w = Math.floor(b.width * s),
                    h = Math.floor(b.height * s);
                if(w>0 && h>0) {
                    $.stackBlurCanvasRGBA(ctx, x, y, w, h, Math.floor(7 * this.drawer.zoom_scale));
                }
        },
        draw_blur : function(ctx, buffered_image) {
            var b_ctx = this.drawer.b_ctx;
            ctx.save();
            ctx.setTransform(1, 0, 0, 1, 0, 0);
            b_ctx.save();
            b_ctx.setTransform(1, 0, 0, 1, 0, 0);

            var b = this.boundary;
            var s = this.drawer.zoom_scale;
            var ox = this.drawer.bg_info.x,
                oy = this.drawer.bg_info.y;
            var x = Math.floor((b.left - ox) * s),
                y = Math.floor((b.top - oy) * s),
                w = Math.floor(b.width * s),
                h = Math.floor(b.height * s);

            if(w>0 && h>0) {
//                ctx.drawImage(buffered_image, x, y, w, h, x, y, w, h);
                b_ctx.drawImage(this.drawer.doodle_canvas, x, y, w, h, x, y, w, h);
                $.stackBlurCanvasRGBA(b_ctx, x, y, w, h, Math.floor(7 * this.drawer.zoom_scale));
                ctx.drawImage(this.drawer.blur_canvas, x, y, w, h, x, y, w, h);

            }
//
            ctx.restore();
            b_ctx.restore();
//

            ctx.strokeStyle = "rgba(0, 0, 0, 0.6)";
            ctx.lineWidth = Math.floor(2 * s);
            $.setLineDash(ctx, [4 * s, 4* s]);
            this._doDraw(ctx);
        },
        _doDraw : function(ctx, fill_color) {
            var p = this.points;
            ctx.save();
            ctx.beginPath();
            ctx.moveTo(p[0].x, p[0].y);
            ctx.lineTo(p[1].x, p[0].y);
            ctx.lineTo(p[1].x, p[1].y);
            ctx.lineTo(p[0].x, p[1].y);
            ctx.closePath();
            if(fill_color) {
                ctx.fillStyle = fill_color;
                ctx.fill();
            }
            ctx.stroke();
            ctx.restore();
        },
        _doChooseDraw : function(ctx, choose_color) {
            this._doDraw(ctx, choose_color);
        },
        draw_select : function(ctx) {
            this.draw_blur(ctx, this.drawer.blur_canvas);
        },

        editPushPoint : function(point) {
            this.points[1].x = point.x;
            this.points[1].y = point.y;
            this._calc();
        }
    };
    $.inherit(Doodle._RectBlurDoodle, Doodle._CommonDoodle);

})(Diigo.Doodle, Diigo.$);
(function(Doodle,UR, $) {
    Doodle._CutDoodle = function(data) {
        if(data.points.length === 1) {
            data.points.push({
                x : data.points[0].x,
                y : data.points[0].y
            });
        }

        this.base(Doodle.Type.CUT, data);
        this.pre_points = $.copyPoints(this.points);
        this.region_points = $.genPoints(8);
        this.dash_value = [3, 3];
        this.resetScale();
        this._create_edit_region();

        this.__point_in__ = false;
    };
    Doodle._CutDoodle.prototype = {
//        getMoveUndoCommand : function() {
//            return new UR._DoodlePointsCommand(this);
//        },
//        getRegionUndoCommand : function() {
//            return new UR._DoodlePointsCommand(this);
//        },
        setSize : function(width, height) {
            var p0 = this.points[0], p1 = this.points[1];
            if(p0.x < p1.x) {
                p1.x = p0.x + width;
            } else {
                p0.x = p1.x + width;
            }
            if(p0.y < p1.y) {
                p1.y = p0.y + height;
            } else {
                p0.y = p1.y + height;
            }
            this._calc();
        },
        _size_callback:function() {
            var p = this.points;
            var w = Math.abs(p[1].x - p[0].x),
                h = Math.abs(p[1].y - p[0].y);
            var l = Math.min(p[0].x, p[1].x),
                t = Math.min(p[0].y, p[1].y);
            var bi = this.drawer.bg_info,
                mw = bi.x + bi.width - l,
                mh = bi.y + bi.height - t;
            this.drawer.style_callback("crop", {
                left: l,
                top : t,
                width: w,
                height: h,
                max_width: mw,
                max_height : mh
            });
        },
        checkPointIn : function(x, y) {
            var b = this.boundary;
            var OFF = 10;
            var is_in =  x >= b.left + OFF && x <= b.right - OFF && y >= b.top + OFF && y<= b.bottom + OFF;
            if(is_in && !this.__point_in__) {
                this.__point_in__ = true;
                this.drawer.setCursor_name("cursor_move");
            } else if(!is_in && this.__point_in__) {
                this.__point_in__ = false;
                this.drawer.setCursor_name("cursor_default");
            }
        },
        onRegionEdit : function(idx, p) {
            var x = p.x,
                y = p.y;
            var p0 = this.points[0],
                p1 = this.points[1];
            switch (idx) {
                case 0:
                    p0.x = x;
                    p0.y = y;
                    break;
                case 1:
                    p0.y = y;
                    break;
                case 2:
                    p1.x = x;
                    p0.y = y;
                    break;
                case 3:
                    p1.x = x;
                    break;
                case 4:
                    p1.x = x;
                    p1.y = y;
                    break;
                case 5:
                    p1.y = y;
                    break;
                case 6:
                    p0.x = x;
                    p1.y = y;
                    break;
                case 7:
                    p0.x = x;
                    break;
            }
            this._calc();
            this._size_callback();
        },
        resetScale : function() {
            var d = Math.round(3 * this.drawer.zoom_scale);
            this.dash_value[0] = d;
            this.dash_value[1] = d;
        },

        _calc : function() {
            var p = this.points, rp = this.region_points;
            rp[0].x = p[0].x;
            rp[0].y = p[0].y;
            rp[1].x = Math.floor((p[0].x+p[1].x)/2);
            rp[1].y = p[0].y;
            rp[2].x = p[1].x;
            rp[2].y = p[0].y;
            rp[3].x = p[1].x;
            rp[3].y = Math.floor((p[0].y+p[1].y)/2);
            rp[4].x = p[1].x;
            rp[4].y = p[1].y;
            rp[5].x = Math.floor((p[0].x+p[1].x)/2);
            rp[5].y = p[1].y;
            rp[6].x = p[0].x;
            rp[6].y = p[1].y;
            rp[7].x = p[0].x;
            rp[7].y = Math.floor((p[0].y+p[1].y)/2);

            this._calc_1(this.points);
        },
        editPushPoint : function(point) {
            this.points[1].x = point.x;
            this.points[1].y = point.y;
            this._calc();
            this._size_callback();
        },
        _create_edit_region : function() {
            for(var i=0;i<this.region_points.length;i++) {
                this.edit_regions.push(new Doodle.CircleRegion(this, i, this.region_points[i], 7, 'pointer'));
            }
        },
        editMove : function(dx, dy) {
            for(var i = 0; i < this.points.length; i++) {
                this.points[i].x = this.pre_points[i].x + dx;
                this.points[i].y = this.pre_points[i].y + dy;
            }
            this._calc();
        },
        move : function(dx, dy) {
            for(var i = 0; i < this.points.length; i++) {
                this.points[i].x += dx;
                this.points[i].y += dy;
            }
            this._calc();
        },
        editStart : function() {
            $.setPoints(this.pre_points, this.points);
        },
        editFinish : function() {
           this._calc();
           this._size_callback();
        },
        draw : function(ctx) {
            var p = this.points;

            ctx.save();
            $.setLineDash(ctx, this.dash_value);
            ctx.beginPath();
            ctx.moveTo(p[0].x, p[0].y);
            ctx.lineTo(p[1].x, p[0].y);
            ctx.lineTo(p[1].x, p[1].y);
            ctx.lineTo(p[0].x, p[1].y);
            ctx.closePath();

            ctx.save();
            ctx.fillStyle = "black";
            ctx.globalCompositeOperation = "destination-out";
            ctx.fill();
            ctx.restore();

            ctx.strokeStyle = "rgba(0, 128, 255, 0.9)";
            ctx.lineWidth = Math.floor(2 / this.drawer.zoom_scale);
            ctx.stroke();

            ctx.restore();
        },
        _doDraw : function(ctx) {
            var p = this.points;
            ctx.beginPath();
            ctx.moveTo(p[0].x, p[0].y);
            ctx.lineTo(p[1].x, p[0].y);
            ctx.lineTo(p[1].x, p[1].y);
            ctx.lineTo(p[0].x, p[1].y);
            ctx.closePath();
            ctx.fill();
        }
    };
    $.inherit(Doodle._CutDoodle, Doodle._Doodle);

})(Diigo.Doodle, Diigo.UndoRedo, Diigo.$);
(function(Doodle, UR, $) {
    var FONT_FAMILY = 'Arial';

    Doodle._ListDoodle = function(data) {
        this.center = data.points[0];

        var LI = Doodle._ListDoodle.__LAST_INFO__;
        data.color = LI.color;
//        data.matrix = $.copyArray(LI.matrix);
        data.points = [{x:0, y: 0}, {x:0, y:0}];

        this.radius = {
            a : LI.radius.a,
            b : LI.radius.b
        };
        this._calc_points(data.points);
        this.i_value = LI.getValue();
        this.i_type = LI.i_type;
        this.i_str = '';
        this._get_i_str();

        var clr = $.str2rgba(data.color);
        var bv = 0.299*clr.r+0.587*clr.g+0.114*clr.b;
        this.font_color = bv > 200 ? $.rgba2str(0, 0, 0, clr.a) : $.rgba2str(255, 255, 255, clr.a);
        this.border_color = $.rgba2str(255, 255, 255, clr.a);
        this.font = '';

        this.base(Doodle.Type.LIST, data);

        this._pre_rp = {x: 0, y: 0};
    };
    Doodle._ListDoodle.__LAST_INFO__ = {
        'radius' : {
            a : 20,
            b : 20
        },
        'i_type' : 'number',
        'i_value' : 1,
        'color' : '#000',
        'cursor_cache' : {},
        'getValue' : function() {
            return this.i_value++;
        },
        'getCursor' : function() {
            var cur = this.cursor_cache[this.i_value];
            if(typeof cur === 'undefined') {
                cur = $.getListCursor(this.i_value);
                this.cursor_cache[this.i_value] = cur;
            }
            return cur;
        },
        'reset' : function() {
            this.i_type = 'number';
            this.i_value = 1;
            this.radius.a = 20;
            this.radius.b = 20;

        }
    };
    Doodle._ListDoodle.__WIDTH_CACHE__ = {
        'w_table' : {},
        'h_table' : {},
        'get_w' : function(str, font_size, ctx) {
            var _t = this.w_table[str];
            if(typeof _t === 'undefined') {
                _t ={};
                this.w_table[str] = _t;
            }
            var _w = _t[font_size];
            if(typeof _w === 'undefined') {
                ctx.save();
                ctx.font = font_size + 'px ' + FONT_FAMILY;
                _w = ctx.measureText(str).width;
                ctx.restore();
                _t[font_size] = _w;
            }
            return _w;
        },
        'get_h' : function(font_size) {
            var _h = this.h_table[font_size];
            if(typeof _h === 'undefined') {
                _h = Math.floor($.getFontInfo(font_size + 'px ' + FONT_FAMILY).height);
                this.h_table[font_size] = _h;
            }
            return _h;
        }
    };
    Doodle._ListDoodle.prototype = {
        setPenWidth : function() {
            //do nothing
        },
        setColor : function(clr) {
            this.color = clr;
            var rgba = $.str2rgba(this.color);
            var bv = 0.299*rgba.r+0.587*rgba.g+0.114*rgba.b;
            this.font_color = bv > 200 ? $.rgba2str(0, 0, 0, rgba.a) : $.rgba2str(255, 255, 255, rgba.a);
            this.border_color = $.rgba2str(255, 255, 255, rgba.a);
        },
        set_i_value : function(val) {
            this.i_value = val;
            this._get_i_str();
            this._calc_font();

            this.drawer._paintEditLayer();
        },
        _get_i_str : function() {
            //以后可以支持a-z,罗马数字等。
            switch (this.i_type) {
                case 'number':
                    this.i_str = this.i_value.toString();
                    break;
            }
        },
        _calc_font : function() {
            var _ma = Math.asin(1) / 2,
                _mx = this.radius.a * Math.cos(_ma),
                _my = this.radius.b * Math.sin(_ma);

            var WC = Doodle._ListDoodle.__WIDTH_CACHE__;
            var W = Math.floor(_mx * 2),
                H = Math.floor(_my * 2);
            var max_fs = 100;
            var str = this.i_str, ctx = this.drawer.t_ctx;
            while(WC.get_w(str, max_fs, ctx) < W && WC.get_h(max_fs) < H) {
                max_fs *= 2;
            }

            //使用二分法获取适当的字体。
            function c_w(min, max, type) {
                var mid = Math.floor((max + min) / 2);
                var V = type === 'w' ? W : H;
                while(true) {
                    if(max - mid <= 1) {
                        return mid;
                    }
                    var mw = type === 'w' ? WC.get_w(str, mid, ctx) : WC.get_h(mid);

                    if(mw > V) {
                        max = mid;
                    } else if(mw < V) {
                        min = mid;
                    } else {
                        return mid;
                    }
                    mid = Math.floor((max + min) / 2);
                }
            }

            if(WC.get_w(str, max_fs, ctx) > W) {
                max_fs = c_w(1, max_fs, 'w');
            }
//            $.log("ma: " + max_fs + "," + WC.get_h(max_fs));
            if(WC.get_h(max_fs) > H) {
                max_fs = c_w(1, max_fs, 'h');
            }

            this.font = max_fs + 'px ' + FONT_FAMILY;

        },
        _calc_points : function(ps) {
            var    c = this.center,
                r = this.radius;
            ps[0].x = c.x - r.a;
            ps[0].y = c.y - r.b;
            ps[1].x = c.x + r.a;
            ps[1].y = c.y + r.b;
        },
        onRegionEdit : function(idx, p) {
//
            var ps = this.points;
            this._onRegionEdit(idx, p, ps);
            var a = Math.round(Math.abs(ps[0].x-ps[1].x)/ 2),
                b = Math.round(Math.abs(ps[0].y-ps[1].y)/ 2);

            this.radius.a = this.radius.b = Math.min(a, b);
            this._calc_points(this.points);
            this._calc();

            this.drawer.edit_doodle.attachDoodle(this);
        },
        onRegionEditStart : function(idx, p) {
            this._pre_rp.x = p.x;
            this._pre_rp.y = p.y;
        },
        onRegionEditFinish : function(idx, p) {
            var DI = Doodle._ListDoodle.__LAST_INFO__;
            DI.radius.a = this.radius.a;
            DI.radius.b = this.radius.b;
        },
        _calc : function() {
            var p = this.points;
            this.center.x = Math.round((p[0].x+p[1].x)/2);
            this.center.y = Math.round((p[0].y+p[1].y)/2);

            this.radius.a = Math.round(Math.abs(p[0].x-p[1].x)/ 2);
            this.radius.b = Math.round(Math.abs(p[0].y-p[1].y)/ 2);

            this.callBase("_calc");

            this._calc_font();
        },
        _doDraw : function(ctx, fill_color) {
            ctx.save();
            ctx.transform(this.matrix[0], this.matrix[3], this.matrix[1], this.matrix[4], this.matrix[2], this.matrix[5]);
            $.drawEllipse(ctx, this.center.x, this.center.y, this.radius.a, this.radius.b, fill_color);
            ctx.restore();
        },
        draw : function(ctx) {
            var x = this.center.x, y = this.center.y,
                a = this.radius.a, b = this.radius.b;

            ctx.save();
            ctx.transform(this.matrix[0], this.matrix[3], this.matrix[1], this.matrix[4], this.matrix[2], this.matrix[5]);

            ctx.save();
//            ctx.strokeStyle = this.border_color;
            ctx.fillStyle = this.border_color;
            ctx.lineWidth = 4;
            ctx.shadowColor = "rgba(0, 0, 0, 0.4)";
            ctx.shadowOffsetX = 0;
            ctx.shadowOffsetY = 2;
            ctx.shadowBlur = 4;
            ctx.beginPath();
            ctx.ellipse(x, y, a + 4, b + 4, 0, 0, Math.PI * 2, 0);
            ctx.closePath();
            ctx.fill();
            ctx.restore();

            ctx.fillStyle = this.color;
            ctx.beginPath();
            ctx.ellipse(x, y, a, b, 0, 0, Math.PI * 2, 0);
            ctx.closePath();
            ctx.fill();

            ctx.font = this.font;
            ctx.fillStyle = this.font_color;
            ctx.textAlign = 'center';
            ctx.textBaseline = 'middle';
            ctx.fillText(this.i_str, this.center.x, this.center.y);

            ctx.restore();
        },
        _doChooseDraw : function(ctx, choose_clr) {
            this._doDraw(ctx, choose_clr);
        },
        _doSelectDraw : function(ctx) {
//            this._doDraw(ctx, null);
        },
        editPushPoint : function(point) {
            //do nothing
        }
    };
    $.inherit(Doodle._ListDoodle, Doodle._MatrixDoodle);
})(Diigo.Doodle, Diigo.UndoRedo, Diigo.$);
(function(Doodle,UR, $) {

Doodle._BezierArrowDoodle = function(data) {
    if(data.points.length === 1) {
        data.points.push({x:0, y: 0},{x:0,y:0},{
            x : data.points[0].x,
            y : data.points[0].y
        });
    } else if(data.points.length === 2) {
        data.points.splice(1, 0, {x: 0, y: 0}, {x:0, y:0});
    }

    this.rotate_point = {
        x : 0,
        y : 0
    };
    this.arrow_info = {
        idx : 0,
        pos : {

        }
    };
    this.base(Doodle.Type.BEZIER_ARROW, data);
    this.region_points = this.points;
    this._create_edit_region();
};
Doodle._BezierArrowDoodle.prototype = {
    setPenWidth : function(pw) {
        this.callBase('setPenWidth', pw);
        this._calc_arrow();
    },
    _calc : function() {
        this._calc_1(this.points);
        this._calc_arrow();
    },
    draw : function(ctx) {

        var t_ctx = this.drawer.t_ctx;
        var bi = this.drawer.bg_info;

        t_ctx.save();
        t_ctx.fillStyle = this.color;
        t_ctx.strokeStyle = this.color;
        t_ctx.lineWidth = this.pen_width;

        t_ctx.clearRect(bi.x, bi.y, bi.width, bi.height);

        this._doDraw(t_ctx);

        t_ctx.restore();

        ctx.save();
        ctx.setTransform(1,0,0,1,0,0);
        ctx.drawImage(t_ctx.canvas, 0, 0);
        ctx.restore();

    },
    _calc_arrow : function() {
        var ps = this.points;
        var A_LEN = this.pen_width * 5;
        this.arrow_info.idx = $.getPTPRange(ps[0], ps[3]) > A_LEN ? 1 : 0;
        this.arrow_info.pos =  $.calcArrow(ps[2].x, ps[2].y, ps[3].x, ps[3].y, A_LEN);
    },
    _doDraw : function(ctx, stroke) {
        var p = this.points;
        var ai = this.arrow_info;
        var pos = ai.pos;
        var _t = ai.idx === 0;

        ctx.beginPath();

        if(!_t) {

            ctx.moveTo(p[0].x, p[0].y);
            ctx.bezierCurveTo(p[1].x, p[1].y, p[2].x, p[2].y, ai.pos.cx, ai.pos.cy);

            if(stroke) {
                ctx.lineTo(pos.ax, pos.ay);
                ctx.lineTo(pos.dx, pos.dy);
                ctx.lineTo(pos.bx, pos.by);
                ctx.lineTo(pos.cx, pos.cy);
                ctx.stroke();
            } else {
                ctx.stroke();
                ctx.closePath();
                ctx.beginPath();
                ctx.moveTo(pos.ax, pos.ay);
                ctx.lineTo(pos.dx, pos.dy);
                ctx.lineTo(pos.bx, pos.by);
                ctx.closePath();
                ctx.save();
                ctx.globalCompositeOperation = "destination-out";
                ctx.fillStyle = "black";
                ctx.fill();
                ctx.restore();
                ctx.fill();
            }
        } else {
            ctx.beginPath();
            ctx.moveTo(pos.ax, pos.ay);
            ctx.lineTo(pos.dx, pos.dy);
            ctx.lineTo(pos.bx, pos.by);
            ctx.closePath();
            ctx.fill();
        }



    },
    _doSelectDraw : function(ctx) {
        var p = this.points;
        ctx.save();
        ctx.lineWidth = 2;
        $.setLineDash(ctx, [8, 5]);
        ctx.strokeStyle = this.highlight_color;
        ctx.shadowBlur = 3;
        ctx.shadowColor = "rgba(0,0,0,0.4)";
        ctx.shadowOffsetX = 0;
        ctx.shadowOffsetY = 1;
        ctx.beginPath();
        ctx.moveTo(p[0].x, p[0].y);
        ctx.lineTo(p[1].x, p[1].y);
        ctx.lineTo(p[2].x, p[2].y);
        ctx.lineTo(p[3].x, p[3].y);
        ctx.stroke();
        ctx.closePath();
        ctx.restore();

        this._doDraw(ctx, true);
    },
    _doChooseDraw : function(ctx, c) {
        this._doDraw(ctx, false);
    },
    editPushPoint : function(point) {
        var ps = this.points;
        ps[3].x = point.x;
        ps[3].y = point.y;
        var dx = Math.floor((ps[3].x - ps[0].x) / 3),
            dy = Math.floor((ps[3].y - ps[0].y) / 3);
        ps[1].x = ps[0].x + dx;
        ps[1].y = ps[0].y + dy;
        ps[2].x = ps[1].x + dx;
        ps[2].y = ps[1].y + dy;
        this._calc();
    },
    getRegionUndoCommand : function() {
        return new UR._DoodlePointsCommand(this);
    },
    onRegionEdit : function(idx, p) {
        this.points[idx].x = p.x;
        this.points[idx].y = p.y;
        this._calc();
        this.drawer.edit_doodle.attachDoodle(this);
    },
    onRegionEditFinish : function(idx, p) {
        this.drawer.edit_doodle.attachDoodle(this);
    }
};
$.inherit(Doodle._BezierArrowDoodle, Doodle._CommonDoodle);

})(Diigo.Doodle, Diigo.UndoRedo, Diigo.$);

(function(Doodle,UR, $) {




    /*
     * 普通笔画，包括Normal, line , diamond
     */
    Doodle._AnnotationDoodle = function(type, data) {
        this.base(type, data);

        this.matrix = data.matrix == null ? [1,0,0,0,1,0,0,0,0] : data.matrix;
        this.pre_matrix = $.copyArray(this.matrix);

        this.pre_points = $.copyPoints(this.points);
        this.rotate_point = {
            x : 0,
            y : 0
        };
        this.svg_width = data.svg_info.width;
        this.svg_height = data.svg_info.height;
        this.svg_shapes = data.svg_info.shapes;
        this._pre_svg();
        this.pre_svg_shapes = this._copy_svg_shapes();

        this.region_points = $.genPoints(8);

        this._calc();
        this._create_edit_region();

    };
    Doodle._AnnotationDoodle.prototype = {
        _copy_svg_shapes : function() {
            var rtn = [];
            for(var i=0;i<this.svg_shapes.length;i++) {
                var s= this.svg_shapes[i];
                var cs = {
                    'type' : s.type,
                    'cmd_arr' : []
                };
                for(var j=0;j< s.cmd_arr.length;j++) {
                    var _c = s.cmd_arr[j];
                    cs.cmd_arr.push({
                        command : _c.command,
                        points : $.copyArray(_c.points)
                    });
                }
                rtn.push(cs);
            }
            return rtn;
        },
        _pre_svg : function() {
            for(var i=0;i<this.svg_shapes.length;i++) {
                var s = this.svg_shapes[i];
                if(s.type === 'path') {
                    s.cmd_arr = $.parseSVGPath(s.data);
                }
            }
        },

//        getRotatePoint : function() {
//            return this.rotate_point;
//        },
        _create_edit_region : function() {
            var CUR = ['nwse-resize', 'ns-resize', 'nesw-resize', 'ew-resize', 'nwse-resize','ns-resize','nesw-resize','ew-resize'];
            for(var i=0;i<this.region_points.length;i++) {
                this.edit_regions.push(new Doodle.CircleRegion(this, i, this.region_points[i], 7, CUR[i]));
            }
        },
        onRegionEdit : function(idx, p) {
            var x = p.x,
                y = p.y;
            var p0 = this.points[0],
                p1 = this.points[1];
            switch (idx) {
                case 0:
                    p0.x = x;
                    p0.y = y;
                    break;
                case 1:
                    p0.y = y;
                    break;
                case 2:
                    p1.x = x;
                    p0.y = y;
                    break;
                case 3:
                    p1.x = x;
                    break;
                case 4:
                    p1.x = x;
                    p1.y = y;
                    break;
                case 5:
                    p1.y = y;
                    break;
                case 6:
                    p0.x = x;
                    p1.y = y;
                    break;
                case 7:
                    p0.x = x;
                    break;
            }
            this._calc();
        },
        _calc : function() {
            var p = this.points, rp = this.region_points;
            rp[0].x = p[0].x;
            rp[0].y = p[0].y;
            rp[1].x = Math.floor((p[0].x+p[1].x)/2);
            rp[1].y = p[0].y;
            rp[2].x = p[1].x;
            rp[2].y = p[0].y;
            rp[3].x = p[1].x;
            rp[3].y = Math.floor((p[0].y+p[1].y)/2);
            rp[4].x = p[1].x;
            rp[4].y = p[1].y;
            rp[5].x = Math.floor((p[0].x+p[1].x)/2);
            rp[5].y = p[1].y;
            rp[6].x = p[0].x;
            rp[6].y = p[1].y;
            rp[7].x = p[0].x;
            rp[7].y = Math.floor((p[0].y+p[1].y)/2);

            this._calc_1(this.points);
            this._calc_svg();

            var b = this.boundary;
            this.rotate_point.x = Math.floor(b.left + b.width / 2);
            this.rotate_point.y = b.top - 20;

        },
        _calc_svg : function() {
            var ps = this.points,
                ox = Math.min(ps[0].x, ps[1].x),
                oy = Math.min(ps[0].y, ps[1].y),
                ow = Math.abs(ps[0].x - ps[1].x),
                oh = Math.abs(ps[0].y - ps[1].y);
            var s, carr, parr;
            var p_s, p_carr, p_parr;
            var rx = ow / this.svg_width,
                ry = oh / this.svg_height;

            for(var i=0;i<this.svg_shapes.length;i++) {
                s = this.svg_shapes[i];
                p_s = this.pre_svg_shapes[i];
                if(s.type === 'path') {
                    carr = s.cmd_arr;
                    p_carr = p_s.cmd_arr;
                    for(var j=0;j<carr.length;j++) {
                        parr = carr[j].points;
                        p_parr = p_carr[j].points;

                        for(var k=0; k<parr.length; k+=2) {
                            parr[k] = ox + p_parr[k] * rx;
                            parr[k+1] = oy + p_parr[k+1] * ry;
                        }

                    }

                }
            }
//            $.log('kll jljl');
        },
        _draw_path : function(ctx, path) {
            ctx.save();

            ctx.beginPath();

            var arr = path.cmd_arr;
            var cmd, ps;
            for(var i=0;i<arr.length;i++) {
                cmd = arr[i];
                ps = cmd.points;
                switch (cmd.command) {
                    case 'M':
                        ctx.moveTo(ps[0], ps[1]);
                        break;
                    case 'C':
                        ctx.bezierCurveTo(ps[0], ps[1], ps[2], ps[3], ps[4], ps[5]);
                        break;
                    case 'Q':
                        ctx.quadraticCurveTo(ps[0], ps[1], ps[2], ps[3]);
                        break;
                    case 'L':
                        ctx.lineTo(ps[0], ps[1]);
                        break;
                    case 'Z':
                        ctx.closePath();
                }
            }

            ctx.fill();

            ctx.restore();
        },
        _doDraw : function(ctx, fill_color, has_shadow) {

            ctx.fillStyle = fill_color;

            for(var i=0;i<this.svg_shapes.length;i++) {
                var s = this.svg_shapes[i];
                switch (s.type) {
                    case 'path':
                        this._draw_path(ctx, s);
                        break;
                }
            }

        },
        draw_select : function(ctx) {
            //do nothing
            ctx.save();

            ctx.restore();
        },

        draw : function(ctx) {
            var p = this.points;
            ctx.save();
            ctx.lineWidth = 3;
            ctx.lineCap = 'round';
            ctx.lineJoin = 'round';
            ctx.fillStyle = this.color;
            this._doDraw(ctx);

            if(!this.initialized) {
                ctx.strokeStyle = "black";
                ctx.beginPath();
                ctx.moveTo(p[0].x, p[0].y);
                ctx.lineTo(p[1].x, p[0].y);
                ctx.lineTo(p[1].x, p[1].y);
                ctx.lineTo(p[0].x, p[1].y);
                ctx.closePath();
                ctx.stroke();
            }
            ctx.restore();
        },
        editStart : function() {
            $.setPoints(this.pre_points, this.points);
        },
        editMove : function(dx, dy) {
            for(var i = 0; i < this.points.length; i++) {
                this.points[i].x = this.pre_points[i].x + dx;
                this.points[i].y = this.pre_points[i].y + dy;
            }
            this._calc();
        },
        editRotateScale : function(relay_point, rotate, scale, not_calc) {
            //current version, ignore scale.
            for(var i = 0; i < this.points.length; i++) {
                var c_x = this.pre_points[i].x - relay_point.x, c_y = this.pre_points[i].y - relay_point.y;
//                c_x = c_x * scale;
//                c_y = c_y * scale;
                this.points[i].x = Math.round(c_x + relay_point.x);
                this.points[i].y = Math.round(c_y + relay_point.y);

                this.points[i].x = Math.round(c_x * Math.cos(rotate) - c_y * Math.sin(rotate) + relay_point.x);
                this.points[i].y = Math.round(c_x * Math.sin(rotate) + c_y * Math.cos(rotate) + relay_point.y);
            }
//            this.pen_width = Math.round(this.pre_pw * scale);

            if(not_calc !== true)
                this._calc();
        },
        rotateScale : function(relay_point, rotate, scale) {
            $.setPoints(this.pre_points, this.points);
            this.editRotateScale(relay_point, rotate, scale);
        },
        editPushPoint : function(p) {
            var p0 = this.points[0];
            var p1 = this.points[1];
            var _x = p.x - p0.x, x = Math.abs(_x);
            var _y = p.y - p0.y, y = Math.abs(_y);

            var sx = x / this.svg_width,
                sy = y / this.svg_height;
            var r = this.svg_width / this.svg_height;

            var tx, ty;
            if(sx > sy) {
                ty = y;
                tx = y * r;
            } else {
                tx = x;
                ty = x / r;
            }

            p1.x = p0.x + Math.floor(_x > 0 ? tx : -tx);
            p1.y = p0.y + Math.floor(_y > 0 ? ty : -ty);


            this._calc();
        }
    };

    $.inherit(Doodle._AnnotationDoodle, Doodle._Doodle);

    Doodle._Annotation_A_Doodle = function(data) {
        //pin.svg
        data.svg_info = {
            'width' : 351.712,
            'height' : 561.438,
            'shapes' : [{
                'type' : 'path',
                'data' : "M333.184,374.484c-11.569,17.688-28.387,33.211-48.997,44.933c31.007,68.849,60.356,136.001,59.616,141.905c0,0.081-0.039,0.081-0.06,0.161L277.16,423.179c-0.81,0.404-1.548,0.891-2.367,1.253c23.594,49.353,46.428,96.923,60.071,124.311c-14.724-24.595-40.957-72.452-66.706-121.235c-13.298,5.662-26.84,9.465-40.189,11.124c-49.877,6.311-96.65-14.281-114.895-54.802c-10.205-22.735-0.242-32.667,15.908-57.181L89.398,162.948c-24.452,1.975-51.909-15.158-68.576-29.973c39.715,11.7,76.577,2.669,101.19-7.718c3.49,5.827,13.341,22.33,14.583,24.858c15.667-6.704,27.64-14.622,35.589-21.014l-0.042-0.081l-7.322-28.772c17.072-13.229,30.471-28.409,38.016-43.164c-0.181,18.983-3.438,43.286-15.168,56.846c0,0,65.674,100.017,92.795,142.089c30.359,3.458,53.105,0.628,63.682,24.089C357.74,310.327,352.379,345.033,333.184,374.484z M174.703,133.701c-8.223,6.514-20.298,14.412-36.023,21.147l89.167,209.149c7.059-2.326,14.018-5.036,20.429-8.464c13.724-7.353,24.716-16.979,32.463-27.903L174.703,133.701z M329.22,358.949l-45.001-27.314c-8.174,11.164-19.499,20.975-33.495,28.468c-6.745,3.6-14.067,6.431-21.491,8.868l-1.021,53.196l-0.021,0.404c11.872-2.59,23.887-6.514,35.821-11.853c27.893-12.528,50.484-30.795,65.411-51.019L329.22,358.949z M133.776,114.123c-23.767,12.408-71.084,30.26-121.235,10.941c-4.207-3.407-7.626-7.392-9.769-12.176c-2.316-5.208-3.116-10.891-2.639-16.818C2.449,68.886,33,36.121,77.598,16.076c44.609-20.003,89.4-21.055,111.234-4.743c4.795,3.582,8.464,7.948,10.822,13.158c2.337,5.216,3.144,10.892,2.639,16.848c0.081,0.92,0.122,2.063,0.182,3.073C195.253,68.2,167.614,96.466,133.776,114.123z"}
            ]
        } ;
        this.base(Doodle.Type.ANNOTATION_A, data);

    };
    $.inherit(Doodle._Annotation_A_Doodle, Doodle._AnnotationDoodle);

    Doodle._Annotation_B_Doodle = function(data) {
        //good.svg
        data.svg_info = {
            'width' : 412.827,
            'height' : 435.695,
            'shapes' : [{
                'type' : 'path',
                'data' : "M121.917,0.016c-8.358-0.696-33.496,20.935-25.586,54.895c7.908,33.959,38.146,65.593,40.938,83.737c2.791,18.143,2.791,37.216-25.122,40.007c-27.912,2.792-46.056-2.791-65.129-3.257c-19.073-0.465-46.056,10.7-46.986,33.496c-0.93,22.794,18.609,32.564,18.609,32.564S4.219,253.553,5.15,274.487c0.93,20.935,17.213,31.634,17.213,31.634s-11.629,28.843-1.861,41.404c9.77,12.56,21.4,18.143,21.4,18.143s-2.791,27.912,8.374,39.078c11.165,11.165,33.293,36.354,134.91,20.003c27.748-4.465,75.363-14.422,75.363-14.422s54.428-141.139,54.428-187.478c0-0.466-21.918-23.766-31.168-43.729c-8.84-19.073-38.893-48.101-73.969-72.572C169.833,78.636,127.499,0.481,121.917,0.016z"
            }, {
                'type' : 'path',
                'data' : 'M330.329,225.177c0,0-32.292,147.129-53.964,174.453c-5.38,6.782,0.466,24.19,6.978,26.981c6.513,2.791,37.217,13.026,55.36,7.444c18.143-5.583,56.29-83.737,60.012-103.741c3.721-20.005,18.143-84.668,13.026-98.159C406.622,218.663,333.585,214.476,330.329,225.177z'
            }]
        } ;
        this.base(Doodle.Type.ANNOTATION_B, data);

    };
    $.inherit(Doodle._Annotation_B_Doodle, Doodle._AnnotationDoodle);

    //

})(Diigo.Doodle, Diigo.UndoRedo, Diigo.$);

(function(UR, $) {

	/**
	 * @class _Command
	 * Undo&Redo Base Command
	 */
    UR._Command = function() {
	};
    UR._Command.prototype = {
		undo : function() {
			throw "abstract method";
		},
		redo : function() {
			throw "abstract method";
		},
		toString : function() {
			return "undo-redo-command";
		},
        finish : function() {
            //do nothing
        }
	};

    UR._CombineCommand = function() {
        this.cmd_array = [];
    };
    UR._CombineCommand.prototype = {
        add : function(cmd) {
            this.cmd_array.push(cmd);
        },
        undo : function() {
            for (var i = this.cmd_array.length - 1; i >= 0; i--) {
                this.cmd_array[i].undo();
            }
        },
        redo : function() {
            for (var i = 0; i < this.cmd_array.length; i++) {
                this.cmd_array[i].redo();
            }
        },
        toString : function() {
            return this.cmd_array.join(",");
        },
        finish : function() {
            for(var i=this.cmd_array.length-1;i>=0;i--) {
                this.cmd_array[i].finish()
            }
        }
    }
    $.inherit(UR._CombineCommand, UR._Command);


	UR._UndoRedoManager = function(drawer) {
        this.drawer = drawer;
		this.cmd_array = [];
		this.cmd_index = -1;
		this.cmd_size = 0;
		this.MAX_NUM = 99999999;
	};
	UR._UndoRedoManager.prototype = {

        add : function(cmd) {
            if (this.cmd_index + 1 < this.MAX_NUM) {
                this.cmd_index++;
                this.cmd_array[this.cmd_index] = cmd;
                this.cmd_size = this.cmd_index + 1;
            } else {
                this.cmd_array.shift();
                this.cmd_array.push(cmd);
            }
            this.drawer._ur_back();
        },
		undo : function() {
			if (this.cmd_index >= 0) {
				this.cmd_array[this.cmd_index--].undo();
                this.drawer.paint();
                this.drawer._ur_back();
            }
        },
        canUndo : function() {
           return this.cmd_index >= 0;
        },
        canRedo : function() {
            return this.cmd_index + 1 < this.cmd_size;
        },
		redo : function() {
			if (this.cmd_index + 1 < this.cmd_size) {
				this.cmd_array[++this.cmd_index].redo();
                this.drawer.paint();
                this.drawer._ur_back();
            }
        },
		reset : function() {
			this.cmd_index = -1;
			this.cmd_size = 0;
            this.cmd_array.length = 0;
            this.drawer._ur_back();
		},
        clear : function() {
            this.reset();
        }
	};

    UR._DoodleCalloutCommand = function(doo) {
        this.doodle = doo;
        this.ps = $.copyPoints(doo.points);
        this.cs = $.copyPoints(this.ps);
        this.pa = {x : doo.a_info.point.x, y : doo.a_info.point.y};
        this.ca = {x : 0, y : 0};
    };
    UR._DoodleCalloutCommand.prototype = {
        _v : function(ps, a) {
            $.setPoints(this.doodle.points, ps);
            this.doodle.a_info.point.x = a.x;
            this.doodle.a_info.point.y = a.y;
            this.doodle.afterUndoRedo();
        },
        undo : function() {
            this._v(this.ps, this.pa);
        },
        redo : function() {
            this._v(this.cs, this.ca);
        },
        finish : function() {
            $.setPoints(this.cs, this.doodle.points);
            this.ca.x = this.doodle.a_info.point.x;
            this.ca.y = this.doodle.a_info.point.y;
        }
    };
    $.inherit(UR._DoodleCalloutCommand, UR._Command);

    UR._DoodleTextCommand = function(doo, pre_t, cur_t) {
        this.doodle = doo;
        this.ps = pre_t;
        this.cs = cur_t;
    };
    UR._DoodleTextCommand.prototype = {
        _v : function(txt) {
           this.doodle.setURText(txt);
           this.doodle.afterUndoRedo();
        },
        undo : function() {
            this._v(this.ps);
        },
        redo : function() {
            this._v(this.cs);
        }

    };
    $.inherit(UR._DoodleTextCommand, UR._Command);

    UR._CropCommand = function(drawer) {
        this.drawer = drawer;
        var bi = this.drawer.bg_info;
        this.ps = {
            x : bi.x,
            y : bi.y,
            w : bi.width,
            h : bi.height
        };
        this.cs = null;
    };
    UR._CropCommand.prototype = {
        _v : function(vb) {
            this.drawer.set_bg_info(vb);
        },
        undo : function() {
            this._v(this.ps);
        },
        redo : function() {
            this._v(this.cs);
        },
        finish : function() {
            var bi = this.drawer.bg_info;
            this.cs = {
                x : bi.x,
                y : bi.y,
                w : bi.width,
                h : bi.height
            }
        }
    };
    $.inherit(UR._CropCommand, UR._Command);

    UR._SizeCommand = function(drawer) {
        this.drawer = drawer;
        var bi = this.drawer.bg_info;
        this.img = document.createElement("canvas");
        this.ps = {
            x : bi.x,
            y : bi.y,
            width : bi.width,
            height : bi.height
        };
        this.ds = [];
        this.cs = null;
        this._init();
    };
    UR._SizeCommand.prototype = {
        _init : function() {
            var ctx = this.img.getContext("2d");
            this.img.width = this.drawer.image_canvas.width;
            this.img.height = this.drawer.image_canvas.height;
            ctx.drawImage(this.drawer.image_canvas, 0, 0);
            [].push.apply(this.ds, this.drawer.page.doodle_array);
        },

        undo : function() {
            this.drawer._set_image_size_undo(this.img, this.ps, this.ds);
        },
        redo : function() {
            this.drawer._set_image_size_redo(this.cs.width, this.cs.height);
        },
        finish : function() {
            var bi = this.drawer.bg_info;
            this.cs = {
                x : bi.x,
                y : bi.y,
                width : bi.width,
                height : bi.height
            }
        }
    };
    $.inherit(UR._SizeCommand, UR._Command);
})(Diigo.UndoRedo, Diigo.$);

(function(UR, $) {

    UR._DoodleColorCommand = function(doo, pre_clr, cur_clr) {
        this.doodle = doo;
        this.ps = pre_clr;
        this.cs = cur_clr;
    };
    UR._DoodleColorCommand.prototype = {
        undo : function() {
            this.doodle.setColor(this.ps);
        },
        redo : function() {
            this.doodle.setColor(this.cs);
        }
    };
    $.inherit(UR._DoodleColorCommand, UR._Command);


    UR._DoodleWidthCommand = function(doo, pre_w, cur_w) {
        this.doodle = doo;
        this.ps = pre_w;
        this.cs = cur_w;
    };
    UR._DoodleWidthCommand.prototype = {
        undo : function() {
            this.doodle.setPenWidth(this.ps);
        },
        redo : function() {
            this.doodle.setPenWidth(this.cs);
        }
    };
    $.inherit(UR._DoodleWidthCommand, UR._Command);

    UR._DoodleNewCommand = function(doo) {
        this.doodle = doo;
    };
    UR._DoodleNewCommand.prototype = {
        undo : function() {
            this.doodle.drawer._removeDoodle(this.doodle);
        },
        redo : function() {
            this.doodle.drawer._ur_insert(this.doodle);
        }
    };
    $.inherit(UR._DoodleNewCommand, UR._Command);

    UR._DoodleDelCommand = function(doo) {
        this.doodle = doo;
    };
    UR._DoodleDelCommand.prototype = {
        undo : function() {
            this.doodle.drawer._ur_insert(this.doodle);
        },
        redo : function() {
            this.doodle.drawer._removeDoodle(this.doodle);
        },
        toString : function() {
            return "doodle-command";
        }
    };
    $.inherit(UR._DoodleDelCommand, UR._Command);


    UR._DoodlePointsCommand = function(doo, pre_ps, cur_ps) {
        this.doodle = doo;
        this.ps = pre_ps ? pre_ps : $.copyPoints(doo.points);
        this.cs = cur_ps ? cur_ps : $.copyPoints(this.ps);
    };
    UR._DoodlePointsCommand.prototype = {
        undo : function() {
            $.setPoints(this.doodle.points, this.ps);
            this.doodle.afterUndoRedo();
        },
        redo : function() {
            $.setPoints(this.doodle.points, this.cs);
            this.doodle.afterUndoRedo();
        },
        finish : function() {
            $.setPoints(this.cs, this.doodle.points);
        }
    };
    $.inherit(UR._DoodlePointsCommand, UR._Command);

    UR._DoodleMatrixCommand = function(doo, pre_ps, cur_ps) {
        this.doodle = doo;
        this.ps = pre_ps ? pre_ps : $.copyArray(doo.matrix);
        this.cs = cur_ps ? cur_ps : $.copyArray(this.ps);
    };
    UR._DoodleMatrixCommand.prototype = {
        undo : function() {
            $.setArray(this.doodle.matrix, this.ps);
            this.doodle.afterUndoRedo();
        },
        redo : function() {
            $.setArray(this.doodle.matrix, this.cs);
            this.doodle.afterUndoRedo();
        },
        finish : function() {
            $.setArray(this.cs, this.doodle.matrix);
        }
    };
    $.inherit(UR._DoodleMatrixCommand, UR._Command);
})(Diigo.UndoRedo, Diigo.$);
(function(Doodle, UR,  $) {

    $.extend(Doodle._Drawer.prototype, {
        _check_region_mouse_down : function(p) {
            var pr = this.__pre_mouse_enter_region__;
            if(pr !== null) {
                pr.onMouseDown(p);
                this.__tmp_undo_command__ = pr.doodle.getRegionUndoCommand(pr);
                return true;
            }
            return false;
        },
        _pointChooseDoodle : function(p) {
            var d_arr = this.page.doodle_array;
            var dt = this.c_ctx.getImageData(p.ox, p.oy, 1, 1), cd = dt.data;
            if(cd[3] < 10) {
                return null;
            }
            var idx = $.color2int(cd);
            if(idx === d_arr.length) {
                return this.cut_doodle ? this.cut_doodle : null;
            } else if(idx >= 0) {
                return d_arr[idx] ? d_arr[idx] : null;
            } else {
                return null;
            }
        },


        _getEventPoint : function(e){
            if(this.out_pos === null) {
                this.out_pos = $.getDomPosition(this.out_container);
            }
            var p = {
                x : e.pageX,
                y : e.pageY
            }, _s = this.zoom_scale,
                bi = this.bg_info;
            p.sx = p.x;
            p.sy = p.y;
            p.cx = p.x - this.out_pos.left;
            p.cy = p.y - this.out_pos.top;
            p.ox = p.cx - this.container.offsetLeft + this.out_container.scrollLeft;
            p.oy = p.cy - this.container.offsetTop + this.out_container.scrollTop;
            p.x = Math.floor(p.ox / _s + bi.x);
            p.y = Math.floor(p.oy / _s + bi.y);

            return p;
        },
        _mouse_up_handler : function(e) {
            if(this.__left_mouse_db_down__) {
                this._mouse_double_down();
                this.__left_mouse_db_down__ = false;
                this.__left_mouse_down__ = false;
                return;
            }

            if(!this.__left_mouse_down__) {
                return;
            }
            this.__left_mouse_down__ = false;

            var p = this._getEventPoint(e);
            this._mouse_up(p);

            this._select_back();

            $.delMouseEvent(window, this.__saved_handler.mouse_move);
            $.delMouseEvent(window, this.__saved_handler.mouse_up);

            $.stopEvent(e);
        },

        _check_region_mouse_in_out : function(p) {
            var pe = this.__pre_mouse_enter_region__;
            var ce = null, d_arr = this.page.doodle_array;
            if(!this.has_selected_doodle) {
                return;
            }

            function er(doo, p, scale) {
                for(var i=0;i<doo.edit_regions.length;i++) {
                    if(doo.edit_regions[i].isPointIn(p, scale)) {
                        return doo.edit_regions[i];
                    }
                }
                return null;
            }
            if(this.cut_doodle !== null) {
                ce = er(this.cut_doodle, p, this.zoom_scale);
            } else {
                ce = er(this.edit_doodle, p, this.zoom_scale);
                if(ce === null) {
                    for(var i=0;i<d_arr.length;i++) {
                        var tmp = er(d_arr[i], p, this.zoom_scale);
                        if (tmp !== null) {
                            ce = tmp;
                            break;
                        }
                    }
                }
            }


            if(ce !== pe) {
                if(pe!==null) {
                    pe.onMouseOut();
                    this._paintEditLayer();
                }
                if(ce!==null) {
                    ce.onMouseIn();
                    this.setCursor_name(ce.cursor);
                    this._paintEditLayer();
                } else {
                    if(this.cursor_type === 2) {
                        this.setCursor(this.default_cursor);
                    } else {
                        this.setCursor_name(this.default_cursor);
                    }
                }
                this.__pre_mouse_enter_region__ = ce;
            }

        },
        _mouse_move_handler : function(e) {
            if (!this.__left_mouse_down__) {
                return;
            }

            var p = this._getEventPoint(e);

            var pr = this.__pre_mouse_enter_region__;
            if(pr !== null) {
                pr.onMouseMove(p);
                this._adjust_scroll(p.x, p.y);
                this._paintEditLayer();
            } else if($.getPTPRange(this.__mouse_down_point__, p) > 10) {
                this._mouse_move(p);
            }

            $.stopEvent(e);

        },

        _region_handler : function(e) {

            var p = this._getEventPoint(e);

            if(!this.__left_mouse_down__) {
                this._check_region_mouse_in_out(p);

                if(this.__pre_mouse_enter_region__ === null) {
                    var doo = this._pointChooseDoodle(p);
                    if(doo !== null && this.style.brush_type !== Doodle.Type.RECT_BLUR && doo.type === Doodle.Type.RECT_BLUR) {
                        doo = null;
                    }
                    if(doo !== null && this.__hover_doodle__ !== doo) {
                        this.__hover_doodle__ = doo;
                        this.setCursor_name("cursor_move");
                    } else if(doo === null && this.__hover_doodle__ !== null) {
                        this.__hover_doodle__ = null;
                        if(this.cursor_type === 2) {
                            this.setCursor(this.default_cursor);
                        } else {
                            this.setCursor_name(this.default_cursor);
                        }
                    }
                }

            }

        },

        _mouse_down_handler : function(e) {

            if(this.__left_mouse_down__) {
                return;
            }

            if(e.button !== 0) {
                return;
            }

            this.__left_mouse_down__ = true;
            this.__left_mouse_db_down__ = false;

            var p = this._getEventPoint(e);
            this.__mouse_down_point__ = p;

            if (this.__mouse_down_time__ === 1 && $.getPTPRange(this.__pre_point__, p) < 10) {
                this.__mouse_down_time__ = 0;
                if (this.__mdt_timeout__ !== null) {
                    window.clearTimeout(this.__mdt_timeout__);
                    this.__mdt_timeout__ = null;
                }
                this.__left_mouse_db_down__ = true;
            } else {
                this.__pre_point__ = p;
                this.__mouse_down_time__++;
                this.__mdt_timeout__ = window.setTimeout(this.__mdt_delegate__, 450);
                this._mouse_down(p);
            }

            this.__saved_handler.mouse_move = $.addMouseEvent(window, 'mousemove', this.__cmv_handler);
            this.__saved_handler.mouse_up = $.addMouseEvent(window, 'mouseup', this.__cmu_handler);

            $.stopEvent(e);

        },


        initEvent : function() {

            this.__left_mouse_down__ = false;
            this.__left_mouse_db_down__ = false;
            this.__draw_point__ = false;

            this.__hover_doodle__ = null;

            this.__cmv_handler = $.createDelegate(this, this._mouse_move_handler);
            this.__cmu_handler = $.createDelegate(this, this._mouse_up_handler);
            this.__saved_handler = {
                mouse_move : null,
                mouse_up : null
            };

            this.__mouse_down_time__ = 0;
            this.__mdt_timeout__ = null;
            this.__mdt_delegate__ = $.createDelegate(this, function() {
                this.__mouse_down_time__ = 0;
                this.__mdt_timeout__ = null;
                this.__left_mouse_db_down__ = false;
            });

            $.addMouseEvent(this.edit_canvas, 'mousedown', $.createDelegate(this, this._mouse_down_handler));
            $.addEvent(this.edit_canvas, 'mousemove', $.createDelegate(this, this._region_handler));

            this.__pre_point__ = {x:0,y:0};

            this.$list_input.attr({
                'min' : 1,
                'max' : 999999
            }).on("mousedown", function(ev) {
                ev.stopPropagation();
            }).on('keypress',function(ev) {
                if(ev.keyCode < 47 || ev.keyCode > 58) {
                    ev.preventDefault();
                }
            }).on("input", $.createDelegate(this, this._list_input_handler)).data("doodle", null);

            $.addEvent(window, "resize", $.createDelegate(this, this._on_resize));
        },
        _on_resize : function() {
            var oh = this.out_container.offsetHeight;
            var h = this.container.offsetHeight;
            if(oh > h + 40) {
                this.container.style.top = '40px';
            } else {
                this.container.style.top = '0px';
            }
        },
        _list_input_handler : function() {
            var ld = this.$list_input.data("doodle");
            var val = Number(this.$list_input.val());
            if(val<1 || val>999999) {
                val = this.$list_input.data("pre_value");
            }
            ld.set_i_value(val);
        },
        _show_list_dialog : function(list_doodle) {
            var $li = this.$list_input, $ld = this.$list_dialog;
            var pre_doo = $li.data("doodle");
            $li.data("doodle", list_doodle);
            $li.data("pre_value", list_doodle.i_value);
            $li.val(list_doodle.i_value);
            var b = list_doodle.boundary;
            var ox = this.bg_info.x,
                oy = this.bg_info.y,
                scale = this.zoom_scale;
            var x = Math.round((b.left + (b.width - $ld.innerWidth() / scale)/ 2 - ox) * scale);
            var y = Math.round((b.bottom - oy) * scale) + 15;

            if(pre_doo === null) {
                $ld.css({
                    left : x,
                    top: y
                }).fadeIn(200, function() {
                    $li.focus();
                });
            } else {
                $ld.animate({
                    left : x,
                    top: y
                }, 200);
            }
        },
        _hide_list_dialog : function() {
            if(this.$list_input.data("doodle") !== null) {
                this.$list_dialog.hide();
                this.$list_input.data("doodle", null);
            }
            this.style_callback('mousedown');
        },
        hideListDialog : function() {
            if(this.$list_input.data("doodle") !== null) {
                this.$list_dialog.hide();
                this.$list_input.data("doodle", null);
            }
        },
        _mouse_double_down : function() {
            var hd = this.__hover_doodle__;
            if(hd === null) {
                return;
            }
            var T = Doodle.Type;
            if(hd.type === T.LIST) {
                this._show_list_dialog(hd);
            } else if(hd.type === T.TEXT) {
                this.cur_textbox = hd;
                this.activeTextbox();
            } else if(hd.type === T.CALLOUT) {
                this.cur_textbox = hd.child_textbox;
                this.activeInnerTextbox();
            }
        },
        _mouse_down : function(p) {

            this._hide_list_dialog();


            var T = Doodle.Type;
            var bt = this.style.brush_type;

            if(this._check_region_mouse_down(p)) {
                return;
            }

            var pre_sd = null;
            var d_arr = this.page.doodle_array;

            if(this.cur_textbox !== null) {

                this.unactiveTextbox();
                this.paint();

                if(bt === T.CALLOUT || bt === T.TEXT) {
                    return;
                }
            }

            function __sd() {
                for(var i=0;i<d_arr.length;i++) {
                    if(d_arr[i].selected) {
                        return d_arr[i];
                    }
                }
                return null;
            }

            this.temp_doodle = null;
            var sd = this.has_selected_doodle ? __sd() : null;
            var hd = this.__hover_doodle__;

            if(hd === null
                && bt === T.LIST
                && sd === null) {

                var ld = Doodle.create(T.LIST, {
                    points:[this.__pre_point__],
                    drawer: this
                });
                this.insertDoodle(ld);
                this.default_cursor = Doodle._ListDoodle.__LAST_INFO__.getCursor();
                this.setCursor_name("cursor_move");
                this.__hover_doodle__ = ld;
                hd = ld;

            } else if(hd === null
                && bt === T.TEXT
                && sd === null) {

                this.temp_doodle = Doodle.create(T.TEXT, {
                    points: [this.__pre_point__],
                    drawer : this
                });

            }

            if(hd !== null) {
                for(var i=0;i<d_arr.length;i++) {
                    if(d_arr[i].selected === true) {
                        pre_sd = d_arr[i];
                    }
                    d_arr[i].selected = false;
                    d_arr[i].setRegionDisabled(true);
                }
                hd.selected = true;
                this.has_selected_doodle = true;
                this.edit_doodle.attachDoodle(hd);
                this.edit_doodle.editStart(p);


                if(this.cut_doodle !== null) {
                    this.cut_doodle.editStart();
                } else {
                    this.__tmp_undo_command__ = hd.getMoveUndoCommand();
                    hd.editStart();
                }

                this._paintDoodleLayer();
                this._paintEditLayer();

                if(hd.type === T.RECT_BLUR && (pre_sd === null || pre_sd.type !== T.RECT_BLUR)) {
                    this._prepare_for_blur();
                }

            } else if(this.temp_doodle === null) {
                if(this.style.brush_type === T.CURVE && this.has_selected_doodle === false) {
                    this.__draw_point__ = true;
                } else {
                    this.__draw_point__ = false;
                }
                this._select_nothing();
                this.edit_doodle.attachNothing();
                this._paintDoodleLayer();
            }


        },
        _move_doodle_to_top : function(doo) {
            var d_arr = this.page.doodle_array;
            var idx = d_arr.indexOf(doo);
            if(idx>=0) {
                d_arr.splice(idx, 1);
                d_arr.unshift(doo);
            }
        },
        _mouse_up : function(p) {
            var pr = this.__pre_mouse_enter_region__;
            var T = Doodle.Type;
            var DI = Doodle._ListDoodle.__LAST_INFO__;

            if(pr!==null) {
                pr.onMouseUp(p);
                if(pr.is_changed) {
                    if(this.__tmp_undo_command__!==null) {
                        this.__tmp_undo_command__.finish();
                        this.history.add(this.__tmp_undo_command__);
                        this.__tmp_undo_command__ = null;
                    }
                    this.paint();
                }
                this.__pre_mouse_enter_region__ = null;
                return;
            }

            var hd = this.__hover_doodle__;
            if(hd !== null) {
                this.edit_doodle.editFinish(p);
                hd.editFinish();
                this._move_doodle_to_top(hd);

                if(this.__tmp_undo_command__ !== null && $.getPTPRange(this.__pre_point__, p) > 10) {
//                    $.log("add move undo");
                    this.__tmp_undo_command__.finish();
                    this.history.add(this.__tmp_undo_command__);
                }
                this.__tmp_undo_command__ = null;

                if(this.cut_doodle !== null) {
                    this.cut_doodle.editFinish();
                }

                if(hd.type=== T.RECT_BLUR) {
                    this._finish_for_blur();
                    this.paint();
                } else if(hd.type === T.LIST) {
                    DI.radius.a = hd.radius.a;
                    DI.radius.b = hd.radius.b;
                    this.paint();
                } else{
                    this.paint();
                }

                return;
            }



            if(this.cut_mode) {

                this.cut_doodle = this.temp_doodle;
                this.temp_doodle = null;
                this.cut_doodle.selected = true;
                this.has_selected_doodle = true;
                this.edit_doodle.attachDoodle(this.cut_doodle);

                this.paint();

                return;
            }

            var td = this.temp_doodle;

            if(td === null) {
                var c = this.style;
                if(this.__draw_point__) {
                    td = Doodle.create(T.CURVE, {
                        drawer : this,
                        pen_width: c.pen_width,
                        line_type : c.dot_type | c.arrow_type,
                        color: getRGBAColor(c.color, c.pen_opacity),
                        points : [this.__pre_point__]
                    });
                    td.initialize();
                    this.insertDoodle(td);
                }
                this.paint();
                return;
            }

            td.editFinish();

            var t = td.type;
            td = this.temp_doodle;
            if(t === T.TEXT) {
                td.auto_width = Math.abs(td.points[1].x - td.points[0].x)<30;
                td.initialize();
                this.insertDoodle(td);
                this.cur_textbox = td;
                this._select_doodle(td);
            } else if(t === T.CALLOUT) {
                td.initialize();
                this.insertDoodle(td);
                this.cur_textbox = td.child_textbox;
                this._select_doodle(td);
            } else if(t === T.BEZIER_ARROW) {
                td.initialize();
                this.insertDoodle(td);
                this._select_doodle(td);
            } else if(t === T.IMAGE) {
                var pp = td.points;
                if(Math.abs(pp[0].x - pp[1].x)< 10 && Math.abs(pp[0].x - pp[1].x) < 10) {
                    td.editPushPoint({
                        x : pp[0].x + 150,
                        y : pp[0].y + 150
                    });
                }
                td.initialize();
                this.insertDoodle(td);
            } else if(t !== T.CUT) {
                td.initialize();
                this.insertDoodle(td);
                if(t === T.RECT_BLUR) {
                    this._finish_for_blur();
                }
            }

            this.temp_doodle = null;

            //清空edit layer
            this._paintEditLayer();

            if(t === T.TEXT) {
                this.activeTextbox();
            }  else if(t === T.CALLOUT) {
                this.activeInnerTextbox();
            } else if(t !== T.CUT) {
                this.paint();
            }
        },
        _adjust_scroll : function(x, y) {
            var oc = this.out_container,
                sl = oc.scrollLeft,
                st = oc.scrollTop,
                W = oc.offsetWidth,
                H = oc.offsetHeight;
            var bi = this.bg_info, scale = this.zoom_scale;
            var OFF = 30;
//            $.log(bd.bottom);
            var y0 = Math.floor((y - OFF - bi.y) * scale), dy0 = y0 - st,
                y1 = Math.floor((y + OFF - bi.y) * scale), dy1 = y1 - st;
            var x0 = Math.floor((x - bi.x - OFF) * scale) - OFF, dx0 = x0 - sl,
                x1 = Math.floor((x + OFF - bi.x) * scale), dx1 = x1 - sl;

//            $.log(dy0, dy1, H);
//            window.setTimeout(function() {
                if(dy0<0) {
                    oc.scrollTop = Math.max(0, y0);
                } else if(dy1>H) {
                    oc.scrollTop = Math.min(y1 - H, Math.floor(bi.height * scale - H));
                }
                if(dx0 < 0) {
                    oc.scrollLeft = Math.max(0, x0 );
                } else if(dx1 > W) {
                    oc.scrollLeft = Math.min(Math.floor(bi.width * scale - W), x1 - W);
                }
//            }, 10);

//            if(oc.scrollTop === )
//            $.log(oc.scrollTop, oc.scrollLeft);
        },
        _mouse_move : function(point) {
            var hd = this.__hover_doodle__;
            if(hd !== null) {
                var d = this.edit_doodle.editMove(point);
                hd.editMove(d.x, d.y);
                if(this.cut_doodle !== null) {
                    this.cut_doodle.editMove(d.x, d.y);
                }
                this._adjust_scroll(point.x, point.y);

                this._paintEditLayer();
                return;
            }

            if(this.temp_doodle===null) {
                var c = this.style, t = c.brush_type, pe=this.__pre_point__;
                if(this.cut_doodle !== null) {
                    this.cut_doodle = null;
                }

                if(t===Doodle.Type.TEXT || t === Doodle.Type.LIST) {
                    //do not create doodle

                } else if(t=== Doodle.Type.IMAGE) {
                    this.temp_doodle = Doodle.create(t, {
                        drawer: this,
                        image : this.style.svg_image,
                        points : [pe, point]
                    });
                } else {
                    this.temp_doodle = Doodle.create(t, {
                        drawer : this,
                        pen_width: c.pen_width,
                        line_type : c.dot_type | c.arrow_type,
                        color: getRGBAColor(c.color, c.pen_opacity),
                        points : [pe, point]
                    });
                    if(t === Doodle.Type.RECT_BLUR) {
                        this._prepare_for_blur();
                    }
                }
            } else {
                this.temp_doodle.editPushPoint(point);
                this._adjust_scroll(point.x, point.y);

            }

            this._paintEditLayer();
        }

    });

    function getRGBAColor(color, opacity){
        var _clr = $.str2rgba(color);
        _clr.a = opacity;
        return "rgba("+_clr.r+","+_clr.g+","+_clr.b+","+_clr.a+")";
    }
})(Diigo.Doodle, Diigo.UndoRedo, Diigo.$);
(function(Doodle, UR, $) {

	/**
	 * 编辑doodle的实现，包括doodle的选择，缩放，旋转等
	 */
	Doodle._EditDoodle = function(drawer) {
        /*
         * points一共五个点。前四个是包围矩形的四点，第五个是旋转按钮所在位置。
         */
		this.base(Doodle.Type.EDITHELPER, {
            drawer : drawer,
            /*
             * 五个点，前四个依次是四个编辑角。第五个是旋转按钮中心位置。
             */
            points : [{
                x : 0,
                y : 0
            }, {
                x : 0,
                y : 0
            }, {
                x : 0,
                y : 0
            }, {
                x : 0,
                y : 0
            }, {
                x : 0,
                y : 0
            }],
            color :  "rgba(123,123,123,0.5)"
        });

        this.pre_points = $.copyPoints(this.points);
        this.selected_doodle = null;
		this.center = {
			x : 0,
			y : 0
		};
        this.pre_point = {
            x : 0,
            y: 0
        };
        this.inter_point = {
            x : 0,
            y : 0
        };
        this.edit_regions.push(new Doodle.TipRegion(this, 0, this.points[4]));
        this.tip_region = this.edit_regions[0];
        this.tip_region.disabled = true;

        this.__tmp_undo_command__ = null;
	};
	Doodle._EditDoodle.prototype = {
        getRegionUndoCommand : function() {
            return this.__tmp_undo_command__;
        },
        onRegionEdit : function(idx, p) {
            if(idx!==0) {
                //not tip region;
                return;
            }
            var rs = this.editRotateScale(p);
            this.selected_doodle.editRotateScale(this.center, rs.rotate, rs.scale);
            this._set_rotate_point();
        },

        onRegionEditStart : function(idx, p) {
            var sd = this.selected_doodle;
            this.__tmp_undo_command__ = sd.getRotateUndoCommand();
            sd.editStart(p);
            this.pre_point.x = p.x;
            this.pre_point.y = p.y;
            this.inter_point.x = p.x;
            this.inter_point.y = p.y;
        },

        onRegionEditFinish : function(idx, p) {
            this.selected_doodle.editFinish();
            if(this.__tmp_undo_command__ !== null) {
                this.__tmp_undo_command__.finish();
                this.drawer.history.add(this.__tmp_undo_command__);
                this.__tmp_undo_command__ = null;
            }
            this._calc();
            this._set_rotate_point();
        },

        attachDoodle : function(doo) {
            var p = this.points, b = doo.boundary;
            p[0].x = b.left;
            p[0].y = b.top;
            p[1].x = b.right;
            p[1].y = b.top;
            p[2].x = b.right;
            p[2].y = b.bottom;
            p[3].x = b.left;
            p[3].y = b.bottom;

            doo.setRegionDisabled(false);
            this.selected_doodle = doo;
            this._calc();
            this._set_rotate_point();
        },
        _re_attach_doodle : function() {
            if(this.selected_doodle === null) {
                return;
            }
            this.attachDoodle(this.selected_doodle);
        },
        _set_rotate_point : function() {
            if(this.selected_doodle === null) {
                return;
            }
            var rp = this.selected_doodle.getRotatePoint();
            if(rp !== null) {
                this.points[4].x = rp.x;
                this.points[4].y = rp.y;
                this.tip_region.disabled = false;
            } else {
                this.tip_region.disabled = true;
            }
        },
        attachNothing : function() {
            this.selected_doodle = null;
            this.tip_region.disabled = true;
        },

		_calc : function() {
            var ps = this.points;
		    this.center.x = Math.floor((ps[0].x+ps[2].x)/2);
            this.center.y = Math.floor((ps[0].y+ps[2].y)/2);
        },

		editStart : function(point) {
            $.setPoints(this.pre_points, this.points);
            this._calc();
            this.pre_point.x = point.x;
            this.pre_point.y = point.y;
        },
		editMove : function(point) {
			//$.log(d)
                var d = {
					x : point.x - this.pre_point.x,
					y : point.y - this.pre_point.y
				};
                for(var i = 0; i < this.points.length; i++) {
                    this.points[i].x = this.pre_points[i].x + d.x;
                    this.points[i].y = this.pre_points[i].y + d.y;
                }
				return d;
		},
        _editFinish : function() {
            this._calc();
            this.drawer.onChange();
        },
		editFinish : function(point) {
            this._editFinish();
            return {
				x : point.x - this.pre_point.x,
				y : point.y - this.pre_point.y
			}
		},
		editRotateScale : function(point) {
			return this._calcRSValue(point);
		},
		_calcRSValue : function(point) {
			var vx1 = point.x - this.center.x, vy1 = point.y - this.center.y, vx2 = this.pre_point.x - this.center.x, vy2 = this.pre_point.y - this.center.y;
			var r1 = Math.sqrt(vx1 * vx1 + vy1 * vy1), r2 = Math.sqrt(vx2 * vx2 + vy2 * vy2);
			var cosa = (vx1 * vx2 + vy1 * vy2) / (r1 * r2), angle = Math.acos(cosa);
			if (Math.abs(cosa - 1.0) <= 0.0000001) {
				angle = 0;
			} else if (Math.abs(cosa + 1.0) <= 0.0000001) {
				angle = Math.PI;
			} else if (vx1 * vy2 - vx2 * vy1 > 0) {
				angle = Math.PI * 2 - angle;
			}
			return {
				scale : r1 / r2,
				rotate : angle
			}
		}
	};
	$.inherit(Doodle._EditDoodle, Doodle._Doodle);

})(Diigo.Doodle, Diigo.UndoRedo, Diigo.$);

/**
 * User: xiaoge
 * Email: abraham1@163.com
 */
(function(Text, Doodle, $) {
    Doodle.EventRegion = function(doo, idx, cursor) {
        this.doodle = doo;
        this.idx = idx;
        this.is_mouse_in = false;
        this.is_changed = false;
        this.cursor = cursor ? 'cursor_' + cursor : "cursor_pointer";
        this.disabled = true;
    };
    Doodle.EventRegion.prototype = {
        isPointIn : function(p) {
            return false;
        },
        isPointIn_xy : function(x, y) {
            return false;
        },
        onMouseIn : function() {
            this.is_mouse_in = true;
        },
        onMouseOut : function() {
            this.is_mouse_in = false;
        },
        onMouseDown : function(p) {
            this.is_changed = false;
            this.doodle.onRegionEditStart(this.idx, p);
        },
        onMouseMove : function(p) {
            this.doodle.onRegionEdit(this.idx, p);
            this.is_changed = true;
        },
        onMouseUp : function(p) {
            this.doodle.onRegionEditFinish(this.idx, p);
        },
        draw : function(ctx, scale) {
            //do nothing;
        },
        editDraw : function(ctx, scale, selected_color) {
            this.doodle.draw_region(ctx, scale, selected_color);
        }
    };

    Doodle.CircleRegion = function(doo, idx, center, radius, cursor) {
        this.base(doo, idx, cursor);
        this.center = center;
        this.radius = typeof radius === 'undefined' ? 7 : radius;
    };
    Doodle.CircleRegion.prototype = {
        isPointIn : function(p) {
            return this.disabled ? false : $.getPTPRange(this.center, p) <= this.radius;
        },
        draw : function(ctx, scale) {

            ctx.save();

            ctx.strokeStyle = "rgba(0,0,0,0.1)";
            ctx.lineWidth = 1; // Math.floor(1 / scale);

            ctx.save();

            ctx.shadowColor = "rgba(0,0,0,0.25)";
            ctx.shadowBlur = 4;
            ctx.shadowOffsetX = 0;
            ctx.shadowOffsetY = 2;

            ctx.beginPath();
            ctx.arc(this.center.x, this.center.y, this.radius, 0, 2 * Math.PI, false);
            ctx.stroke();
            ctx.closePath();
            ctx.fillStyle = "#fff";
            ctx.fill();

            ctx.restore();

            var _x = this.center.x - this.radius + 2;
            var _y = this.center.y - this.radius + 2;

            var gr = ctx.createLinearGradient(_x, _y, _x, _y + (this.radius -2)*2);
            gr.addColorStop(0, '#09f');
            gr.addColorStop(1, '#07f');

            ctx.fillStyle = gr;
            ctx.beginPath();
            ctx.arc(this.center.x, this.center.y, this.radius - 2, 0, 2 * Math.PI, false);
            ctx.closePath();
            ctx.fill();

            ctx.restore();
        }
    };
    $.inherit(Doodle.CircleRegion, Doodle.EventRegion);

    Doodle.TipRegion = function(doo, idx,  center) {
        this.base(doo, idx , center, 5, 'rotation');

    };
    Doodle.TipRegion.prototype = {
        isPointIn : function(p) {
            return this.disabled ? false : $.getPTPRange(this.center, p) <= this.radius;
        },
        isPointIn_xy : function(x, y) {
            return this.disabled ? false : $.getPTPRange_xy(this.center.x, this.center.y, x, y) <= this.radius;
        },
        draw : function(ctx, scale) {

            if(this.disabled) {
                return;
            }

            ctx.save();

            ctx.strokeStyle = "rgba(0,0,0,0.2)";
            ctx.lineWidth = 2; // Math.floor(1 / scale);

            ctx.save();

            ctx.shadowColor = "rgba(0,0,0,0.15)";
            ctx.shadowBlur = 3;
            ctx.shadowOffsetX = 0;
            ctx.shadowOffsetY = 1;

            ctx.beginPath();
            ctx.arc(this.center.x, this.center.y, this.radius, 0, 2 * Math.PI, false);
            ctx.stroke();
            ctx.closePath();
            ctx.fillStyle = "#fff";
            ctx.fill();

            ctx.restore();

//            var _x = this.center.x - this.radius + 1;
//            var _y = this.center.y - this.radius + 1;
//
//            var gr = ctx.createLinearGradient(_x, _y, _x, _y + (this.radius -1)*2);
//            gr.addColorStop(0, '#080');
//            gr.addColorStop(1, '#07f');

//            ctx.fillStyle = gr;
            ctx.fillStyle = '#080';
            ctx.beginPath();
            ctx.arc(this.center.x, this.center.y, this.radius - 1, 0, 2 * Math.PI, false);
            ctx.closePath();
            ctx.fill();

            ctx.restore();
        }
    };
    $.inherit(Doodle.TipRegion, Doodle.CircleRegion);

})(Diigo.Text, Diigo.Doodle, Diigo.$);
(function (Doodle, $) {
    var mul_table = [512, 512, 456, 512, 328, 456, 335, 512, 405, 328, 271, 456, 388, 335, 292, 512, 454, 405, 364, 328, 298, 271, 496, 456, 420, 388, 360, 335, 312, 292, 273, 512, 482, 454, 428, 405, 383, 364, 345, 328, 312, 298, 284, 271, 259, 496, 475, 456, 437, 420, 404, 388, 374, 360, 347, 335, 323, 312, 302, 292, 282, 273, 265, 512, 497, 482, 468, 454, 441, 428, 417, 405, 394, 383, 373, 364, 354, 345, 337, 328, 320, 312, 305, 298, 291, 284, 278, 271, 265, 259, 507, 496, 485, 475, 465, 456, 446, 437, 428, 420, 412, 404, 396, 388, 381, 374, 367, 360, 354, 347, 341, 335, 329, 323, 318, 312, 307, 302, 297, 292, 287, 282, 278, 273, 269, 265, 261, 512, 505, 497, 489, 482, 475, 468, 461, 454, 447, 441, 435, 428, 422, 417, 411, 405, 399, 394, 389, 383, 378, 373, 368, 364, 359, 354, 350, 345, 341, 337, 332, 328, 324, 320, 316, 312, 309, 305, 301, 298, 294, 291, 287, 284, 281, 278, 274, 271, 268, 265, 262, 259, 257, 507, 501, 496, 491, 485, 480, 475, 470, 465, 460, 456, 451, 446, 442, 437, 433, 428, 424, 420, 416, 412, 408, 404, 400, 396, 392, 388, 385, 381, 377, 374, 370, 367, 363, 360, 357, 354, 350, 347, 344, 341, 338, 335, 332, 329, 326, 323, 320, 318, 315, 312, 310, 307, 304, 302, 299, 297, 294, 292, 289, 287, 285, 282, 280, 278, 275, 273, 271, 269, 267, 265, 263, 261, 259];

    var shg_table = [9, 11, 12, 13, 13, 14, 14, 15, 15, 15, 15, 16, 16, 16, 16, 17, 17, 17, 17, 17, 17, 17, 18, 18, 18, 18, 18, 18, 18, 18, 18, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24];


    var _blur_data = function (imageData, width, height, radius) {

        var pixels = imageData.data;

        var x, y, i, p, yp, yi, yw, r_sum, g_sum, b_sum, a_sum, r_out_sum, g_out_sum, b_out_sum, a_out_sum, r_in_sum, g_in_sum, b_in_sum, a_in_sum, pr, pg, pb, pa, rbs;

        var div = radius + radius + 1;
        var w4 = width << 2;
        var widthMinus1 = width - 1;
        var heightMinus1 = height - 1;
        var radiusPlus1 = radius + 1;
        var sumFactor = radiusPlus1 * (radiusPlus1 + 1 ) / 2;

        var stackStart = {
            r: 0,
            g: 0,
            b: 0,
            a: 0,
            next: null
        };
        var stack = stackStart;
        for (i = 1; i < div; i++) {
            stack = stack.next = {
                r: 0,
                g: 0,
                b: 0,
                a: 0,
                next: null
            };
            if (i == radiusPlus1)
                var stackEnd = stack;
        }
        stack.next = stackStart;
        var stackIn = null;
        var stackOut = null;
        yw = yi = 0;

        var mul_sum = mul_table[radius];
        var shg_sum = shg_table[radius];

        for (y = 0; y < height; y++) {
            r_in_sum = g_in_sum = b_in_sum = a_in_sum = r_sum = g_sum = b_sum = a_sum = 0;
            r_out_sum = radiusPlus1 * ( pr = pixels[yi] );
            g_out_sum = radiusPlus1 * ( pg = pixels[yi + 1] );
            b_out_sum = radiusPlus1 * ( pb = pixels[yi + 2] );
            a_out_sum = radiusPlus1 * ( pa = pixels[yi + 3] );
            r_sum += sumFactor * pr;
            g_sum += sumFactor * pg;
            b_sum += sumFactor * pb;
            a_sum += sumFactor * pa;
            stack = stackStart;

            for (i = 0; i < radiusPlus1; i++) {
                stack.r = pr;
                stack.g = pg;
                stack.b = pb;
                stack.a = pa;
                stack = stack.next;
            }

            for (i = 1; i < radiusPlus1; i++) {
                p = yi + ((widthMinus1 < i ? widthMinus1 : i ) << 2 );
                r_sum += (stack.r = ( pr = pixels[p])) * ( rbs = radiusPlus1 - i );
                g_sum += (stack.g = ( pg = pixels[p + 1])) * rbs;
                b_sum += (stack.b = ( pb = pixels[p + 2])) * rbs;
                a_sum += (stack.a = ( pa = pixels[p + 3])) * rbs;
                r_in_sum += pr;
                g_in_sum += pg;
                b_in_sum += pb;
                a_in_sum += pa;
                stack = stack.next;
            }
            stackIn = stackStart;
            stackOut = stackEnd;
            for (x = 0; x < width; x++) {
                pixels[yi + 3] = pa = (a_sum * mul_sum) >> shg_sum;
                if (pa != 0) {
                    pa = 255 / pa;
                    pixels[yi] = ((r_sum * mul_sum) >> shg_sum) * pa;
                    pixels[yi + 1] = ((g_sum * mul_sum) >> shg_sum) * pa;
                    pixels[yi + 2] = ((b_sum * mul_sum) >> shg_sum) * pa;
                } else {
                    pixels[yi] = pixels[yi + 1] = pixels[yi + 2] = 0;
                }
                r_sum -= r_out_sum;
                g_sum -= g_out_sum;
                b_sum -= b_out_sum;
                a_sum -= a_out_sum;
                r_out_sum -= stackIn.r;
                g_out_sum -= stackIn.g;
                b_out_sum -= stackIn.b;
                a_out_sum -= stackIn.a;
                p = (yw + (( p = x + radius + 1 ) < widthMinus1 ? p : widthMinus1 ) ) << 2;
                r_in_sum += (stackIn.r = pixels[p]);
                g_in_sum += (stackIn.g = pixels[p + 1]);
                b_in_sum += (stackIn.b = pixels[p + 2]);
                a_in_sum += (stackIn.a = pixels[p + 3]);
                r_sum += r_in_sum;
                g_sum += g_in_sum;
                b_sum += b_in_sum;
                a_sum += a_in_sum;
                stackIn = stackIn.next;
                r_out_sum += ( pr = stackOut.r );
                g_out_sum += ( pg = stackOut.g );
                b_out_sum += ( pb = stackOut.b );
                a_out_sum += ( pa = stackOut.a );
                r_in_sum -= pr;
                g_in_sum -= pg;
                b_in_sum -= pb;
                a_in_sum -= pa;
                stackOut = stackOut.next;
                yi += 4;
            }
            yw += width;
        }

        for (x = 0; x < width; x++) {
            g_in_sum = b_in_sum = a_in_sum = r_in_sum = g_sum = b_sum = a_sum = r_sum = 0;
            yi = x << 2;
            r_out_sum = radiusPlus1 * ( pr = pixels[yi]);
            g_out_sum = radiusPlus1 * ( pg = pixels[yi + 1]);
            b_out_sum = radiusPlus1 * ( pb = pixels[yi + 2]);
            a_out_sum = radiusPlus1 * ( pa = pixels[yi + 3]);
            r_sum += sumFactor * pr;
            g_sum += sumFactor * pg;
            b_sum += sumFactor * pb;
            a_sum += sumFactor * pa;
            stack = stackStart;

            for (i = 0; i < radiusPlus1; i++) {
                stack.r = pr;
                stack.g = pg;
                stack.b = pb;
                stack.a = pa;
                stack = stack.next;
            }
            yp = width;

            for (i = 1; i <= radius; i++) {
                yi = (yp + x ) << 2;
                r_sum += (stack.r = ( pr = pixels[yi])) * ( rbs = radiusPlus1 - i );
                g_sum += (stack.g = ( pg = pixels[yi + 1])) * rbs;
                b_sum += (stack.b = ( pb = pixels[yi + 2])) * rbs;
                a_sum += (stack.a = ( pa = pixels[yi + 3])) * rbs;
                r_in_sum += pr;
                g_in_sum += pg;
                b_in_sum += pb;
                a_in_sum += pa;
                stack = stack.next;

                if (i < heightMinus1) {
                    yp += width;
                }
            }
            yi = x;
            stackIn = stackStart;
            stackOut = stackEnd;
            for (y = 0; y < height; y++) {
                p = yi << 2;
                pixels[p + 3] = pa = (a_sum * mul_sum) >> shg_sum;
                if (pa > 0) {
                    pa = 255 / pa;
                    pixels[p] = ((r_sum * mul_sum) >> shg_sum ) * pa;
                    pixels[p + 1] = ((g_sum * mul_sum) >> shg_sum ) * pa;
                    pixels[p + 2] = ((b_sum * mul_sum) >> shg_sum ) * pa;
                } else {
                    pixels[p] = pixels[p + 1] = pixels[p + 2] = 0;
                }
                r_sum -= r_out_sum;
                g_sum -= g_out_sum;
                b_sum -= b_out_sum;
                a_sum -= a_out_sum;
                r_out_sum -= stackIn.r;
                g_out_sum -= stackIn.g;
                b_out_sum -= stackIn.b;
                a_out_sum -= stackIn.a;
                p = (x + ((( p = y + radiusPlus1) < heightMinus1 ? p : heightMinus1 ) * width )) << 2;
                r_sum += (r_in_sum += (stackIn.r = pixels[p]));
                g_sum += (g_in_sum += (stackIn.g = pixels[p + 1]));
                b_sum += (b_in_sum += (stackIn.b = pixels[p + 2]));
                a_sum += (a_in_sum += (stackIn.a = pixels[p + 3]));
                stackIn = stackIn.next;
                r_out_sum += ( pr = stackOut.r );
                g_out_sum += ( pg = stackOut.g );
                b_out_sum += ( pb = stackOut.b );
                a_out_sum += ( pa = stackOut.a );
                r_in_sum -= pr;
                g_in_sum -= pg;
                b_in_sum -= pb;
                a_in_sum -= pa;
                stackOut = stackOut.next;
                yi += width;
            }
        }
    };

    $.stackBlurCanvasRGBA = function(context, top_x, top_y, width, height, radius) {
        var imageData = context.getImageData(top_x, top_y, width, height);
        _blur_data(imageData, width, height, typeof radius === 'undefined' ? 7 : radius);
        context.putImageData(imageData, top_x, top_y);
    };


})(Diigo.Doodle, Diigo.$);
(function(Text, Doodle, UR, $) {
	Text._Editor = function(parent) {
		this.parent = parent;
        this.history = parent.history;
        this.auto_width = false;

        this.textarea = parent.textarea;
        this.textarea_out = parent.textarea_out;

        this.floated_textbox = null;

		this.RTL = parent.RTL;

		this.cur_page = null;
		this.pages = [];


		this.render = new Text._Render(this);
		this.initEvent();

        this.focused = false;

        this.saved_info = {
            cur_page : null,
            width: 0,
            height: 0,
            scale : 1.0
        };
	};
	Text._Editor.prototype = {
        onChange : function() {

        },
        paint : function() {
            this.render.paint();
        },
        _paint : function() {
            this.render._paint();
        },

        getPageByIdx : function(idx) {
            return this.pages[idx];
        },
        setBoxAutoWidth : function(auto_width) {
            this.auto_width = auto_width;
        },

        setBoxSize_scale : function(width, height, scale) {
            var c_width = Math.floor(width * scale),
                c_height = Math.floor(height * scale);

            this.textarea.style.width = c_width + "px";
            this.textarea.style.height = c_height + "px";
            this.render.width = width;
            this.render.height = height;
            this.render.scale = scale;
        },
        save_state : function() {
            var si = this.saved_info;
            si.scale = this.render.scale;
            si.width = this.render.width;
            si.height = this.render.height;
            si.cur_page = this.cur_page;
        },
        set_drawtext_size : function(width, height, scale) {
            this.render.width = width;
            this.render.height = height;
            this.render.scale = scale;
        },
        restore_state : function() {
            var si = this.saved_info;
            this.render.scale = si.scale;
            this.render.width = si.width;
            this.render.height = si.height;
            this.cur_page = si.cur_page;
            this.render.page = si.cur_page;

            var c_width = Math.floor(si.width * si.scale),
                c_height = Math.floor(si.height * si.scale);

            this.textarea.style.width = c_width + "px";
            this.textarea.style.height = c_height + "px";

        },

        getPageHeight : function(page_idx) {
            return this.pages[page_idx].page_height;
        },
        /**
         * 设置css3 transform矩阵。用于图层文本框功能。
         * @param m
         */
        setBoxMatrix : function(m) {
            var m_str =  "matrix("+m[0]+","+m[3]+","+m[1]+","+m[4]+","+(m[2])+","+((m[5]))+")";
            this.textarea.style.webkitTransform = m_str;
        },
        setBoxPosition : function(x, y, rotate) {
            this.textarea_out.style.left = x + 'px';
            this.textarea_out.style.top = y + 'px';
            this.textarea.style.webkitTransform = "rotate("+Math.round(rotate*180/Math.PI)+"deg)";

        },
		createPage : function(style) {
            var np = new Text._Page(this, style);
            this.pages.push(np);
			return this.pages.length - 1;
		},
		setCurPage : function(index, auto_width) {
			this.cur_page = this.pages[index];
			this.render.page = this.cur_page;
            this.render.m_auto_width = auto_width ? true : false;
            var fnt = this.cur_page.style.getScaleFont(this.parent.zoom_scale);
            this.textarea.style.font = fnt;
            this.textarea.style.lineHeight = $.getFontInfo(fnt).height + 'px';
            this.textarea.style.color = this.cur_page.style.color;
            this.textarea.value = this.cur_page.text;
		},
        _setCurPage : function(index) {
            this.cur_page = this.pages[index];
            this.render.page = this.cur_page;
        },
        _setCurPage_saved : function(index) {
            var pre_idx = this.pages.indexOf(this.cur_page);
            this._setCurPage(index);
            return pre_idx;
        },

		focus : function() {
			if (this.focused === false) {
				this.focused = true;
				this.textarea.focus();
			}
		},
		blur : function() {
            if(this.focused) {
                this.focused = false;
                this.textarea.blur();
            }
		},

		clear : function() {
			this.cur_page.reset();
			this.select_doodle = null;
			this._setCaret({
				index : -1,
				para : 0,
				para_at : -1,
				left : 0,
				top : 0
			});
			this.history.clear();
		},
        show : function() {
            this.textarea.style.display = "block";
        },
        hide : function() {
            this.textarea.style.display = "none";
        }
	}
})(Diigo.Text, Diigo.Doodle, Diigo.UndoRedo, Diigo.$);

(function(Text, Doodle, Data, UR, $) {

	$.extend(Text._Editor.prototype, {

		_text_handler : function() {
            this.floated_textbox.onTextInput(this.textarea.value);
        },
        _keypress_handler : function() {
            this.floated_textbox.onTextPress();
        },
        initEvent : function() {
            $.addEvent(this.textarea, "input", $.createDelegate(this, this._text_handler));
            $.addEvent(this.textarea, "keypress", $.createDelegate(this, this._keypress_handler));
		}
		
	});
	/**MODULE END**/
})(Diigo.Text, Diigo.Doodle, Diigo.Data, Diigo.UndoRedo, Diigo.$);
(function(Text, $) {

	/**
	 * 页面逻辑
	 */
    Text._Paragraph = function(idx, len,line_start,line_cross,rtl,align,lines) {
        this.index = idx;
        this.length = len;
        this.line_start = line_start;
        this.line_cross = line_cross;
        this.lines = lines ? lines : [new Text._Line()];
        this.rtl = rtl ? true : false;
        this.align = align ? align : Text._Paragraph.Align.LEFT;
    };
    Text._Paragraph.Align = {
        LEFT : 0,
        RIGHT : 1,
        MIDDLE : 2
    };
    Text._Line = function(end_index, unti_dir, width) {
        this.end_index = end_index ? end_index : -1;
        this.unti_dir = unti_dir ? unti_dir : [];
        this.width = width ? width : 0;
    };
    Text._Element = function(value) {
        this.value = value;
        this.width = 0;
        this.visible = true;
    };
	Text._Page = function(editor, style) {
        this.editor = editor;
        this.style = style;
        /**
         * 字符元素，包括文本字符和手写文字
         */
		this.text = "";
        this.ele_array = [];
        this.para_number = 0;
        this.para_info = [];
        this.line_number = 0;
        this.page_height = 0;
        var fi = $.getFontInfo(style.font);
        this.line_height = fi.height;
        this.baseline_offset = fi.baseline_offset;
        this._init();
	};
	Text._Page.prototype = {
        resetFont : function() {
            var fi = $.getFontInfo(this.style.font);
            this.line_height = fi.height;
            this.baseline_offset = fi.baseline_offset;
        },
		_init : function() {
			this.para_number = 1;
			this.para_info = [new Text._Paragraph(-1,0,0,1,false, Text._Paragraph.Align.LEFT)];
			this.line_number = 1;
            this.page_height = this.line_number * this.line_height;
			this.text = "";
            this.ele_array.length = 0;
		},
		reset : function() {
			this._init();
		},
        initParagraph : function() {
            /**
             * 重新生成段落信息
             */

            var pi = -1, pl = 0, pp = new Text._Paragraph(pi,0,pl,1);
            this.ele_array.length = this.text.length;
            var i;
            for(i=0;i<this.text.length;i++) {
                this.ele_array[i] = new Text._Element(this.text[i]);
            }

            this.para_number = 1;
            this.para_info = [];
            this.line_number = 0;
            this.para_info.push(pp);

            for(i=0;i<this.ele_array.length;i++) {
                if(this.ele_array[i].value === '\n') {
                    pp.length = i - pi -1;
                    pp.line_cross = this._measureParagraph(pp);
                    pl += pp.line_cross;
                    this.line_number+=pp.line_cross;
                    pi = i;
                    pp = new Text._Paragraph(pi, 0, pl, 1);
                    this.para_info.push(pp);
                    this.para_number ++;
                }
            }
            pp.length = this.ele_array.length -1 - pi;
            pp.line_cross = this._measureParagraph(pp);
            this.line_number += pp.line_cross;
            this.page_height = this.line_number * this.line_height;
        },
		_measureParagraph : function(para) {
			para.rtl = this._getParaRTL(para);
			return this.editor.render._measure(para, this.style);
		},
        _getParaRTL : function(para) {
            var _det = false;
            var c = 0;
            if (para.length > 0) {
                for (var i = para.index + 1; i < para.index + 1 + para.length; i++) {
                    c = this.text.charCodeAt(i);
                    if (c >= 0 && !Text.Char.isBiaoDian(c) && !Text.Char.isDigit(c)) {
                        _det = true;
                        break;
                    }
                }
            }
            if (!_det) {
                return false;
            } else {
                return Text.Char.isRTL(c);
            }
        }


	}

})(Diigo.Text, Diigo.$);

(function(Text) {
	Text._Style = function(style) {
		style = style ? style : {};
		this.color = style.color ? style.color : '#000000';
		this.background = style.background ? style.background : false;
		this.underline = style.underline ? style.underline : false;
		this.through = style.through ? style.through : false;
		this.bold = style.bold ? style.bold : false;
        this.italic = style.italic ? style.italic : false;
        this.font_name = style.font_name ? style.font_name : 'Arial';
        this.font_size = style.font_size ? style.font_size : 16;
        this.font = this._getFont();
	};
	Text._Style.prototype = {
        setFontName : function(name) {
            this.font_name = name;
            this.font = this._getFont();
        },
        setFontSize : function(size) {
            this.font_size = size;
            this.font = this._getFont();
        },
        setItalic : function(italic) {
            this.italic = italic;
            this.font = this._getFont();
        },
		setThrough : function(through) {
			this.through = through;
		},
        setScale : function(scale) {
            this.scale = scale;
            this.font = this._getFont();
        },
        setBold : function(bold) {
            this.bold = bold;
            this.font = this._getFont();
        },
		setStyle : function(style) {
			style.bold != null ? this.bold = style.bold : false;
			style.color != null ? this.color = style.color : false;
			style.background != null ? this.background = style.background : false;
            style.bg_invert != null ? this.bg_invert = style.bg_invert : false;
			style.underline != null ? this.underline = style.underline : false;
			style.through != null ? this.through = style.through : false;
            style.italic != null? this.italic = style.italic : false;
            style.font_name != null ? this.font_name = style.font_name: false;
            style.font_size != null ? this.font_size = style.font_size : false;
            this.font = this._getFont();
		},
        clone : function() {
            return new Text._Style(this);
        },
        _getFont : function() {
            return (this.bold ? "bold " : "") + (this.italic ? "italic " : "") + this.font_size + "px " + this.font_name;
        },
        getScaleFont : function(scale) {
            return (this.bold ? "bold " : "") + (this.italic ? "italic " : "") + Math.floor(this.font_size * scale) + "px " + this.font_name;
        }

	};


})(Diigo.Text);

/**
 * 渲染逻辑
 */
(function(Text, $) {

	Text._Render = function(editor) {
		this.editor = editor;
		this.page = null;

		this.width = 0;
		this.height = 0;
        this.scale = 1.0;


        this.baseline_offset = 0;

        this.canvas = document.createElement("canvas");
        this.ctx = this.canvas.getContext('2d');

    };

	Text._Render.prototype = {

		_paintLine : function(si, ei, p_idx, unti_dir, rtl, bottom, hor_offset) {
            var str = this.editor.cur_page.text.substr(p_idx+si, ei - si + 1);
//            this.ctx.textBaseline = 'ideographic';
            this.ctx.fillText(str, hor_offset, bottom);
		},
		_paintContent : function() {
			var ed = this.editor,
                scale = this.scale,
                t_p = 0,

				l_h = ed.cur_page.line_height, s_l_h = ed.cur_page.line_height * scale,
				para = this.page.para_info, total_line = 0, t_h = t_p / scale,
				line_start = 0, bottom = 0, s_bottom = 0;
            var max_height = this.height * scale + s_l_h;

            if(t_h<=0){
				line_start = 0;
				bottom = -t_h + l_h;
                s_bottom = -t_p + s_l_h;
			} else {
				line_start = Math.floor(t_h/l_h);
				bottom = (line_start+1)*l_h - t_h;
                s_bottom = (line_start+1)*s_l_h - t_p;

            }
//            $.log("tt: %s, %s, %s", t_p, t_h, line_start);

            var i = 0;
			while(i<para.length && (total_line+=para[i].lines.length)<=line_start){
				i++;
			}
            if(i>=para.length) {
                return;
            }
//            $.log("dd: %s, %s, %s", i, total_line, para.length);

            var _start = line_start - (total_line - para[i].lines.length);
			para_loop:
			for (;i < para.length; i++) {
				var ep = para[i], ls = ep.lines, si = 0, A = Text._Paragraph.Align;
                if(_start>0) {
                    si = ls[_start-1].end_index + 1;
                }
                for (var j = _start; j < ls.length; j++) {
                    var hor_offset = 0;
                    switch (ep.align) {
                        case A.LEFT :
                            hor_offset = 0;
                            break;
                        case A.MIDDLE :
                            hor_offset = Math.round((this.width - ls[j].width)/2);
                            break;
                        case A.RIGHT:
                            hor_offset = this.width-ls[j].width;
                            break;
                    }
                    //$.log(hor_offset);
					this._paintLine(si, ls[j].end_index, ep.index + 1, ls[j].unti_dir, ep.rtl, bottom - ed.cur_page.baseline_offset, hor_offset);
					si = ls[j].end_index + 1;
					bottom += l_h;
                    s_bottom += s_l_h;
					if(s_bottom >= max_height){
						break para_loop;
					}
				}
                _start = 0;

            }
		},
        paintToContext : function(ctx, style) {
            var saved_ctx = this.ctx;
            var _s = this.scale;
            this.ctx = ctx;
            this.ctx.save();
            this.ctx.scale(_s, _s);
            this.ctx.font = style.font;
            this.ctx.fillStyle = style.color;

            if (this.page.text.trim() !== '') {
                this._paintContent();
            }
            this.ctx.restore();
            this.ctx = saved_ctx;
        }


	}

})(Diigo.Text, Diigo.$);

(function(Text, $) {
	Text.Char = {
		isRTL : function(c) {
			return c >= 0x600 && c <= 0x6ff;
		},
		isBiaoDian : function(c) {
			return (c >= 32 && c <= 47) || (c >= 58 && c <= 64) || (c >= 91 && c <= 96) || (c >= 123 && c <= 126);
		},
		isDigit : function(c) {
			return c >= 48 && c <= 57;
		},
		/**
		 * 从andorid 源码StaticLayout.java移植
		 */
		isIdeographic : function(c, includeNonStarters) {
			if (c >= 0x2E80 && c <= 0x2FFF) {
				return true;
				// CJK, KANGXI RADICALS, DESCRIPTION SYMBOLS
			}
			if (c === 0x3000) {
				return true;
				// IDEOGRAPHIC SPACE
			}
			if (c >= 0x3040 && c <= 0x309F) {
				if (!includeNonStarters) {
					switch (c) {
						case 0x3041:
						//  # HIRAGANA LETTER SMALL A
						case 0x3043:
						//  # HIRAGANA LETTER SMALL I
						case 0x3045:
						//  # HIRAGANA LETTER SMALL U
						case 0x3047:
						//  # HIRAGANA LETTER SMALL E
						case 0x3049:
						//  # HIRAGANA LETTER SMALL O
						case 0x3063:
						//  # HIRAGANA LETTER SMALL TU
						case 0x3083:
						//  # HIRAGANA LETTER SMALL YA
						case 0x3085:
						//  # HIRAGANA LETTER SMALL YU
						case 0x3087:
						//  # HIRAGANA LETTER SMALL YO
						case 0x308E:
						//  # HIRAGANA LETTER SMALL WA
						case 0x3095:
						//  # HIRAGANA LETTER SMALL KA
						case 0x3096:
						//  # HIRAGANA LETTER SMALL KE
						case 0x309B:
						//  # KATAKANA-HIRAGANA VOICED SOUND MARK
						case 0x309C:
						//  # KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK
						case 0x309D:
						//  # HIRAGANA ITERATION MARK
						case 0x309E:
							//  # HIRAGANA VOICED ITERATION MARK
							return false;
					}
				}
				return true;
				// Hiragana (except small characters)
			}
			if (c >= 0x30A0 && c <= 0x30FF) {
				if (!includeNonStarters) {
					switch (c) {
						case 0x30A0:
						//  # KATAKANA-HIRAGANA DOUBLE HYPHEN
						case 0x30A1:
						//  # KATAKANA LETTER SMALL A
						case 0x30A3:
						//  # KATAKANA LETTER SMALL I
						case 0x30A5:
						//  # KATAKANA LETTER SMALL U
						case 0x30A7:
						//  # KATAKANA LETTER SMALL E
						case 0x30A9:
						//  # KATAKANA LETTER SMALL O
						case 0x30C3:
						//  # KATAKANA LETTER SMALL TU
						case 0x30E3:
						//  # KATAKANA LETTER SMALL YA
						case 0x30E5:
						//  # KATAKANA LETTER SMALL YU
						case 0x30E7:
						//  # KATAKANA LETTER SMALL YO
						case 0x30EE:
						//  # KATAKANA LETTER SMALL WA
						case 0x30F5:
						//  # KATAKANA LETTER SMALL KA
						case 0x30F6:
						//  # KATAKANA LETTER SMALL KE
						case 0x30FB:
						//  # KATAKANA MIDDLE DOT
						case 0x30FC:
						//  # KATAKANA-HIRAGANA PROLONGED SOUND MARK
						case 0x30FD:
						//  # KATAKANA ITERATION MARK
						case 0x30FE:
							//  # KATAKANA VOICED ITERATION MARK
							return false;
					}
				}
				return true;
				// Katakana (except small characters)
			}
			if (c >= 0x3400 && c <= 0x4DB5) {
				return true;
				// CJK UNIFIED IDEOGRAPHS EXTENSION A
			}
			if (c >= 0x4E00 && c <= 0x9FBB) {
				return true;
				// CJK UNIFIED IDEOGRAPHS
			}
			if (c >= 0xF900 && c <= 0xFAD9) {
				return true;
				// CJK COMPATIBILITY IDEOGRAPHS
			}
			if (c >= 0xA000 && c <= 0xA48F) {
				return true;
				// YI SYLLABLES
			}
			if (c >= 0xA490 && c <= 0xA4CF) {
				return true;
				// YI RADICALS
			}
			if (c >= 0xFE62 && c <= 0xFE66) {
				return true;
				// SMALL PLUS SIGN to SMALL EQUALS SIGN
			}
			if (c >= 0xFF10 && c <= 0xFF19) {
				return true;
				// WIDE DIGITS
			}

			return false;
		}
	}

	$.extend(Text._Render.prototype, {
		_getDirLength : function(e_arr, idx, e_idx, rtl) {
			var pre_a = idx, pre_s = false, len = 1, i = idx + 1, s_len = 0;
			while (i < e_idx) {
				var c = e_arr[i].value.charCodeAt(i);
				var is_dir = rtl ? Text.Char.isRTL(c) : (c > 0 && !Text.Char.isRTL(c) && !Text.Char.isBiaoDian(c));
				if (is_dir) {
					/**
					 * 如果 rtl为真，则取得rtl文字；否则，通过is_rtl和c>0取得 ltr 文字。
					 * 因为c<0代表图片或手写文字，不具备方向属性。
					 */
					if (pre_s) {
						/**
						 * 如果在两端阿拉伯文字中夹了空格，把空格加入
						 */
						len += s_len;
						pre_s = false;
						s_len = 0;
					}
					len++;

				} else if (c < 0 || Text.Char.isBiaoDian(c)) {
					/**
					 * 图片、手写文字及标点自身不具备方向属性，如果夹在两个相同方向之间，则跟这个方向一致。
					 */
					s_len++;
					pre_s = true;
				} else {
					break;
				}
				i++;
			}
			//$.log("al:%d",len)
			return len;
		},
		_getCode : function(ele) {
			return ele.value.charCodeAt(0);
		},
		_measureStrElement : function(str) {
            return this.ctx.measureText(str).width;
		},
        _measureElement : function(ele) {
            return this.ctx.measureText(ele.value).width;
        },
		_measure : function(para, style) {

            this.ctx.font = style.font;
			para.lines = [new Text._Line(-1, [], 0)];

			return this._doMeasure(para);


		},

        _m_LTR : function(unti, left, e_arr, idx, l_at, para, s_idx, e_idx) {

            var bk_idx = idx - 1, first = unti ? true : false, bk_w = 0, i = idx, line_at = l_at;
            var end_index = unti ? idx + this._getDirLength(e_arr, idx, e_idx, false) : e_idx;
            var width = unti ? left :  this.width - left;
            var rg_idx = unti ? idx : -1;
//            var pre_w = 0, cur_w = 0, str = "";

            //$.log(width);
            while (i < end_index) {

                var e = e_arr[i], c = this._getCode(e),
                    pe = i===idx? null : e_arr[i-1], pc = pe===null ? -1 : this._getCode(pe),
                    ne = i + 1 < e_idx ? e_arr[i + 1] : null,
                    nc = (ne === null ? -1 : this._getCode(ne));

                if (!unti && Text.Char.isRTL(c)) {
                    end_index = i;
                    break;
                }

                if (c >= 0) {
                    if(e.width === 0) {
//                        $.log('m : %s', e.value);
                        e.width = this._measureElement(e);
                    }
                }

                bk_w += e.width;

                if (bk_w < width) {
                    if (//如果当前字符不是char，可breakline
                        c < 0
                            //如果是空格或tab键可breakline
                            || c === 32 || c === 9
                            //如果当前字符是, . : ; 并且其左右不是数字，可breakline
                            || ((c === 44 || c === 46 || c === 58 || c === 59) && (i === s_idx || !Text.Char.isDigit(this._getCode(e_arr[i - 1]))) && (ne === null || !Text.Char.isDigit(nc)))
                            //如果当前字符是 / - 并且右边不是数字，可breakline
                            || ((c === 45 || c === 47) && (ne === null || !Text.Char.isDigit(nc)))
                            //如果当前是中日韩，并且右边不是不可断行字符，可breakline
                            || c >= 0x2E80 && Text.Char.isIdeographic(c, true) && ne !== null && Text.Char.isIdeographic(nc, false)
                    //
                        ) {
                        first = false;
                        bk_idx = i;
                    }
                } else if (c === 32) {
                    //如果当前是空格，则不能换行，并且把该空格设置为不可见。
                    //空格不能出现在某一行的行首
                    e.visible = false;
                    bk_idx = i;
                } else {
                    //$.log("bk:" + bk_idx)

                    if (bk_idx >= idx || first) {
                        //如果当前可换行
                        //将i回退到需要换行位置
                        i = bk_idx + 1;
                    }
                    var cur_line_idx = l_at - para.line_start;
                    if (!first && unti) {
                        //$.log("%d,%d,%d",i,rg_idx,bk_idx)
                        //$.log("%s", bk_w)
                        var _dir = {
                            index : rg_idx - s_idx,
                            length : i - rg_idx,
                            width : 0
                        }
                        for (var d = rg_idx; d < i; d++) {
                            _dir.width += e_arr[d].width;
                        }
                        para.lines[cur_line_idx].unti_dir.push(_dir);
                    }
                    para.lines[cur_line_idx].end_index = i - 1 - s_idx;
                    para.lines.push(new Text._Line());
                    bk_w = 0;
                    rg_idx = i;
                    left = unti ? this.width : 0;
                    width = this.width;
                    bk_w = 0;
                    bk_idx = idx - 1;
                    l_at++;
                    first = false;
                    /**
                     * 直接跳到下一次循环
                     */
                    continue;
                }
                i++;
            }

            if (unti) {
                /**
                 * 最后一段反向区域的宽度直接可以由bk_w得到
                 */
                para.lines[l_at - para.line_start].unti_dir.push({
                    index : rg_idx - s_idx,
                    length : end_index - rg_idx,
                    width : bk_w
                });

            }

            return {
                left : unti ? left - bk_w : left + bk_w,
                line_at : l_at,
                end_index : end_index
            }
        },
        _calc_line_width : function(e_arr, s, e) {
            var w = 0;
            for(var i=s;i<=e;i++) {
                if(e_arr[i].visible) {
                    w += e_arr[i].width;
                    //$.log("i:%s , w:%s",i, w);
                }
            }
            return w;
        },
		_m_RTL : function(unti, left, e_arr, idx, l_at, para, s_idx, e_idx) {
			//$.log("rtl unti:"+unti)
			var bk_idx = idx - 1, first = unti ? true : false, bk_w = 0, i = idx, line_at = l_at;
			var width = unti ? this.width - left : left;
			var end_index = unti ? idx + this._getDirLength(e_arr, idx, e_idx, true) : e_idx;
			//$.log(end_index)
			var rg_idx = unti ? idx : -1;
			var pre_i = i, ew = 0, str = "";

			//$.log("%d",end_index)
			while (i < end_index) {
				var e = e_arr[i], ne = i + 1 < e_idx ? e_arr[i + 1] : null, c = this._getCode(e);

				if (!unti && c >= 0 && !Text.Char.isRTL(c) && !Text.Char.isBiaoDian(c)) {
					end_index = i;
					break;
				}

				if (c > 0) {
					str += e.value;
					ew = this._measureStrElement(e, str);
				} else {
					ew = e.width;
				}

				if (bk_w + ew < width) {
					if (c < 0x600) {
						first = false;
						bk_idx = i;
					}
					if (c < 0x600 || ne === null || !Text.Char.isRTL(this._getCode(ne))) {
						if (c > 0) {
							for (var k = pre_i; k <= i; k++) {
								e_arr[k].width = ew / (i - pre_i + 1);
							}
							//$.log("%s,%s,%s,%s",k,pre_i,i,ew)
						}
						bk_w += ew;
						str = "";
						pre_i = i + 1;
					}
					i++;
					//$.log(SNEditor.cur_page.ele_array[6].width)
				} else {

					//$.log(first)

					if (bk_idx > idx || first) {
						i = bk_idx + 1;
					}
                    var cur_line_idx = l_at - para.line_start;
					if (!first && unti) {
						//$.log("%d,%d,%d",i,rg_idx,bk_idx)
						//$.log("%d,%d",para.lines.length,l_at)
						var _dir = {
							index : rg_idx - s_idx,
							length : i - rg_idx,
							width : 0
						}
						for (var d = rg_idx; d < i; d++) {
							_dir.width += e_arr[d].width;
						}
						para.lines[cur_line_idx].unti_dir.push(_dir);
					}
					para.lines[cur_line_idx].end_index = i - 1 - s_idx;
                    para.lines.push(new Text._Line());
					rg_idx = i;
					for (var k = pre_i; k <= i; k++) {
						e_arr[k].width = ew / (i - pre_i + 1)
					}
					//$.log("%s,%s,%s,%s",k,pre_i,i,ew)
					str = "";
					pre_i = i;
					left = unti ? 0 : this.width;
					width = this.width;
					bk_w = 0;
					bk_idx = idx - 1;
					l_at++;
					first = false;
					//$.log(SNEditor.cur_page.ele_array[6].width)
				}
			}
			//$.log("e?%s",SNEditor.cur_page.ele_array[6].width)
			if (unti) {
				para.lines[l_at - para.line_start].unti_dir.push({
					index : rg_idx - s_idx,
					length : end_index - rg_idx,
					width : bk_w
				});
			}
			//$.log(bk_w);
			//$.log(left);
			return {
				left : unti ? left + bk_w : left - bk_w,
				line_at : l_at,
				end_index : end_index
			}
		},
		_doMeasure : function(para) {

			var rtl = para.rtl, s_idx = para.index + 1, e_idx = s_idx + para.length;
			var l_at = para.line_start, e_arr = this.page.ele_array;
			var left = rtl ? this.width : 0;
			var i = s_idx, m_r = null;
			while (i < e_idx) {

				if (rtl) {
					m_r = this._m_RTL(para.rtl === false, left, e_arr, i, l_at, para, s_idx, e_idx);
				} else {
                    m_r = this._m_LTR(para.rtl === true, left, e_arr, i, l_at, para, s_idx, e_idx);
				}
				l_at = m_r.line_at;
				left = m_r.left;
				i = m_r.end_index;
				rtl = !rtl;
			}


			para.lines[l_at - para.line_start].end_index = para.length - 1;

            for(var i=0;i<para.lines.length;i++) {
                var _w = this._calc_line_width(e_arr, para.index + 1 + (i===0?0:para.lines[i-1].end_index), para.index + 1 + para.lines[i].end_index);
                //$.log("%s,%s",i,_w);
                para.lines[i].width = _w;
            }


            return l_at - para.line_start + 1;
		}
	});
})(Diigo.Text, Diigo.$);